@@ -2,7 +2,7 @@
 #define NEWSBOAT_CONFIG_H_
 
 #define PACKAGE				"newsboat"
-#define PROGRAM_NAME			PACKAGE
+#define PROGRAM_NAME			"Newsboat"
 
 #define PROGRAM_URL			"https://newsboat.org/"
 
@@ -27,6 +27,12 @@
 
 #define _s(msg) std::string(gettext(msg))
 
+// Use this macro instead of `_` and `_s` if you want the string to get extracted
+// by xgettext, but don't want to call gettext(). This is useful for
+// initializers of statically-allocated global objects, where gettext() calls
+// operate with default (C) locale and are useless.
+#define translatable(msg) msg
+
 /* #define NDEBUG */ // only enable this #define if you want to disable all debug logging.
 
 #endif /* NEWSBOAT_CONFIG_H_ */
