@@ -1,11 +1,11 @@
 #ifndef NEWSBOAT_COLORMANAGER_H_
 #define NEWSBOAT_COLORMANAGER_H_
 
+#include <functional>
 #include <map>
 #include <vector>
 
-#include "configparser.h"
-#include "stflpp.h"
+#include "configactionhandler.h"
 
 namespace podboat {
 class PbView;
@@ -15,6 +15,8 @@ class View;
 
 namespace newsboat {
 
+class ConfigParser;
+
 struct TextStyle {
 	std::string fg_color;
 	std::string bg_color;
@@ -28,14 +30,15 @@ public:
 	void register_commands(ConfigParser& cfgparser);
 	void handle_action(const std::string& action,
 		const std::vector<std::string>& params) override;
-	void dump_config(std::vector<std::string>& config_output) override;
-	void apply_colors(Stfl::Form& form) const;
-	std::map<std::string, TextStyle> get_styles() const
-	{
-		return element_styles;
-	}
+	void dump_config(std::vector<std::string>& config_output) const override;
+	void apply_colors(std::function<void(const std::string&, const std::string&)>
+		stfl_value_setter) const;
 
 private:
+	void emit_fallback_from_to(const std::string& from_element, const std::string& to_element,
+		const std::function<void(const std::string&, const std::string&)>& stfl_value_setter)
+	const;
+
 	std::map<std::string, TextStyle> element_styles;
 };
 
