@@ -9,9 +9,9 @@
 namespace newsboat {
 
 enum class ActionHandlerStatus {
-	VALID = 0,
 	INVALID_PARAMS,
 	TOO_FEW_PARAMS,
+	TOO_MANY_PARAMS,
 	INVALID_COMMAND,
 	FILENOTFOUND
 };
@@ -24,11 +24,21 @@ public:
 		ConfigActionHandler& handler);
 	void handle_action(const std::string& action,
 		const std::vector<std::string>& params) override;
-	void dump_config(std::vector<std::string>&) override
+	void dump_config(std::vector<std::string>&) const override
 	{
 		/* nothing because ConfigParser itself only handles include */
 	}
+
+	/// Processes configuration commands from a file at \a filename.
+	///
+	/// Returns:
+	/// - `false` if the file couldn't be opened;
+	/// - `true` if the whole file was processed completely.
+	///
+	/// If the file contains any errors, throws `ConfigException` with
+	/// a message explaining the problem.
 	bool parse_file(const std::string& filename);
+
 	void parse_line(const std::string& line, const std::string& location);
 	static std::string evaluate_backticks(std::string token);
 
