@@ -7,15 +7,15 @@
 #include "configcontainer.h"
 #include "file_system.h"
 #include "formaction.h"
-#include "listformatter.h"
 #include "listwidget.h"
+#include "stflrichtext.h"
 
 namespace newsboat {
 
 class DirBrowserFormAction : public FormAction {
 public:
-	DirBrowserFormAction(View*, std::string formstr, ConfigContainer* cfg);
-	~DirBrowserFormAction() override;
+	DirBrowserFormAction(View&, std::string formstr, ConfigContainer* cfg);
+	~DirBrowserFormAction() override = default;
 	void prepare() override;
 	void init() override;
 	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
@@ -41,13 +41,16 @@ private:
 	void add_directory(std::vector<file_system::FileSystemEntry>& id_at_position,
 		std::string dirname);
 	std::vector<file_system::FileSystemEntry> id_at_position;
-	std::vector<std::string> lines;
+	std::vector<StflRichText> lines;
 
 	std::string get_formatted_dirname(std::string dirname, mode_t mode);
 
+	LineView file_prompt_line;
 	std::string cwd;
 
 	ListWidget files_list;
+
+	View& view;
 };
 
 } // namespace newsboat
