@@ -7,7 +7,7 @@ namespace newsboat {
 
 class EmptyFormAction : public FormAction {
 public:
-	EmptyFormAction(View* v, const std::string& formstr, ConfigContainer* cfg);
+	EmptyFormAction(View& v, const std::string& formstr, ConfigContainer* cfg);
 	virtual ~EmptyFormAction() = default;
 
 	std::string id() const override;
@@ -20,8 +20,8 @@ public:
 
 protected:
 	bool process_operation(Operation op,
-		bool automatic = false,
-		std::vector<std::string>* args = nullptr) override;
+		const std::vector<std::string>& args,
+		BindingType bindingType = BindingType::BindKey) override;
 	std::string main_widget() const override
 	{
 		return "lastline";
