@@ -7,15 +7,15 @@
 #include "configcontainer.h"
 #include "file_system.h"
 #include "formaction.h"
-#include "listformatter.h"
 #include "listwidget.h"
+#include "stflrichtext.h"
 
 namespace newsboat {
 
 class FileBrowserFormAction : public FormAction {
 public:
-	FileBrowserFormAction(View*, std::string formstr, ConfigContainer* cfg);
-	~FileBrowserFormAction() override;
+	FileBrowserFormAction(View&, std::string formstr, ConfigContainer* cfg);
+	~FileBrowserFormAction() override = default;
 	void prepare() override;
 	void init() override;
 	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
@@ -39,23 +39,26 @@ protected:
 
 private:
 	bool process_operation(Operation op,
-		bool automatic = false,
-		std::vector<std::string>* args = nullptr) override;
+		const std::vector<std::string>& args,
+		BindingType bindingType = BindingType::BindKey) override;
 	void update_title(const std::string& working_directory);
 
-	void add_file(ListFormatter& listfmt,
-		std::vector<file_system::FileSystemEntry>& id_at_position,
+	void add_file(std::vector<file_system::FileSystemEntry>& id_at_position,
 		std::string filename);
 	std::string get_filename_suggestion(const std::string& s);
 	std::vector<file_system::FileSystemEntry> id_at_position;
+	std::vector<StflRichText> lines;
 
 	std::string get_formatted_filename(std::string filename, mode_t mode);
 
+	LineView file_prompt_line;
 	bool quit;
 	std::string cwd;
 	std::string default_filename;
 
 	ListWidget files_list;
+
+	View& view;
 };
 
 } // namespace newsboat
