@@ -11,13 +11,17 @@ class FileUrlReader : public UrlReader {
 public:
 	explicit FileUrlReader(const std::string& file = "");
 
-	void reload() override;
+	/// \brief Load URLs from the urls file.
+	///
+	/// \return A non-value on success, a structure with error info otherwise.
+	nonstd::optional<utils::ReadTextFileError> reload() override;
+
 	std::string get_source() override;
 
-	/// \brief Write URLs back to the input file.
+	/// \brief Write URLs back to the urls file.
 	///
-	/// This method is used after importing feeds from OPML.
-	void write_config();
+	/// \return A non-value on success, an error message otherwise.
+	nonstd::optional<std::string> write_config();
 
 private:
 	const std::string filename;
