@@ -1,7 +1,9 @@
 #ifndef NEWSBOAT_FILTERCONTAINER_H_
 #define NEWSBOAT_FILTERCONTAINER_H_
 
-#include "configparser.h"
+#include "configactionhandler.h"
+
+#include "3rd-party/optional.hpp"
 
 namespace newsboat {
 
@@ -21,7 +23,7 @@ public:
 	~FilterContainer() override;
 	void handle_action(const std::string& action,
 		const std::vector<std::string>& params) override;
-	void dump_config(std::vector<std::string>& config_output) override;
+	void dump_config(std::vector<std::string>& config_output) const override;
 	std::vector<FilterNameExprPair>& get_filters()
 	{
 		return filters;
@@ -31,6 +33,8 @@ public:
 		return filters.size();
 	}
 
+	nonstd::optional<std::string> get_filter(const std::string& name);
+
 private:
 	std::vector<FilterNameExprPair> filters;
 };
