@@ -1,7 +1,8 @@
 #ifndef NEWSBOAT_FORMATSTRING_H_
 #define NEWSBOAT_FORMATSTRING_H_
 
-#include <map>
+#include "libnewsboat-ffi/src/fmtstrformatter.rs.h"
+
 #include <string>
 
 namespace newsboat {
@@ -9,12 +10,14 @@ namespace newsboat {
 class FmtStrFormatter {
 public:
 	FmtStrFormatter();
-	~FmtStrFormatter();
+	FmtStrFormatter(FmtStrFormatter&&) = default;
+	FmtStrFormatter& operator=(FmtStrFormatter&&) = default;
+	~FmtStrFormatter() = default;
 	void register_fmt(char f, const std::string& value);
 	std::string do_format(const std::string& fmt, unsigned int width = 0);
 
 private:
-	void* rs_fmt = nullptr;
+	rust::Box<fmtstrformatter::bridged::FmtStrFormatter> rs_object;
 };
 
 } // namespace newsboat
