@@ -3,15 +3,13 @@
 
 #include <libxml/tree.h>
 
-#include "cache.h"
 #include "remoteapi.h"
-#include "urlreader.h"
 
 namespace newsboat {
 
 class InoreaderApi : public RemoteApi {
 public:
-	explicit InoreaderApi(ConfigContainer* c);
+	explicit InoreaderApi(ConfigContainer& c);
 	virtual ~InoreaderApi() = default;
 	virtual bool authenticate();
 	virtual std::vector<TaggedFeedUrl> get_subscribed_urls();
