@@ -1,8 +1,6 @@
 #ifndef NEWSBOAT_ITEMLISTFORMACTION_H_
 #define NEWSBOAT_ITEMLISTFORMACTION_H_
 
-#include <assert.h>
-
 #include "3rd-party/optional.hpp"
 
 #include "configcontainer.h"
@@ -11,6 +9,7 @@
 #include "listformaction.h"
 #include "listformatter.h"
 #include "regexmanager.h"
+#include "stflrichtext.h"
 #include "view.h"
 
 namespace newsboat {
@@ -23,13 +22,13 @@ enum class InvalidationMode { NONE, PARTIAL, COMPLETE };
 
 class ItemListFormAction : public ListFormAction {
 public:
-	ItemListFormAction(View*,
+	ItemListFormAction(View&,
 		std::string formstr,
 		Cache* cc,
 		FilterContainer& f,
 		ConfigContainer* cfg,
 		RegexManager& r);
-	~ItemListFormAction() override;
+	~ItemListFormAction() override = default;
 	void prepare() override;
 	void init() override;
 
@@ -71,8 +70,8 @@ public:
 
 protected:
 	bool process_operation(Operation op,
-		bool automatic = false,
-		std::vector<std::string>* args = nullptr) override;
+		const std::vector<std::string>& args,
+		BindingType bindingType = BindingType::BindKey) override;
 	std::string main_widget() const override
 	{
 		return "items";
@@ -117,7 +116,7 @@ private:
 
 	int get_pos(unsigned int idx);
 
-	void save_article(const std::string& filename,
+	void save_article(const nonstd::optional<std::string>& filename,
 		std::shared_ptr<RssItem> item);
 
 	void handle_save(const std::vector<std::string>& cmd_args);
@@ -134,7 +133,7 @@ private:
 
 	void prepare_set_filterpos();
 
-	std::string item2formatted_line(const ItemPtrPosPair& item,
+	StflRichText item2formatted_line(const ItemPtrPosPair& item,
 		const unsigned int width,
 		const std::string& itemlist_format,
 		const std::string& datetime_format);
