@@ -2,7 +2,7 @@
 #define NEWSBOAT_ITEMVIEWFORMACTION_H_
 
 #include "formaction.h"
-#include "htmlrenderer.h"
+#include "links.h"
 #include "regexmanager.h"
 #include "textformatter.h"
 #include "textviewwidget.h"
@@ -15,13 +15,13 @@ class RssItem;
 
 class ItemViewFormAction : public FormAction {
 public:
-	ItemViewFormAction(View*,
+	ItemViewFormAction(View&,
 		std::shared_ptr<ItemListFormAction> il,
 		std::string formstr,
 		Cache* cc,
 		ConfigContainer* cfg,
 		RegexManager& r);
-	~ItemViewFormAction() override;
+	~ItemViewFormAction() override = default;
 	void prepare() override;
 	void init() override;
 	void set_guid(const std::string& guid_)
@@ -47,7 +47,7 @@ public:
 	void render_html(
 		const std::string& source,
 		std::vector<std::pair<LineType, std::string>>& lines,
-		std::vector<LinkPair>& thelinks,
+		Links& links,
 		const std::string& url);
 
 	void update_percent();
@@ -62,8 +62,8 @@ private:
 	void register_format_styles();
 
 	bool process_operation(Operation op,
-		bool automatic = false,
-		std::vector<std::string>* args = nullptr) override;
+		const std::vector<std::string>& args,
+		BindingType bindingType = BindingType::BindKey) override;
 
 	bool open_link_in_browser(const std::string& link, const std::string& type,
 		const std::string& title, bool interactive) const;
@@ -85,7 +85,7 @@ private:
 	std::shared_ptr<RssFeed> feed;
 	std::shared_ptr<RssItem> item;
 	bool show_source;
-	std::vector<LinkPair> links;
+	Links links;
 	RegexManager& rxman;
 	unsigned int num_lines;
 	std::shared_ptr<ItemListFormAction> itemlist;
