@@ -9,12 +9,13 @@ class RemoteApi;
 
 class MinifluxUrlReader : public UrlReader {
 public:
-	MinifluxUrlReader(const std::string& url_file, RemoteApi* a);
+	MinifluxUrlReader(ConfigContainer* c, const std::string& url_file, RemoteApi* a);
 	~MinifluxUrlReader() override;
 	nonstd::optional<utils::ReadTextFileError> reload() override;
 	std::string get_source() override;
 
 private:
+	ConfigContainer* cfg;
 	std::string file;
 	RemoteApi* api;
 };
