@@ -11,7 +11,7 @@ class OcNewsUrlReader : public UrlReader {
 public:
 	OcNewsUrlReader(const std::string& url_file, RemoteApi* a);
 	~OcNewsUrlReader() override;
-	void reload() override;
+	nonstd::optional<utils::ReadTextFileError> reload() override;
 	std::string get_source() override;
 
 private:
