@@ -11,13 +11,13 @@ namespace newsboat {
 
 class OpmlUrlReader : public UrlReader {
 public:
-	explicit OpmlUrlReader(ConfigContainer* c);
+	explicit OpmlUrlReader(ConfigContainer& c);
 	nonstd::optional<utils::ReadTextFileError> reload() override;
 	std::string get_source() override;
 
 protected:
 	virtual void handle_node(xmlNode* node, const std::string& tag);
-	ConfigContainer* cfg;
+	ConfigContainer& cfg;
 
 private:
 	void rec_find_rss_outlines(xmlNode* node, std::string tag);
