@@ -1,10 +1,9 @@
 #ifndef PODBOAT_PODDLTHREAD_H_
 #define PODBOAT_PODDLTHREAD_H_
 
+#include <chrono>
 #include <fstream>
 #include <memory>
-#include <sys/time.h>
-#include <thread>
 #include <time.h>
 
 #include "configcontainer.h"
@@ -14,7 +13,7 @@ namespace podboat {
 
 class PodDlThread {
 public:
-	PodDlThread(Download* dl_, newsboat::ConfigContainer*);
+	PodDlThread(Download* dl_, newsboat::ConfigContainer& c);
 	virtual ~PodDlThread();
 	size_t write_data(void* buffer, size_t size, size_t nmemb);
 	int progress(double dlnow, double dltotal);
@@ -27,10 +26,10 @@ private:
 	void run();
 	Download* dl;
 	std::shared_ptr<std::ofstream> f;
-	timeval tv1;
-	timeval tv2;
+	std::chrono::time_point<std::chrono::steady_clock> tv1;
+	std::chrono::time_point<std::chrono::steady_clock> tv2;
 	size_t bytecount;
-	newsboat::ConfigContainer* cfg;
+	newsboat::ConfigContainer& cfg;
 };
 
 } // namespace podboat
