@@ -4,7 +4,6 @@
 #include <map>
 #include <memory>
 #include <regex.h>
-#include <regex>
 #include <string>
 #include <sys/types.h>
 #include <utility>
@@ -13,6 +12,7 @@
 #include "configactionhandler.h"
 #include "matcher.h"
 #include "regexowner.h"
+#include "stflrichtext.h"
 
 namespace newsboat {
 
@@ -22,15 +22,10 @@ public:
 	void handle_action(const std::string& action,
 		const std::vector<std::string>& params) override;
 	void dump_config(std::vector<std::string>& config_output) const override;
-	void quote_and_highlight(std::string& str, const std::string& location);
+	void quote_and_highlight(StflRichText& stflString, const std::string& location);
 	void remove_last_regex(const std::string& location);
 	int article_matches(Matchable* item);
 	int feed_matches(Matchable* feed);
-	std::map<size_t, std::string> extract_style_tags(std::string& str);
-	void insert_style_tags(std::string& str, std::map<size_t, std::string>& tags);
-	void merge_style_tag(std::map<size_t, std::string>& tags,
-		const std::string& tag,
-		size_t start, size_t end);
 	std::string get_attrs_stfl_string(const std::string& location, bool hasFocus);
 
 private:
