@@ -2,28 +2,27 @@
 #define NEWSBOAT_REMOTEAPI_H_
 
 #include <curl/curl.h>
+#include <functional>
 #include <string>
 #include <utility>
 #include <vector>
 
-#include "configcontainer.h"
-
 namespace newsboat {
 
+class ConfigContainer;
+
 typedef std::pair<std::string, std::vector<std::string>> TaggedFeedUrl;
 
 typedef struct {
 	std::string user;
 	std::string pass;
+	std::string token;
 } Credentials;
 
 class RemoteApi {
 public:
-	explicit RemoteApi(ConfigContainer* c)
-		: cfg(c)
-	{
-	}
-	virtual ~RemoteApi() {}
+	explicit RemoteApi(ConfigContainer& c);
+	virtual ~RemoteApi() = default;
 	virtual bool authenticate() = 0;
 	virtual std::vector<TaggedFeedUrl> get_subscribed_urls() = 0;
 	virtual void add_custom_headers(curl_slist** custom_headers) = 0;
@@ -37,7 +36,11 @@ public:
 	static const std::string eval_password(const std::string& cmd);
 
 protected:
-	ConfigContainer* cfg;
+	static void update_flag(const std::string& oldflags,
+		const std::string& newflags,
+		char flag, std::function<void(bool added)>&& do_update);
+
+	ConfigContainer& cfg;
 	Credentials get_credentials(const std::string& scope,
 		const std::string& name);
 };
