@@ -1,8 +1,9 @@
 #ifndef NEWSBOAT_TTRSSAPI_H_
 #define NEWSBOAT_TTRSSAPI_H_
 
+#include <mutex>
+
 #include "3rd-party/json.hpp"
-#include "cache.h"
 #include "remoteapi.h"
 
 namespace rsspp {
@@ -11,24 +12,29 @@ class Feed;
 
 namespace newsboat {
 
+class CurlHandle;
+
 class TtRssApi : public RemoteApi {
 public:
-	explicit TtRssApi(ConfigContainer* c);
-	~TtRssApi() override;
+	explicit TtRssApi(ConfigContainer& c);
+	~TtRssApi() override = default;
 	bool authenticate() override;
 	virtual nlohmann::json run_op(const std::string& op,
 		const std::map<std::string, std::string>& args,
-		bool try_login = true,
-		CURL* cached_handle = nullptr);
+		bool try_login = true);
+	virtual nlohmann::json run_op(const std::string& op,
+		const std::map<std::string, std::string>& args,
+		CurlHandle& cached_handle,
+		bool try_login = true);
 	std::vector<TaggedFeedUrl> get_subscribed_urls() override;
 	void add_custom_headers(curl_slist** custom_headers) override;
-	bool mark_all_read(const std::string& feedurl) override;
+	bool mark_all_read(const std::string& feed_url) override;
 	bool mark_article_read(const std::string& guid, bool read) override;
 	bool update_article_flags(const std::string& oldflags,
 		const std::string& newflags,
 		const std::string& guid) override;
-	rsspp::Feed fetch_feed(const std::string& id, CURL* cached_handle);
-	bool update_article(const std::string& guid, int mode, int field);
+	rsspp::Feed fetch_feed(const std::string& id, CurlHandle& cached_handle);
+	bool update_article(const std::string& guid, int field, int mode);
 
 private:
 	void fetch_feeds_per_category(const nlohmann::json& cat,
