@@ -11,7 +11,7 @@ class TtRssUrlReader : public UrlReader {
 public:
 	TtRssUrlReader(const std::string& url_file, RemoteApi* a);
 	~TtRssUrlReader() override;
-	void reload() override;
+	nonstd::optional<utils::ReadTextFileError> reload() override;
 	std::string get_source() override;
 
 private:
