@@ -2,18 +2,18 @@
 #define NEWSBOAT_URLVIEWFORMACTION_H_
 
 #include "formaction.h"
-#include "htmlrenderer.h"
+#include "links.h"
 #include "listwidget.h"
 
 namespace newsboat {
 
 class UrlViewFormAction : public FormAction {
 public:
-	UrlViewFormAction(View*,
+	UrlViewFormAction(View&,
 		std::shared_ptr<RssFeed>& feed,
 		std::string formstr,
 		ConfigContainer* cfg);
-	~UrlViewFormAction() override;
+	~UrlViewFormAction() override = default;
 	void prepare() override;
 	void init() override;
 	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
