@@ -1,9 +1,12 @@
-#include <cstring>
-#include <errno.h>
+#include <algorithm>
+#include <cstddef>
 #include <iostream>
 #include <ncurses.h>
 #include <sstream>
+#include <string>
 #include <sys/utsname.h>
+#include <utility>
+#include <vector>
 
 #include "cache.h"
 #include "cliargsparser.h"
@@ -25,8 +28,7 @@ extern "C" {
 
 using namespace newsboat;
 
-void print_usage(const std::string& argv0, const std::string& config_path,
-	const std::string& urls_path, const std::string& cache_path)
+void print_usage(const std::string& argv0, const ConfigPaths& configpaths)
 {
 	auto msg = strprintf::fmt(
 			_("%s %s\nusage: %s [-i <file>|-e] [-u <urlfile>] "
@@ -51,20 +53,38 @@ void print_usage(const std::string& argv0, const std::string& config_path,
 		{
 			'u',
 			"url-file",
-			_s("<urlfile>"),
-			_s("read RSS feed URLs from <urlfile>")
+			_s("<file>"),
+			_s("read RSS feed URLs from <file>")
 		},
 		{
 			'c',
 			"cache-file",
-			_s("<cachefile>"),
-			_s("use <cachefile> as cache file")
+			_s("<file>"),
+			_s("use <file> as cache file")
 		},
 		{
 			'C',
 			"config-file",
-			_s("<configfile>"),
-			_s("read configuration from <configfile>")
+			_s("<file>"),
+			_s("read configuration from <file>")
+		},
+		{
+			'-',
+			"queue-file",
+			_s("<file>"),
+			_s("use <file> as podcast queue file")
+		},
+		{
+			'-',
+			"search-history-file",
+			_s("<file>"),
+			_s("save the input history of the search to <file>")
+		},
+		{
+			'-',
+			"cmdline-history-file",
+			_s("<file>"),
+			_s("save the input history of the command line to <file>")
 		},
 		{'X', "vacuum", "", _s("compact the cache")},
 		{
@@ -85,8 +105,8 @@ void print_usage(const std::string& argv0, const std::string& config_path,
 		{
 			'd',
 			"log-file",
-			_s("<logfile>"),
-			_s("use <logfile> as output log file")
+			_s("<file>"),
+			_s("use <file> as output log file")
 		},
 		{
 			'E',
@@ -104,7 +124,8 @@ void print_usage(const std::string& argv0, const std::string& config_path,
 		{'-', "cleanup", "", _s("remove unreferenced items from cache")}
 	};
 
-	std::stringstream ss;
+	std::vector<std::pair<std::string, std::string>> helpLines;
+	std::size_t maxLength = 0;
 	for (const auto& a : args) {
 		std::string longcolumn;
 		if (a.name != '-') {
@@ -116,15 +137,17 @@ void print_usage(const std::string& argv0, const std::string& config_path,
 		}
 		longcolumn += "--" + a.longname;
 		longcolumn += a.params.size() > 0 ? "=" + a.params : "";
-		ss << "\t" << longcolumn;
-		for (unsigned int j = 0; j < utils::gentabs(longcolumn); j++) {
-			ss << "\t";
-		}
-		ss << a.desc << std::endl;
-	}
-	std::cout << ss.str();
 
-	std::cout << '\n';
+		maxLength = std::max(maxLength, longcolumn.length());
+		helpLines.push_back({longcolumn, a.desc});
+	}
+	for (const auto& helpLine : helpLines) {
+		std::cout << std::string(8, ' ') << helpLine.first;
+		const auto padding = maxLength - helpLine.first.length();
+		std::cout << std::string(2 + padding, ' ') << helpLine.second;
+		std::cout << std::endl;
+	}
+	std::cout << std::endl;
 
 	std::cout << _("Files:") << '\n';
 	// i18n: This is printed out by --help before the path to the config file
@@ -133,7 +156,14 @@ void print_usage(const std::string& argv0, const std::string& config_path,
 	const std::string tr_urls = _("feed URLs");
 	// i18n This is printed out by --help before the path to the cache file
 	const std::string tr_cache = _("cache");
-	const auto widest = std::max({tr_config.length(), tr_urls.length(), tr_cache.length()});
+	// i18n: This is printed out by --help before the path to the queue file
+	const std::string tr_queue = _("podcast queue");
+	// i18n: This is printed out by --help before the path to the search history file
+	const std::string tr_search = _("search history");
+	// i18n: This is printed out by --help before the path to the cmdline history file
+	const std::string tr_cmdline = _("command line history");
+	const auto widest = std::max({tr_config.length(), tr_urls.length(), tr_cache.length(),
+				tr_search.length(), tr_cmdline.length(), tr_queue.length()});
 
 	const auto print_filepath = [widest](const std::string& name,
 	const std::string& value) {
@@ -141,9 +171,12 @@ void print_usage(const std::string& argv0, const std::string& config_path,
 				widest - name.length(), ' ') << value << '\n';
 	};
 
-	print_filepath(tr_config, config_path);
-	print_filepath(tr_urls, urls_path);
-	print_filepath(tr_cache, cache_path);
+	print_filepath(tr_config, configpaths.config_file());
+	print_filepath(tr_urls, configpaths.url_file());
+	print_filepath(tr_cache, configpaths.cache_file());
+	print_filepath(tr_queue, configpaths.queue_file());
+	print_filepath(tr_search, configpaths.search_history_file());
+	print_filepath(tr_cmdline, configpaths.cmdline_history_file());
 
 	std::cout << std::endl
 		<< _("Support at #newsboat at https://libera.chat or on our mailing "
@@ -161,11 +194,11 @@ void print_version(const std::string& argv0, unsigned int level)
 			<< PROGRAM_URL << std::endl;
 		ss << "Copyright (C) 2006-2015 Andreas Krennmair"
 			<< std::endl;
-		ss << "Copyright (C) 2015-2023 Alexander Batischev"
+		ss << "Copyright (C) 2015-2024 Alexander Batischev"
 			<< std::endl;
 		ss << "Copyright (C) 2006-2017 Newsbeuter contributors"
 			<< std::endl;
-		ss << "Copyright (C) 2017-2023 Newsboat contributors"
+		ss << "Copyright (C) 2017-2024 Newsboat contributors"
 			<< std::endl;
 		ss << std::endl;
 
@@ -243,8 +276,7 @@ int main(int argc, char* argv[])
 	configpaths.process_args(args);
 
 	if (args.should_print_usage()) {
-		print_usage(args.program_name(), configpaths.config_file(),
-			configpaths.url_file(), configpaths.cache_file());
+		print_usage(args.program_name(), configpaths);
 		if (args.return_code().has_value()) {
 			return args.return_code().value();
 		}
