@@ -7,6 +7,13 @@
 
 namespace rsspp {
 
+struct Enclosure {
+	std::string url;
+	std::string type;
+	std::string description;
+	std::string description_mime_type;
+};
+
 class Item {
 public:
 	Item()
@@ -19,7 +26,7 @@ public:
 	std::string title_type;
 	std::string link;
 	std::string description;
-	std::string description_type;
+	std::string description_mime_type;
 
 	std::string author;
 	std::string author_email;
@@ -28,8 +35,7 @@ public:
 	std::string guid;
 	bool guid_isPermaLink;
 
-	std::string enclosure_url;
-	std::string enclosure_type;
+	std::vector<Enclosure> enclosures;
 
 	// extensions:
 	std::string content_encoded;
