@@ -4,14 +4,14 @@
 #include <memory>
 #include <libxml/tree.h>
 
+#include "feed.h"
 #include "rssparser.h"
 
 namespace rsspp {
 
-class Feed;
-
 struct RssParserFactory {
-	static std::shared_ptr<RssParser> get_object(Feed& f, xmlDocPtr doc);
+	static std::shared_ptr<RssParser> get_object(Feed::Version rss_version,
+		xmlDocPtr doc);
 };
 
 } // namespace rsspp
