@@ -19,7 +19,6 @@ mod ffi {
         fn is_exec_url(url: &str) -> bool;
         fn is_valid_color(color: &str) -> bool;
         fn is_valid_attribute(attribute: &str) -> bool;
-        fn gentabs(string: &str) -> usize;
         fn run_command(cmd: &str, param: &str);
         fn strnaturalcmp(a: &str, b: &str) -> isize;
         fn strwidth(rs_str: &str) -> usize;
@@ -90,15 +89,6 @@ mod bridged {
         fn utf8_to_locale(text: &str) -> Vec<u8>;
         fn locale_to_utf8(text: &[u8]) -> String;
     }
-
-    extern "C++" {
-        // cxx uses `std::out_of_range`, but doesn't include the header that defines that
-        // exception. So we do it for them.
-        include!("stdexcept");
-        // Also inject a header that defines ptrdiff_t. Note this is *not* a C++ header, because
-        // cxx uses a non-C++ name of the type.
-        include!("stddef.h");
-    }
 }
 
 fn get_auth_method(method: &str) -> u64 {
@@ -166,6 +156,9 @@ fn read_text_file(
     }
 }
 
+// Temporarily ignore clippy lint until PR is merged:
+// https://github.com/rust-lang/rust-clippy/pull/12756
+#[allow(clippy::assigning_clones)]
 fn extract_token_quoted(line: &mut String, delimiters: &str, token: &mut String) -> bool {
     let (token_opt, remainder) = utils::extract_token_quoted(line, delimiters);
     *line = remainder.to_owned();
