@@ -9,14 +9,15 @@ pub mod logger;
 pub mod human_panic;
 pub mod utils;
 
+pub mod charencoding;
 pub mod cliargsparser;
 pub mod configpaths;
 pub mod filterparser;
 pub mod fmtstrformatter;
 pub mod fslock;
 pub mod history;
-pub mod htmlrenderer;
 pub mod keymap;
+pub mod links;
 pub mod matchable;
 pub mod matcher;
 pub mod matchererror;
