@@ -100,10 +100,10 @@ impl Operator {
 
 /// Convert numerical prefix of the string to i32.
 ///
-/// Return 0 if there is no numeric prefix. On underflow, return `std::i32::MIN`. On overflow,
-/// return `std::i32::MAX`.
+/// Return 0 if there is no numeric prefix. On underflow, return `i32::MIN`. On overflow,
+/// return `i32::MAX`.
 fn string_to_num(input: &str) -> i32 {
-    let search_start = if input.starts_with('-') { 1 } else { 0 };
+    let search_start = usize::from(input.starts_with('-'));
 
     let numerics_end = input[search_start..]
         .find(|c: char| !c.is_numeric())
@@ -119,10 +119,10 @@ fn string_to_num(input: &str) -> i32 {
         number
     } else if search_start == 1 {
         // Number starts with minus and couldn't be parsed => underflow
-        std::i32::MIN
+        i32::MIN
     } else {
         // Number doesn't start with minus and couldn't be parsed => overflow
-        std::i32::MAX
+        i32::MAX
     }
 }
 
