@@ -1,12 +1,11 @@
-#[macro_use]
-extern crate libnewsboat;
-extern crate tempfile;
-
-use self::tempfile::TempDir;
-use libnewsboat::logger::{self, get_instance, Level};
+use libnewsboat::{
+    log,
+    logger::{self, get_instance, Level},
+};
 use std::fs::File;
 use std::io::{BufRead, BufReader, Result};
 use std::path;
+use tempfile::TempDir;
 
 fn log_contains_n_lines(logfile: &path::Path, n: usize) -> Result<()> {
     let file = File::open(logfile)?;
