@@ -156,18 +156,18 @@ mod tests {
         assert_eq!(fmt!(&format!("%{PRIi32}"), 42i32), "42");
         assert_eq!(fmt!(&format!("%{PRId32}"), 42i32), "42");
 
-        assert_eq!(fmt!(&format!("%{PRIi32}"), std::i32::MIN), "-2147483648");
-        assert_eq!(fmt!(&format!("%{PRId32}"), std::i32::MIN), "-2147483648");
+        assert_eq!(fmt!(&format!("%{PRIi32}"), i32::MIN), "-2147483648");
+        assert_eq!(fmt!(&format!("%{PRId32}"), i32::MIN), "-2147483648");
 
-        assert_eq!(fmt!(&format!("%{PRIi32}"), std::i32::MAX), "2147483647");
-        assert_eq!(fmt!(&format!("%{PRId32}"), std::i32::MAX), "2147483647");
+        assert_eq!(fmt!(&format!("%{PRIi32}"), i32::MAX), "2147483647");
+        assert_eq!(fmt!(&format!("%{PRId32}"), i32::MAX), "2147483647");
     }
 
     #[test]
     fn formats_u32() {
         assert_eq!(fmt!(&format!("%{PRIu32}"), 42u32), "42");
         assert_eq!(fmt!(&format!("%{PRIu32}"), 0u32), "0");
-        assert_eq!(fmt!(&format!("%{PRIu32}"), std::u32::MAX), "4294967295");
+        assert_eq!(fmt!(&format!("%{PRIu32}"), u32::MAX), "4294967295");
     }
 
     #[test]
@@ -176,22 +176,16 @@ mod tests {
         assert_eq!(fmt!(&format!("%{PRId64}"), 42i64), "42");
 
         assert_eq!(
-            fmt!(&format!("%{PRIi64}"), std::i64::MIN),
+            fmt!(&format!("%{PRIi64}"), i64::MIN),
             "-9223372036854775808"
         );
         assert_eq!(
-            fmt!(&format!("%{PRId64}"), std::i64::MIN),
+            fmt!(&format!("%{PRId64}"), i64::MIN),
             "-9223372036854775808"
         );
 
-        assert_eq!(
-            fmt!(&format!("%{PRIi64}"), std::i64::MAX),
-            "9223372036854775807"
-        );
-        assert_eq!(
-            fmt!(&format!("%{PRId64}"), std::i64::MAX),
-            "9223372036854775807"
-        );
+        assert_eq!(fmt!(&format!("%{PRIi64}"), i64::MAX), "9223372036854775807");
+        assert_eq!(fmt!(&format!("%{PRId64}"), i64::MAX), "9223372036854775807");
     }
 
     #[test]
@@ -199,7 +193,7 @@ mod tests {
         assert_eq!(fmt!(&format!("%{PRIu64}"), 42u64), "42");
         assert_eq!(fmt!(&format!("%{PRIu64}"), 0u64), "0");
         assert_eq!(
-            fmt!(&format!("%{PRIu64}"), std::u64::MAX),
+            fmt!(&format!("%{PRIu64}"), u64::MAX),
             "18446744073709551615"
         );
     }
@@ -243,14 +237,14 @@ mod tests {
         assert_eq!(fmt!("%e", y), "4.200000e+04");
         assert_eq!(fmt!("%.3e", y), "4.200e+04");
 
-        assert_eq!(fmt!("%f", std::f32::INFINITY), "inf");
-        assert_eq!(fmt!("%F", std::f32::INFINITY), "INF");
+        assert_eq!(fmt!("%f", f32::INFINITY), "inf");
+        assert_eq!(fmt!("%F", f32::INFINITY), "INF");
 
-        assert_eq!(fmt!("%f", std::f32::NEG_INFINITY), "-inf");
-        assert_eq!(fmt!("%F", std::f32::NEG_INFINITY), "-INF");
+        assert_eq!(fmt!("%f", f32::NEG_INFINITY), "-inf");
+        assert_eq!(fmt!("%F", f32::NEG_INFINITY), "-INF");
 
-        assert_eq!(fmt!("%f", std::f32::NAN), "nan");
-        assert_eq!(fmt!("%F", std::f32::NAN), "NAN");
+        assert_eq!(fmt!("%f", f32::NAN), "nan");
+        assert_eq!(fmt!("%F", f32::NAN), "NAN");
     }
 
     #[test]
@@ -263,14 +257,14 @@ mod tests {
         assert_eq!(fmt!("%e", y), "4.200000e+139");
         assert_eq!(fmt!("%.3e", y), "4.200e+139");
 
-        assert_eq!(fmt!("%f", std::f64::INFINITY), "inf");
-        assert_eq!(fmt!("%F", std::f64::INFINITY), "INF");
+        assert_eq!(fmt!("%f", f64::INFINITY), "inf");
+        assert_eq!(fmt!("%F", f64::INFINITY), "INF");
 
-        assert_eq!(fmt!("%f", std::f64::NEG_INFINITY), "-inf");
-        assert_eq!(fmt!("%F", std::f64::NEG_INFINITY), "-INF");
+        assert_eq!(fmt!("%f", f64::NEG_INFINITY), "-inf");
+        assert_eq!(fmt!("%F", f64::NEG_INFINITY), "-INF");
 
-        assert_eq!(fmt!("%f", std::f64::NAN), "nan");
-        assert_eq!(fmt!("%F", std::f64::NAN), "NAN");
+        assert_eq!(fmt!("%f", f64::NAN), "nan");
+        assert_eq!(fmt!("%F", f64::NAN), "NAN");
     }
 
     #[test]
