@@ -2,21 +2,18 @@
 
 #include <cassert>
 #include <cinttypes>
-#include <cstdlib>
 #include <cstring>
-#include <fstream>
 #include <iostream>
 #include <sqlite3.h>
 #include <sstream>
 #include <time.h>
 
-#include "config.h"
 #include "configcontainer.h"
-#include "controller.h"
 #include "dbexception.h"
 #include "logger.h"
 #include "matcherexception.h"
 #include "rssfeed.h"
+#include "rssignores.h"
 #include "scopemeasure.h"
 #include "strprintf.h"
 #include "utils.h"
@@ -173,7 +170,7 @@ static int rssitem_callback(void* myfeed, int argc, char** argv,
 {
 	std::shared_ptr<RssFeed>* feed =
 		static_cast<std::shared_ptr<RssFeed>*>(myfeed);
-	assert(argc == 13);
+	assert(argc == 15);
 	std::shared_ptr<RssItem> item(new RssItem(nullptr));
 	item->set_guid(argv[0]);
 	item->set_title(argv[1]);
@@ -192,9 +189,11 @@ static int rssitem_callback(void* myfeed, int argc, char** argv,
 
 	item->set_enclosure_url(argv[8] ? argv[8] : "");
 	item->set_enclosure_type(argv[9] ? argv[9] : "");
-	item->set_enqueued((std::string("1") == (argv[10] ? argv[10] : "")));
-	item->set_flags(argv[11] ? argv[11] : "");
-	item->set_base(argv[12] ? argv[12] : "");
+	item->set_enclosure_description(argv[10] ? argv[10] : "");
+	item->set_enclosure_description_mime_type(argv[11] ? argv[11] : "");
+	item->set_enqueued((std::string("1") == (argv[12] ? argv[12] : "")));
+	item->set_flags(argv[13] ? argv[13] : "");
+	item->set_base(argv[14] ? argv[14] : "");
 
 	//(*feed)->items().push_back(item);
 	(*feed)->add_item(item);
@@ -223,7 +222,7 @@ static int search_item_callback(void* myfeed,
 {
 	std::vector<std::shared_ptr<RssItem>>* items =
 			static_cast<std::vector<std::shared_ptr<RssItem>>*>(myfeed);
-	assert(argc == 13);
+	assert(argc == 15);
 	std::shared_ptr<RssItem> item(new RssItem(nullptr));
 	item->set_guid(argv[0]);
 	item->set_title(argv[1]);
@@ -241,9 +240,11 @@ static int search_item_callback(void* myfeed,
 
 	item->set_enclosure_url(argv[8] ? argv[8] : "");
 	item->set_enclosure_type(argv[9] ? argv[9] : "");
-	item->set_enqueued((std::string("1") == argv[10]));
-	item->set_flags(argv[11] ? argv[11] : "");
-	item->set_base(argv[12] ? argv[12] : "");
+	item->set_enclosure_description(argv[10] ? argv[10] : "");
+	item->set_enclosure_description_mime_type(argv[11] ? argv[11] : "");
+	item->set_enqueued((std::string("1") == argv[12]));
+	item->set_flags(argv[13] ? argv[13] : "");
+	item->set_base(argv[14] ? argv[14] : "");
 
 	items->push_back(item);
 	return 0;
@@ -299,7 +300,7 @@ void Cache::set_pragmas()
 static const schema_patches schemaPatches{
 	{	{2, 10},
 		{
-			"CREATE TABLE rss_feed ( "
+			"CREATE TABLE rss_feed ( " // NOLINT(bugprone-suspicious-missing-comma)
 			" rssurl VARCHAR(1024) PRIMARY KEY NOT NULL, "
 			" url VARCHAR(1024) NOT NULL, "
 			" title VARCHAR(1024) NOT NULL ); ",
@@ -384,11 +385,15 @@ static const schema_patches schemaPatches{
 	},
 	{	{2, 22},
 		{
-			"UPDATE metadata SET db_schema_version_major = 2, db_schema_version_minor = 22;",
-
 			"ALTER TABLE rss_item ADD COLUMN content_mime_type VARCHAR(255) NOT NULL DEFAULT \"\";"
 		}
-	}
+	},
+	{	{2, 33},
+		{
+			"ALTER TABLE rss_item ADD COLUMN enclosure_description VARCHAR(1024) NOT NULL DEFAULT \"\";",
+			"ALTER TABLE rss_item ADD COLUMN enclosure_description_mime_type VARCHAR(128) NOT NULL DEFAULT \"\";",
+		}
+	},
 
 	// Note: schema changes should use the version number of the release that introduced them.
 };
@@ -424,6 +429,15 @@ void Cache::populate_tables()
 			"for version %u.%u",
 			patch_version.major,
 			patch_version.minor);
+
+		std::string update_metadata_query = "UPDATE metadata SET db_schema_version_major = " +
+			std::to_string(patch_version.major) + ", db_schema_version_minor = " +
+			std::to_string(patch_version.minor) + ";";
+
+		if (patch_version > SchemaVersion{2, 11}) {
+			run_sql_nothrow(update_metadata_query);
+		}
+
 		for (const auto& query : patches_it->second) {
 			run_sql_nothrow(query);
 		}
@@ -596,7 +610,8 @@ std::shared_ptr<RssFeed> Cache::internalize_rssfeed(std::string rssurl,
 	query = prepare_query(
 			"SELECT guid, title, author, url, pubDate, length(content), "
 			"unread, "
-			"feedurl, enclosure_url, enclosure_type, enqueued, flags, base "
+			"feedurl, enclosure_url, enclosure_type, enclosure_description, enclosure_description_mime_type, "
+			"enqueued, flags, base "
 			"FROM rss_item "
 			"WHERE feedurl = '%q' "
 			"AND deleted = 0 "
@@ -670,6 +685,7 @@ std::vector<std::shared_ptr<RssItem>> Cache::search_for_items(
 				"SELECT guid, title, author, url, pubDate, "
 				"length(content), "
 				"unread, feedurl, enclosure_url, enclosure_type, "
+				"enclosure_description, enclosure_description_mime_type, "
 				"enqueued, flags, base "
 				"FROM rss_item "
 				"WHERE (title LIKE '%%%q%%' OR content LIKE '%%%q%%') "
@@ -684,6 +700,7 @@ std::vector<std::shared_ptr<RssItem>> Cache::search_for_items(
 				"SELECT guid, title, author, url, pubDate, "
 				"length(content), "
 				"unread, feedurl, enclosure_url, enclosure_type, "
+				"enclosure_description, enclosure_description_mime_type, "
 				"enqueued, flags, base "
 				"FROM rss_item "
 				"WHERE (title LIKE '%%%q%%' OR content LIKE '%%%q%%') "
@@ -871,7 +888,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					"SET title = '%q', author = '%q', url = '%q', "
 					"feedurl = '%q', "
 					"content = '%q', content_mime_type = '%q', enclosure_url = '%q', "
-					"enclosure_type = '%q', base = '%q', unread = "
+					"enclosure_type = '%q', enclosure_description = '%q', "
+					"enclosure_description_mime_type = '%q', base = '%q', unread = "
 					"'%d' "
 					"WHERE guid = '%q'",
 					item->title(),
@@ -882,6 +900,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					description.mime,
 					item->enclosure_url(),
 					item->enclosure_type(),
+					item->enclosure_description(),
+					item->enclosure_description_mime_type(),
 					item->get_base(),
 					(item->unread() ? 1 : 0),
 					item->guid());
@@ -891,7 +911,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					"SET title = '%q', author = '%q', url = '%q', "
 					"feedurl = '%q', "
 					"content = '%q', content_mime_type = '%q', enclosure_url = '%q', "
-					"enclosure_type = '%q', base = '%q' "
+					"enclosure_type = '%q', enclosure_description = '%q', "
+					"enclosure_description_mime_type = '%q', base = '%q' "
 					"WHERE guid = '%q'",
 					item->title(),
 					item->author(),
@@ -901,6 +922,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					description.mime,
 					item->enclosure_url(),
 					item->enclosure_type(),
+					item->enclosure_description(),
+					item->enclosure_description_mime_type(),
 					item->get_base(),
 					item->guid());
 		}
@@ -910,11 +933,10 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 				"INSERT INTO rss_item (guid, title, author, url, "
 				"feedurl, "
 				"pubDate, content, content_mime_type, unread, enclosure_url, "
-				"enclosure_type, enqueued, base) "
+				"enclosure_type, enclosure_description, enclosure_description_mime_type, "
+				"enqueued, base) "
 				"VALUES "
-				"('%q','%q','%q','%q','%q','%u','%q','%q','%d','%q','%q',%d,"
-				" "
-				"'%q')",
+				"('%q','%q','%q','%q','%q','%u','%q','%q','%d','%q','%q','%q','%q',%d, '%q')",
 				item->guid(),
 				item->title(),
 				item->author(),
@@ -926,6 +948,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 				(item->unread() ? 1 : 0),
 				item->enclosure_url(),
 				item->enclosure_type(),
+				item->enclosure_description(),
+				item->enclosure_description_mime_type(),
 				item->enqueued() ? 1 : 0,
 				item->get_base());
 		run_sql(insert);
