@@ -1,10 +1,7 @@
 #include "cliargsparser.h"
 
-#include <cstdlib>
-
 namespace newsboat {
 
-
 rust::Vec<cliargsparser::bridged::BytesVec> argv_to_rust_args(int argc, char* argv[])
 {
 	rust::Vec<cliargsparser::bridged::BytesVec> args;
@@ -154,6 +151,33 @@ nonstd::optional<std::string> CliArgsParser::config_file() const
 	return nonstd::nullopt;
 }
 
+nonstd::optional<std::string> CliArgsParser::queue_file() const
+{
+	rust::String path;
+	if (newsboat::cliargsparser::bridged::queue_file(*rs_object, path)) {
+		return std::string(path);
+	}
+	return nonstd::nullopt;
+}
+
+nonstd::optional<std::string> CliArgsParser::search_history_file() const
+{
+	rust::String path;
+	if (newsboat::cliargsparser::bridged::search_history_file(*rs_object, path)) {
+		return std::string(path);
+	}
+	return nonstd::nullopt;
+}
+
+nonstd::optional<std::string> CliArgsParser::cmdline_history_file() const
+{
+	rust::String path;
+	if (newsboat::cliargsparser::bridged::cmdline_history_file(*rs_object, path)) {
+		return std::string(path);
+	}
+	return nonstd::nullopt;
+}
+
 std::vector<std::string> CliArgsParser::cmds_to_execute()
 const
 {
@@ -191,4 +215,3 @@ const cliargsparser::bridged::CliArgsParser& CliArgsParser::get_rust_ref() const
 }
 
 } // namespace newsboat
-
