@@ -85,6 +85,12 @@ ConfigContainer::ConfigContainer()
 	{
 		"feedhq-url",
 		ConfigData("https://feedhq.org/", ConfigDataType::STR)},
+	{"feedbin-url", ConfigData("https://api.feedbin.com", ConfigDataType::STR)},
+	{"feedbin-login", ConfigData("", ConfigDataType::STR)},
+	{"feedbin-password", ConfigData("", ConfigDataType::STR)},
+	{"feedbin-passwordfile", ConfigData("", ConfigDataType::PATH)},
+	{"feedbin-passwordeval", ConfigData("", ConfigDataType::STR)},
+	{"feedbin-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"freshrss-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"freshrss-login", ConfigData("", ConfigDataType::STR)},
 	{"freshrss-min-items", ConfigData("20", ConfigDataType::INT)},
@@ -261,11 +267,15 @@ ConfigContainer::ConfigContainer()
 	{"ocnews-passwordeval", ConfigData("", ConfigDataType::STR)},
 	{"ocnews-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"ocnews-url", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-login", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-min-items", ConfigData("100", ConfigDataType::INT)},
 	{"miniflux-password", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-passwordfile", ConfigData("", ConfigDataType::PATH)},
 	{"miniflux-passwordeval", ConfigData("", ConfigDataType::STR)},
+	{
+		"miniflux-show-special-feeds",
+		ConfigData("yes", ConfigDataType::BOOL)},
 	{"miniflux-token", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-tokenfile", ConfigData("", ConfigDataType::PATH)},
 	{"miniflux-tokeneval", ConfigData("", ConfigDataType::STR)},
@@ -279,6 +289,7 @@ ConfigContainer::ConfigContainer()
 			"ttrss",
 			"newsblur",
 			"feedhq",
+			"feedbin",
 			"freshrss",
 			"ocnews",
 			"miniflux",
