@@ -7,7 +7,6 @@
 #include <ctime>
 #include <curl/curl.h>
 #include <fstream>
-#include <functional>
 #include <iostream>
 #include <langinfo.h>
 #include <libgen.h>
@@ -15,7 +14,7 @@
 #include <libxml/tree.h>
 #include <libxml/xmlsave.h>
 #include <libxml/xmlversion.h>
-#include <mutex>
+#include <memory>
 #include <pwd.h>
 #include <signal.h>
 #include <sys/stat.h>
@@ -35,6 +34,8 @@
 #include "feedhqapi.h"
 #include "feedhqurlreader.h"
 #include "formaction.h"
+#include "feedbinapi.h"
+#include "feedbinurlreader.h"
 #include "freshrssapi.h"
 #include "freshrssurlreader.h"
 #include "fileurlreader.h"
@@ -50,6 +51,7 @@
 #include "ocnewsurlreader.h"
 #include "oldreaderapi.h"
 #include "oldreaderurlreader.h"
+#include "opml.h"
 #include "opmlurlreader.h"
 #include "regexmanager.h"
 #include "remoteapi.h"
@@ -248,8 +250,7 @@ int Controller::run(const CliArgsParser& args)
 		std::cout << _("done.") << std::endl;
 	}
 
-	reloader =
-		std::unique_ptr<Reloader>(new Reloader(this, rsscache, cfg));
+	reloader = std::make_unique<Reloader>(this, rsscache, cfg);
 
 	std::string type = cfg.get_configvalue("urls-source");
 	if (type == "local") {
@@ -285,6 +286,23 @@ int Controller::run(const CliArgsParser& args)
 	} else if (type == "feedhq") {
 		api = new FeedHqApi(cfg);
 		urlcfg = new FeedHqUrlReader(&cfg, configpaths.url_file(), api);
+	} else if (type == "feedbin") {
+		const std::string user = cfg.get_configvalue("feedbin-login");
+		const std::string pass = cfg.get_configvalue("feedbin-password");
+		const std::string pass_file = cfg.get_configvalue("feedbin-passwordfile");
+		const std::string pass_eval = cfg.get_configvalue("feedbin-passwordeval");
+		const bool creds_set = !user.empty() &&
+			(!pass.empty() || !pass_file.empty() || !pass_eval.empty());
+		if (!creds_set) {
+			std::cerr <<
+				_("ERROR: You must set `feedbin-login` and one of `feedbin-password`, "
+					"`feedbin-passwordfile` or `feedbin-passwordeval` to use "
+					"Feedbin\n");
+			return EXIT_FAILURE;
+		}
+
+		api = new FeedbinApi(cfg);
+		urlcfg = new FeedbinUrlReader(configpaths.url_file(), api);
 	} else if (type == "freshrss") {
 		const auto freshrss_url = cfg.get_configvalue("freshrss-url");
 		if (freshrss_url.empty()) {
@@ -338,7 +356,7 @@ int Controller::run(const CliArgsParser& args)
 		}
 
 		api = new MinifluxApi(cfg);
-		urlcfg = new MinifluxUrlReader(configpaths.url_file(), api);
+		urlcfg = new MinifluxUrlReader(&cfg, configpaths.url_file(), api);
 	} else if (type == "inoreader") {
 		const auto all_set = !cfg.get_configvalue("inoreader-app-id").empty()
 			&& !cfg.get_configvalue("inoreader-app-key").empty();
@@ -413,6 +431,11 @@ int Controller::run(const CliArgsParser& args)
 					_("It looks like you haven't configured any "
 						"feeds in your Miniflux account. Please do "
 						"so, and try again."));
+		} else if (type == "feedbin") {
+			msg = strprintf::fmt(
+					_("It looks like you haven't configured any "
+						"feeds in your Feedbin account. Please do "
+						"so, and try again."));
 		} else if (type == "ocnews") {
 			msg = strprintf::fmt(
 					_("It looks like you haven't configured any feeds in your "
@@ -483,7 +506,6 @@ int Controller::run(const CliArgsParser& args)
 		return EXIT_SUCCESS;
 	}
 
-
 	// if configured, we fill all query feeds with some data; no need to
 	// sort it, it will be refilled when actually opening it.
 	if (cfg.get_configvalue_as_bool("prepopulate-query-feeds")) {
@@ -548,7 +570,7 @@ int Controller::run(const CliArgsParser& args)
 	}
 
 	FormAction::load_histories(
-		configpaths.search_file(), configpaths.cmdline_file());
+		configpaths.search_history_file(), configpaths.cmdline_history_file());
 
 	// run the View
 	int ret = v->run();
@@ -556,8 +578,8 @@ int Controller::run(const CliArgsParser& args)
 	unsigned int history_limit =
 		cfg.get_configvalue_as_int("history-limit");
 	LOG(Level::DEBUG, "Controller::run: history-limit = %u", history_limit);
-	FormAction::save_histories(configpaths.search_file(),
-		configpaths.cmdline_file(),
+	FormAction::save_histories(configpaths.search_history_file(),
+		configpaths.cmdline_history_file(),
 		history_limit);
 
 	if (!args.silent()) {
