@@ -2,10 +2,9 @@
 
 #include <algorithm>
 #include <cassert>
+#include <cstdint>
 #include <cstring>
 #include <langinfo.h>
-#include <numeric>
-#include <sstream>
 #include <string>
 
 #include "config.h"
@@ -24,13 +23,13 @@
 
 namespace newsboat {
 
-FeedListFormAction::FeedListFormAction(View* vv,
+FeedListFormAction::FeedListFormAction(View& vv,
 	std::string formstr,
 	Cache* cc,
 	FilterContainer& f,
 	ConfigContainer* cfg,
 	RegexManager& r)
-	: ListFormAction(vv, formstr, "feeds", cfg)
+	: ListFormAction(vv, "feedlist", formstr, "feeds", cfg, r)
 	, zero_feedpos(false)
 	, filter_active(false)
 	, filterpos(0)
@@ -51,10 +50,10 @@ void FeedListFormAction::init()
 
 	recalculate_widget_dimensions();
 
-	if (v->get_ctrl()->get_refresh_on_start()) {
-		v->get_ctrl()->get_reloader()->start_reload_all_thread();
+	if (v.get_ctrl()->get_refresh_on_start()) {
+		v.get_ctrl()->get_reloader()->start_reload_all_thread();
 	}
-	v->get_ctrl()->update_feedlist();
+	v.get_ctrl()->update_feedlist();
 
 	/*
 	 * This is kind of a hack.
@@ -62,80 +61,74 @@ void FeedListFormAction::init()
 	 * ReloadThread, which is responsible for regularly spawning
 	 * DownloadThreads.
 	 */
-	v->get_ctrl()->get_reloader()->spawn_reloadthread();
+	v.get_ctrl()->get_reloader()->spawn_reloadthread();
 }
 
-FeedListFormAction::~FeedListFormAction() {}
-
 void FeedListFormAction::prepare()
 {
 	const auto sort_strategy = cfg->get_feed_sort_strategy();
 	if (!old_sort_strategy || sort_strategy != *old_sort_strategy) {
-		v->get_ctrl()->get_feedcontainer()->sort_feeds(sort_strategy);
+		v.get_ctrl()->get_feedcontainer()->sort_feeds(sort_strategy);
 		old_sort_strategy = sort_strategy;
 		do_redraw = true;
 	}
 
 	if (do_redraw) {
 		LOG(Level::DEBUG, "FeedListFormAction::prepare: doing redraw");
-		v->get_ctrl()->update_feedlist();
+		v.get_ctrl()->update_feedlist();
 		set_pos();
 		do_redraw = false;
 	}
 }
 
 bool FeedListFormAction::process_operation(Operation op,
-	bool automatic,
-	std::vector<std::string>* args)
+	const std::vector<std::string>& args,
+	BindingType bindingType)
 {
 	unsigned int pos = 0;
 	if (visible_feeds.size() >= 1) {
 		const auto selected_pos = list.get_position();
 		pos = visible_feeds[selected_pos].second;
 	}
-	const std::string feedpos = std::to_string(pos);
 	bool quit = false;
 REDO:
 	switch (op) {
 	case OP_OPEN: {
 		if (f.get_focus() == "feeds") {
-			if (automatic && args->size() > 0) {
-				pos = utils::to_u((*args)[0]);
+			if (args.size() > 0) {
+				pos = utils::to_u(args.front());
 			}
 			LOG(Level::INFO,
-				"FeedListFormAction: opening feed at position "
-				"`%s'",
-				feedpos);
-			if (visible_feeds.size() > 0 && feedpos.length() > 0) {
-				v->push_itemlist(pos);
+				"FeedListFormAction: opening feed at position `%d'", pos);
+			if (visible_feeds.size() > 0) {
+				v.push_itemlist(pos);
 			} else {
 				// should not happen
-				v->get_statusline().show_error(_("No feed selected!"));
+				v.get_statusline().show_error(_("No feed selected!"));
 			}
 		}
 	}
 	break;
 	case OP_RELOAD: {
 		LOG(Level::INFO,
-			"FeedListFormAction: reloading feed at position `%s'",
-			feedpos);
-		if (visible_feeds.size() > 0 && feedpos.length() > 0) {
-			v->get_ctrl()->get_reloader()->reload(pos);
+			"FeedListFormAction: reloading feed at position `%d'", pos);
+		if (visible_feeds.size() > 0) {
+			v.get_ctrl()->get_reloader()->reload(pos);
 		} else {
-			v->get_statusline().show_error(
+			v.get_statusline().show_error(
 				_("No feed selected!")); // should not happen
 		}
 	}
 	break;
 	case OP_RELOADURLS:
-		v->get_ctrl()->reload_urls_file();
+		v.get_ctrl()->reload_urls_file();
 		break;
 	case OP_SORT: {
 		// i18n: This string is related to the letters in parentheses in the
 		// "Sort by (f)irsttag/..." and "Reverse Sort by
 		// (f)irsttag/..." messages
 		std::string input_options = _("ftauln");
-		char c = v->confirm(
+		char c = v.confirm(
 				_("Sort by "
 					"(f)irsttag/(t)itle/(a)rticlecount/"
 					"(u)nreadarticlecount/(l)astupdated/(n)one?"),
@@ -175,7 +168,7 @@ REDO:
 	break;
 	case OP_REVSORT: {
 		std::string input_options = _("ftauln");
-		char c = v->confirm(
+		char c = v.confirm(
 				_("Reverse Sort by "
 					"(f)irsttag/(t)itle/(a)rticlecount/"
 					"(u)nreadarticlecount/(l)astupdated/(n)one?"),
@@ -221,15 +214,13 @@ REDO:
 		return open_position_in_browser(pos, interactive);
 	}
 	case OP_OPENALLUNREADINBROWSER:
-		if (visible_feeds.size() > 0 && feedpos.length() > 0) {
+		if (visible_feeds.size() > 0) {
 			std::shared_ptr<RssFeed> feed =
-				v->get_ctrl()->get_feedcontainer()->get_feed(pos);
+				v.get_ctrl()->get_feedcontainer()->get_feed(pos);
 			if (feed) {
 				LOG(Level::INFO,
-					"FeedListFormAction: opening all "
-					"unread "
-					"items in feed at position `%s'",
-					feedpos.c_str());
+					"FeedListFormAction: opening all unread items in feed at position `%d'",
+					pos);
 
 				// We can't just `const auto exit_code = ...` here because this
 				// triggers -Wmaybe-initialized in GCC 9 with -O2.
@@ -237,29 +228,26 @@ REDO:
 				exit_code = open_unread_items_in_browser(feed, false);
 
 				if (!exit_code.has_value()) {
-					v->get_statusline().show_error(_("Failed to spawn browser"));
+					v.get_statusline().show_error(_("Failed to spawn browser"));
 					return false;
 				} else if (*exit_code != 0) {
-					v->get_statusline().show_error(strprintf::fmt(_("Browser returned error code %i"),
+					v.get_statusline().show_error(strprintf::fmt(_("Browser returned error code %i"),
 							*exit_code));
 					return false;
 				}
 			}
 		} else {
-			v->get_statusline().show_error(_("No feed selected!"));
+			v.get_statusline().show_error(_("No feed selected!"));
 		}
 		break;
 	case OP_OPENALLUNREADINBROWSER_AND_MARK:
-		if (visible_feeds.size() > 0 && feedpos.length() > 0) {
+		if (visible_feeds.size() > 0) {
 			std::shared_ptr<RssFeed> feed =
-				v->get_ctrl()->get_feedcontainer()->get_feed(pos);
+				v.get_ctrl()->get_feedcontainer()->get_feed(pos);
 			if (feed) {
 				LOG(Level::INFO,
-					"FeedListFormAction: opening all "
-					"unread "
-					"items in feed at position `%s' and "
-					"marking read",
-					feedpos.c_str());
+					"FeedListFormAction: opening all unread items in feed at position `%d' and marking read",
+					pos);
 
 				// We can't just `const auto exit_code = ...` here because this
 				// triggers -Wmaybe-initialized in GCC 9 with -O2.
@@ -267,10 +255,10 @@ REDO:
 				exit_code = open_unread_items_in_browser(feed, true);
 
 				if (!exit_code.has_value()) {
-					v->get_statusline().show_error(_("Failed to spawn browser"));
+					v.get_statusline().show_error(_("Failed to spawn browser"));
 					return false;
 				} else if (*exit_code != 0) {
-					v->get_statusline().show_error(strprintf::fmt(_("Browser returned error code %i"),
+					v.get_statusline().show_error(strprintf::fmt(_("Browser returned error code %i"),
 							*exit_code));
 					return false;
 				}
@@ -296,24 +284,21 @@ REDO:
 					idxs.push_back(feed.second);
 				}
 			}
-			v->get_ctrl()->get_reloader()->start_reload_all_thread(idxs);
+			v.get_ctrl()->get_reloader()->start_reload_all_thread(idxs);
 		}
 		break;
 	case OP_MARKFEEDREAD: {
 		if (!cfg->get_configvalue_as_bool(
 				"confirm-mark-feed-read") ||
-			v->confirm(_("Do you really want to mark this feed as read (y:Yes n:No)? "),
+			v.confirm(_("Do you really want to mark this feed as read (y:Yes n:No)? "),
 				_("yn")) == *_("y")) {
-			LOG(Level::INFO,
-				"FeedListFormAction: marking feed read at position "
-				"`%s'",
-				feedpos);
-			if (visible_feeds.size() > 0 && feedpos.length() > 0) {
+			LOG(Level::INFO, "FeedListFormAction: marking feed read at position `%d'", pos);
+			if (visible_feeds.size() > 0) {
 				try {
 					{
-						const auto message_lifetime = v->get_statusline().show_message_until_finished(
+						const auto message_lifetime = v.get_statusline().show_message_until_finished(
 								_("Marking feed read..."));
-						v->get_ctrl()->mark_all_read(pos);
+						v.get_ctrl()->mark_all_read(pos);
 						do_redraw = true;
 					}
 					bool show_read = cfg->get_configvalue_as_bool("show-read-feeds");
@@ -321,12 +306,12 @@ REDO:
 						list.set_position(list.get_position() + 1);
 					}
 				} catch (const DbException& e) {
-					v->get_statusline().show_error(strprintf::fmt(
+					v.get_statusline().show_error(strprintf::fmt(
 							_("Error: couldn't mark feed read: %s"),
 							e.what()));
 				}
 			} else {
-				v->get_statusline().show_error(
+				v.get_statusline().show_error(
 					_("No feed selected!")); // should not happen
 			}
 		}
@@ -348,7 +333,7 @@ REDO:
 		LOG(Level::INFO,
 			"FeedListFormAction: jumping to next unread feed");
 		if (!jump_to_next_unread_feed(local_tmp)) {
-			v->get_statusline().show_error(_("No feeds with unread items."));
+			v.get_statusline().show_error(_("No feeds with unread items."));
 		}
 	}
 	break;
@@ -357,7 +342,7 @@ REDO:
 		LOG(Level::INFO,
 			"FeedListFormAction: jumping to previous unread feed");
 		if (!jump_to_previous_unread_feed(local_tmp)) {
-			v->get_statusline().show_error(_("No feeds with unread items."));
+			v.get_statusline().show_error(_("No feeds with unread items."));
 		}
 	}
 	break;
@@ -365,7 +350,7 @@ REDO:
 		unsigned int local_tmp;
 		LOG(Level::INFO, "FeedListFormAction: jumping to next feed");
 		if (!jump_to_next_feed(local_tmp)) {
-			v->get_statusline().show_error(_("Already on last feed."));
+			v.get_statusline().show_error(_("Already on last feed."));
 		}
 	}
 	break;
@@ -374,7 +359,7 @@ REDO:
 		LOG(Level::INFO,
 			"FeedListFormAction: jumping to previous feed");
 		if (!jump_to_previous_feed(local_tmp)) {
-			v->get_statusline().show_error(_("Already on first feed."));
+			v.get_statusline().show_error(_("Already on first feed."));
 		}
 	}
 	break;
@@ -383,27 +368,27 @@ REDO:
 		LOG(Level::INFO,
 			"FeedListFormAction: jumping to random unread feed");
 		if (!jump_to_random_unread_feed(local_tmp)) {
-			v->get_statusline().show_error(_("No feeds with unread items."));
+			v.get_statusline().show_error(_("No feeds with unread items."));
 		}
 	}
 	break;
 	case OP_MARKALLFEEDSREAD:
 		if (!cfg->get_configvalue_as_bool(
 				"confirm-mark-all-feeds-read") ||
-			v->confirm(_("Do you really want to mark all feeds as read (y:Yes n:No)? "),
+			v.confirm(_("Do you really want to mark all feeds as read (y:Yes n:No)? "),
 				_("yn")) == *_("y")) {
 			LOG(Level::INFO, "FeedListFormAction: marking all feeds read");
-			const auto message_lifetime = v->get_statusline().show_message_until_finished(
+			const auto message_lifetime = v.get_statusline().show_message_until_finished(
 					_("Marking all feeds read..."));
 			if (tag == "") {
-				v->get_ctrl()->mark_all_read("");
+				v.get_ctrl()->mark_all_read("");
 			} else {
 				// we're in tag view, so let's only touch feeds that are
 				// visible
 				for (const auto& feedptr_pos_pair : visible_feeds) {
 					auto rss_feed_ptr = feedptr_pos_pair.first;
 					auto feedurl = rss_feed_ptr->rssurl();
-					v->get_ctrl()->mark_all_read(feedurl);
+					v.get_ctrl()->mark_all_read(feedurl);
 				}
 			}
 			do_redraw = true;
@@ -416,10 +401,10 @@ REDO:
 		break;
 	case OP_SETTAG: {
 		std::string newtag;
-		if (automatic && args->size() > 0) {
-			newtag = (*args)[0];
+		if (args.size() > 0) {
+			newtag = args.front();
 		} else {
-			newtag = v->select_tag(tag);
+			newtag = v.select_tag(tag);
 		}
 		if (newtag != "") {
 			tag = newtag;
@@ -430,32 +415,32 @@ REDO:
 	break;
 	case OP_SELECTFILTER:
 		if (filter_container.size() > 0) {
-			if (automatic && args->size() > 0) {
-				const std::string filter_name = (*args)[0];
+			if (args.size() > 0) {
+				const std::string filter_name = args.front();
 				const auto filter = filter_container.get_filter(filter_name);
 
 				if (filter.has_value()) {
 					apply_filter(filter.value());
 				} else {
-					v->get_statusline().show_error(strprintf::fmt(_("No filter found with name `%s'."),
+					v.get_statusline().show_error(strprintf::fmt(_("No filter found with name `%s'."),
 							filter_name));
 				}
 			} else {
-				const std::string filter_text = v->select_filter(filter_container.get_filters());
+				const std::string filter_text = v.select_filter(filter_container.get_filters());
 				apply_filter(filter_text);
 			}
 		} else {
-			v->get_statusline().show_error(_("No filters defined."));
+			v.get_statusline().show_error(_("No filters defined."));
 		}
 		break;
 	case OP_SEARCH:
-		if (automatic && args->size() > 0) {
+		if (args.size() > 0) {
 			qna_responses.clear();
-			// when in automatic mode, we manually fill the
+			// If arguments are specified, we manually fill the
 			// qna_responses vector from the arguments and then run
 			// the finished_qna() by ourselves to simulate a "Q&A"
 			// session that is in fact macro-driven.
-			qna_responses.push_back((*args)[0]);
+			qna_responses.push_back(args.front());
 			finished_qna(OP_INT_START_SEARCH);
 		} else {
 			std::vector<QnaPair> qna;
@@ -465,15 +450,29 @@ REDO:
 		}
 		break;
 	case OP_GOTO_TITLE:
-		if (automatic) {
-			if (args->size() >= 1) {
+		switch (bindingType) {
+		case BindingType::Bind:
+			if (args.empty()) {
+				std::vector<QnaPair> qna {
+					QnaPair(_("Title: "), "")
+				};
+				this->start_qna(qna, OP_INT_GOTO_TITLE);
+			} else {
 				qna_responses = {args[0]};
 				finished_qna(OP_INT_GOTO_TITLE);
 			}
-		} else {
+			break;
+		case BindingType::Macro:
+			if (args.size() >= 1) {
+				qna_responses = {args[0]};
+				finished_qna(OP_INT_GOTO_TITLE);
+			}
+			break;
+		case BindingType::BindKey:
 			std::vector<QnaPair> qna;
 			qna.push_back(QnaPair(_("Title: "), ""));
 			this->start_qna(qna, OP_INT_GOTO_TITLE);
+			break;
 		}
 		break;
 	case OP_CLEARFILTER:
@@ -482,9 +481,9 @@ REDO:
 		save_filterpos();
 		break;
 	case OP_SETFILTER:
-		if (automatic && args->size() > 0) {
+		if (args.size() > 0) {
 			qna_responses.clear();
-			qna_responses.push_back((*args)[0]);
+			qna_responses.push_back(args.front());
 			finished_qna(OP_INT_END_SETFILTER);
 		} else {
 			std::vector<QnaPair> qna;
@@ -494,7 +493,7 @@ REDO:
 		}
 		break;
 	case OP_EDIT_URLS:
-		v->get_ctrl()->edit_urls_file();
+		v.get_ctrl()->edit_urls_file();
 		break;
 	case OP_QUIT:
 		if (tag != "") {
@@ -502,9 +501,9 @@ REDO:
 			goto REDO;
 		}
 		LOG(Level::INFO, "FeedListFormAction: quitting");
-		if (automatic ||
+		if (bindingType == BindingType::Macro ||
 			!cfg->get_configvalue_as_bool("confirm-exit") ||
-			v->confirm(
+			v.confirm(
 				_("Do you really want to quit (y:Yes n:No)? "),
 				_("yn")) == *_("y")) {
 			quit = true;
@@ -515,15 +514,15 @@ REDO:
 		quit = true;
 		break;
 	case OP_HELP:
-		v->push_help();
+		v.push_help();
 		break;
 	default:
-		ListFormAction::process_operation(op, automatic, args);
+		ListFormAction::process_operation(op, args, bindingType);
 		break;
 	}
 	if (quit) {
-		while (v->formaction_stack_size() > 0) {
-			v->pop_current_formaction();
+		while (v.formaction_stack_size() > 0) {
+			v.pop_current_formaction();
 		}
 	}
 	return true;
@@ -533,19 +532,19 @@ bool FeedListFormAction::open_position_in_browser(unsigned int pos,
 	bool interactive) const
 {
 	if (visible_feeds.empty()) {
-		v->get_statusline().show_error(_("No feed selected!"));
+		v.get_statusline().show_error(_("No feed selected!"));
 		return false;
 	}
 
-	std::shared_ptr<RssFeed> feed = v->get_ctrl()->get_feedcontainer()->get_feed(
+	std::shared_ptr<RssFeed> feed = v.get_ctrl()->get_feedcontainer()->get_feed(
 			pos);
 	if (feed == nullptr) {
-		v->get_statusline().show_error(_("No feed selected!"));
+		v.get_statusline().show_error(_("No feed selected!"));
 		return false;
 	}
 
 	if (feed->is_query_feed()) {
-		v->get_statusline().show_error(_("Cannot open query feeds in the browser!"));
+		v.get_statusline().show_error(_("Cannot open query feeds in the browser!"));
 		return false;
 	}
 
@@ -574,12 +573,12 @@ bool FeedListFormAction::open_position_in_browser(unsigned int pos,
 
 	if (!url.empty()) {
 		const std::string feedurl = feed->rssurl();
-		const auto exit_code = v->open_in_browser(url, feedurl, type, feed->title(), interactive);
+		const auto exit_code = v.open_in_browser(url, feedurl, type, feed->title(), interactive);
 		if (!exit_code.has_value()) {
-			v->get_statusline().show_error(_("Failed to spawn browser"));
+			v.get_statusline().show_error(_("Failed to spawn browser"));
 			return false;
 		} else if (*exit_code != 0) {
-			v->get_statusline().show_error(strprintf::fmt(_("Browser returned error code %i"),
+			v.get_statusline().show_error(strprintf::fmt(_("Browser returned error code %i"),
 					*exit_code));
 			return false;
 		}
@@ -622,14 +621,16 @@ void FeedListFormAction::set_feedlist(
 
 	update_visible_feeds(feeds);
 
-	for (const auto& feed : visible_feeds) {
-		listfmt.add_line(format_line(feedlist_format,
-				feed.first,
-				feed.second,
-				width));
-	}
-
-	list.stfl_replace_lines(listfmt);
+	auto render_line = [this, feedlist_format](std::uint32_t line,
+	std::uint32_t width) -> StflRichText {
+		if (line >= visible_feeds.size())
+		{
+			return StflRichText::from_plaintext("ERROR");
+		}
+		auto& feed = visible_feeds[line];
+		return format_line(feedlist_format, feed.first, feed.second, width);
+	};
+	list.invalidate_list_content(visible_feeds.size(), render_line);
 
 	update_form_title(width);
 }
@@ -886,7 +887,7 @@ void FeedListFormAction::mark_pos_if_visible(unsigned int pos)
 {
 	ScopeMeasure m1("FeedListFormAction::mark_pos_if_visible");
 	unsigned int vpos = 0;
-	v->get_ctrl()->update_visible_feeds();
+	v.get_ctrl()->update_visible_feeds();
 	for (const auto& feed : visible_feeds) {
 		if (feed.second == pos) {
 			LOG(Level::DEBUG,
@@ -900,7 +901,7 @@ void FeedListFormAction::mark_pos_if_visible(unsigned int pos)
 		vpos++;
 	}
 	vpos = 0;
-	pos = v->get_ctrl()->get_feedcontainer()->get_pos_of_next_unread(pos);
+	pos = v.get_ctrl()->get_feedcontainer()->get_pos_of_next_unread(pos);
 	for (const auto& feed : visible_feeds) {
 		if (feed.second == pos) {
 			LOG(Level::DEBUG,
@@ -932,7 +933,7 @@ void FeedListFormAction::register_format_styles()
 			"style_focus[listfocus]:fg=yellow,bg=blue,attr=bold "
 			"pos[feeds_pos]:0 offset[feeds_offset]:0 %s richtext:1}",
 			attrstr);
-	list.stfl_replace_list(0, textview);
+	list.stfl_replace_list(textview);
 }
 
 void FeedListFormAction::update_form_title(unsigned int width)
@@ -949,7 +950,7 @@ void FeedListFormAction::update_form_title(unsigned int width)
 	fmt.register_fmt('t', std::to_string(visible_feeds.size()));
 	fmt.register_fmt('F', filter_active ? matcher.get_expression() : "");
 
-	set_value("head", fmt.do_format(title_format, width));
+	set_title(fmt.do_format(title_format, width));
 }
 
 unsigned int FeedListFormAction::count_unread_feeds()
@@ -985,16 +986,16 @@ void FeedListFormAction::op_start_search()
 		"`%s'",
 		searchphrase);
 	if (searchphrase.length() > 0) {
-		const auto message_lifetime = v->get_statusline().show_message_until_finished(
+		const auto message_lifetime = v.get_statusline().show_message_until_finished(
 				_("Searching..."));
 		searchhistory.add_line(searchphrase);
 		std::vector<std::shared_ptr<RssItem>> items;
 		try {
 			const auto utf8searchphrase = utils::locale_to_utf8(searchphrase);
-			items = v->get_ctrl()->search_for_items(
+			items = v.get_ctrl()->search_for_items(
 					utf8searchphrase, nullptr);
 		} catch (const DbException& e) {
-			v->get_statusline().show_error(strprintf::fmt(
+			v.get_statusline().show_error(strprintf::fmt(
 					_("Error while searching for `%s': %s"),
 					searchphrase,
 					e.what()));
@@ -1004,9 +1005,9 @@ void FeedListFormAction::op_start_search()
 			std::shared_ptr<RssFeed> search_dummy_feed(new RssFeed(cache, ""));
 			search_dummy_feed->set_search_feed(true);
 			search_dummy_feed->add_items(items);
-			v->push_searchresult(search_dummy_feed, searchphrase);
+			v.push_searchresult(search_dummy_feed, searchphrase);
 		} else {
-			v->get_statusline().show_error(_("No results."));
+			v.get_statusline().show_error(_("No results."));
 		}
 	}
 }
@@ -1017,12 +1018,12 @@ void FeedListFormAction::handle_cmdline_num(unsigned int idx)
 		idx <= (visible_feeds[visible_feeds.size() - 1].second + 1)) {
 		int i = get_pos(idx - 1);
 		if (i == -1) {
-			v->get_statusline().show_error(_("Position not visible!"));
+			v.get_statusline().show_error(_("Position not visible!"));
 		} else {
 			list.set_position(i);
 		}
 	} else {
-		v->get_statusline().show_error(_("Invalid position!"));
+		v.get_statusline().show_error(_("Invalid position!"));
 	}
 }
 
@@ -1058,7 +1059,7 @@ std::string FeedListFormAction::get_title(std::shared_ptr<RssFeed> feed)
 	return title;
 }
 
-std::string FeedListFormAction::format_line(const std::string& feedlist_format,
+StflRichText FeedListFormAction::format_line(const std::string& feedlist_format,
 	std::shared_ptr<RssFeed> feed,
 	unsigned int pos,
 	unsigned int width)
@@ -1081,19 +1082,20 @@ std::string FeedListFormAction::format_line(const std::string& feedlist_format,
 	fmt.register_fmt('L', utils::censor_url(feed->rssurl()));
 	fmt.register_fmt('d', utils::utf8_to_locale(feed->description()));
 
-	auto formattedLine = fmt.do_format(feedlist_format, width);
-	formattedLine = utils::quote_for_stfl(formattedLine);
+	const auto formattedLine = fmt.do_format(feedlist_format, width);
+	auto stflFormattedLine = StflRichText::from_plaintext(formattedLine);
+
+	if (unread_count > 0) {
+		stflFormattedLine.apply_style_tag("<unread>", 0, formattedLine.length());
+	}
 
 	const int id = rxman.feed_matches(feed.get());
 	if (id != -1) {
-		formattedLine = strprintf::fmt("<%d>%s</>", id, formattedLine);
+		const auto tag = strprintf::fmt("<%d>", id);
+		stflFormattedLine.apply_style_tag(tag, 0, formattedLine.length());
 	}
 
-	if (unread_count > 0) {
-		formattedLine = strprintf::fmt("<unread>%s</>", formattedLine);
-	}
-
-	return formattedLine;
+	return stflFormattedLine;
 }
 
 std::string FeedListFormAction::title()
@@ -1111,7 +1113,7 @@ void FeedListFormAction::apply_filter(const std::string& filtertext)
 
 	filterhistory.add_line(filtertext);
 	if (!matcher.parse(filtertext)) {
-		v->get_statusline().show_error(strprintf::fmt(
+		v.get_statusline().show_error(strprintf::fmt(
 				_("Error: couldn't parse filter expression `%s': %s"),
 				filtertext,
 				matcher.get_parse_error()));
