@@ -7,17 +7,13 @@
 #include <ncurses.h>
 #include <dirent.h>
 #include <grp.h>
-#include <iomanip>
-#include <iostream>
 #include <pwd.h>
-#include <sstream>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
 
 #include "config.h"
 #include "fmtstrformatter.h"
-#include "listformatter.h"
 #include "logger.h"
 #include "strprintf.h"
 #include "utils.h"
@@ -25,24 +21,17 @@
 
 namespace newsboat {
 
-FileBrowserFormAction::FileBrowserFormAction(View* vv,
+FileBrowserFormAction::FileBrowserFormAction(View& vv,
 	std::string formstr,
 	ConfigContainer* cfg)
 	: FormAction(vv, formstr, cfg)
+	, file_prompt_line(f, "fileprompt")
 	, quit(false)
 	, files_list("files", FormAction::f, cfg->get_configvalue_as_int("scrolloff"))
+	, view(vv)
 {
-	// In filebrowser, keyboard focus is at the input field, so user will be
-	// unable to use alphanumeric keys to confirm or quit the dialog (e.g. they
-	// can't quit with the default `q` bind).
-	KeyMap* keys = vv->get_keymap();
-	keys->set_key(OP_OPEN, "ENTER", id());
-	keys->set_key(OP_QUIT, "ESC", id());
-	vv->set_keymap(keys);
 }
 
-FileBrowserFormAction::~FileBrowserFormAction() {}
-
 bool FileBrowserFormAction::process_operation(Operation op,
 	const std::vector<std::string>& /* args */,
 	BindingType /*bindingType*/)
@@ -118,7 +107,7 @@ bool FileBrowserFormAction::process_operation(Operation op,
 				 */
 				if (::stat(fn.c_str(), &sbuf) != -1) {
 					f.set_focus("files");
-					if (v->confirm(
+					if (v.confirm(
 							strprintf::fmt(
 								_("Do you really want to overwrite `%s' "
 									"(y:Yes n:No)? "),
@@ -130,7 +119,7 @@ bool FileBrowserFormAction::process_operation(Operation op,
 				}
 				if (do_pop) {
 					curs_set(0);
-					v->pop_current_formaction();
+					v.pop_current_formaction();
 				}
 			}
 		}
@@ -203,13 +192,13 @@ bool FileBrowserFormAction::process_operation(Operation op,
 	case OP_QUIT:
 		LOG(Level::DEBUG, "view::filebrowser: quitting");
 		curs_set(0);
-		v->pop_current_formaction();
+		v.pop_current_formaction();
 		set_value("filenametext", "");
 		break;
 	case OP_HARDQUIT:
 		LOG(Level::DEBUG, "view::filebrowser: hard quitting");
-		while (v->formaction_stack_size() > 0) {
-			v->pop_current_formaction();
+		while (v.formaction_stack_size() > 0) {
+			v.pop_current_formaction();
 		}
 		set_value("filenametext", "");
 		break;
@@ -228,10 +217,8 @@ void FileBrowserFormAction::update_title(const std::string& working_directory)
 	fmt.register_fmt('V', utils::program_version());
 	fmt.register_fmt('f', working_directory);
 
-	const std::string title = fmt.do_format(
-			cfg->get_configvalue("filebrowser-title-format"), width);
-
-	set_value("head", title);
+	set_title(fmt.do_format(
+			cfg->get_configvalue("filebrowser-title-format"), width));
 }
 
 std::vector<std::string> get_sorted_filelist()
@@ -282,7 +269,7 @@ void FileBrowserFormAction::prepare()
 		}
 
 
-		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> std::string {
+		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> StflRichText {
 			(void)width;
 			return lines[line];
 		};
@@ -301,9 +288,17 @@ void FileBrowserFormAction::prepare()
 
 void FileBrowserFormAction::init()
 {
+	// In filebrowser, keyboard focus is at the input field, so user will be
+	// unable to use alphanumeric keys to confirm or quit the dialog (e.g. they
+	// can't quit with the default `q` bind).
+	KeyMap* keys = view.get_keymap();
+	keys->set_key(OP_OPEN, KeyCombination("ENTER"), id());
+	keys->set_key(OP_QUIT, KeyCombination("ESC"), id());
+	view.set_keymap(keys);
+
 	set_keymap_hints();
 
-	set_value("fileprompt", _("File: "));
+	file_prompt_line.set_text(_("File: "));
 
 	const std::string save_path = cfg->get_configvalue("save-path");
 
@@ -355,7 +350,7 @@ void FileBrowserFormAction::add_file(
 				group,
 				sizestr,
 				formattedfilename);
-		lines.push_back(utils::quote_for_stfl(line));
+		lines.push_back(StflRichText::from_plaintext(line));
 		id_at_position.push_back(file_system::FileSystemEntry{ftype, filename});
 	}
 }
