@@ -1,8 +1,6 @@
 #include "helpformaction.h"
 
-#include <algorithm>
 #include <cstring>
-#include <sstream>
 
 #include "config.h"
 #include "fmtstrformatter.h"
@@ -14,7 +12,7 @@
 
 namespace newsboat {
 
-HelpFormAction::HelpFormAction(View* vv,
+HelpFormAction::HelpFormAction(View& vv,
 	std::string formstr,
 	ConfigContainer* cfg,
 	const std::string& ctx)
@@ -26,38 +24,12 @@ HelpFormAction::HelpFormAction(View* vv,
 {
 }
 
-HelpFormAction::~HelpFormAction() {}
-
 bool HelpFormAction::process_operation(Operation op,
-	bool /* automatic */,
-	std::vector<std::string>* /* args */)
+	const std::vector<std::string>& /* args */,
+	BindingType /*bindingType*/)
 {
 	bool hardquit = false;
 	switch (op) {
-	case OP_SK_UP:
-		textview.scroll_up();
-		break;
-	case OP_SK_DOWN:
-		textview.scroll_down();
-		break;
-	case OP_SK_HOME:
-		textview.scroll_to_top();
-		break;
-	case OP_SK_END:
-		textview.scroll_to_bottom();
-		break;
-	case OP_SK_PGUP:
-		textview.scroll_page_up();
-		break;
-	case OP_SK_PGDOWN:
-		textview.scroll_page_down();
-		break;
-	case OP_SK_HALF_PAGE_UP:
-		textview.scroll_halfpage_up();
-		break;
-	case OP_SK_HALF_PAGE_DOWN:
-		textview.scroll_halfpage_down();
-		break;
 	case OP_QUIT:
 		quit = true;
 		break;
@@ -75,14 +47,17 @@ bool HelpFormAction::process_operation(Operation op,
 		do_redraw = true;
 		break;
 	default:
+		if (handle_textview_operations(textview, op)) {
+			break;
+		}
 		break;
 	}
 	if (hardquit) {
-		while (v->formaction_stack_size() > 0) {
-			v->pop_current_formaction();
+		while (v.formaction_stack_size() > 0) {
+			v.pop_current_formaction();
 		}
 	} else if (quit) {
-		v->pop_current_formaction();
+		v.pop_current_formaction();
 	}
 	return true;
 }
@@ -97,34 +72,37 @@ void HelpFormAction::prepare()
 		FmtStrFormatter fmt;
 		fmt.register_fmt('N', PROGRAM_NAME);
 		fmt.register_fmt('V', utils::program_version());
-		set_value("head",
-			fmt.do_format(cfg->get_configvalue("help-title-format"), width));
+		set_title(fmt.do_format(cfg->get_configvalue("help-title-format"), width));
 
-		const auto descs = v->get_keymap()->get_keymap_descriptions(context);
+		const auto descs = v.get_keymap()->get_keymap_descriptions(context);
 
-		std::string highlighted_searchphrase =
-			strprintf::fmt("<hl>%s</>", searchphrase);
 		std::vector<std::string> colors = utils::tokenize(
 				cfg->get_configvalue("search-highlight-colors"), " ");
 		set_value("highlight", make_colorstring(colors));
 		ListFormatter listfmt;
 
-		const unsigned int unbound_count = std::count_if(descs.begin(),
-		descs.end(), [](const KeyMapDesc& desc) {
-			return desc.key.length() == 0;
-		});
-		const unsigned int syskey_count = std::count_if(descs.begin(),
-		descs.end(), [](const KeyMapDesc& desc) {
-			return desc.flags & KM_SYSKEYS;
-		});
+		std::vector<KeyMapDesc> syskey_descriptions;
+		std::vector<KeyMapDesc> unbound_descriptions;
+		std::vector<KeyMapDesc> bound_descriptions;
+
+		for (const auto& desc : descs) {
+			if (desc.flags & KM_SYSKEYS) {
+				syskey_descriptions.push_back(desc);
+			} else if (desc.key.get_key().empty()) {
+				unbound_descriptions.push_back(desc);
+			} else {
+				bound_descriptions.push_back(desc);
+			}
+		}
 
 		const auto should_be_visible = [&](const KeyMapDesc& desc) {
 			return !apply_search
-				|| strcasestr(desc.key.c_str(), searchphrase.c_str()) != nullptr
+				|| strcasestr(desc.key.to_bindkey_string().c_str(), searchphrase.c_str()) != nullptr
 				|| strcasestr(desc.cmd.c_str(), searchphrase.c_str()) != nullptr
 				|| strcasestr(desc.desc.c_str(), searchphrase.c_str()) != nullptr;
 		};
 
+		std::string highlighted_searchphrase = strprintf::fmt("<hl>%s</>", searchphrase);
 		const auto apply_highlights = [&](const std::string& line) {
 			if (apply_search && searchphrase.length() > 0) {
 				return utils::replace_all(line, searchphrase, highlighted_searchphrase);
@@ -132,69 +110,66 @@ void HelpFormAction::prepare()
 			return line;
 		};
 
-		for (const auto& desc : descs) {
-			if (desc.key.length() == 0 || desc.flags & KM_SYSKEYS) {
-				continue;
-			}
+		for (const auto& desc : bound_descriptions) {
 			if (should_be_visible(desc)) {
-				auto line = strprintf::fmt("%-15s %-23s %s", desc.key, desc.cmd, desc.desc);
+				auto line = strprintf::fmt("%-15s %-23s %s",
+						desc.key.to_bindkey_string(),
+						desc.cmd,
+						desc.desc);
 				line = utils::quote_for_stfl(line);
 				line = apply_highlights(line);
-				listfmt.add_line(line);
+				listfmt.add_line(StflRichText::from_quoted(line));
 			}
 		}
 
-		if (syskey_count > 0) {
-			listfmt.add_line("");
-			listfmt.add_line(_("Generic bindings:"));
-			listfmt.add_line("");
+		if (!syskey_descriptions.empty()) {
+			listfmt.add_line(StflRichText::from_plaintext(""));
+			listfmt.add_line(StflRichText::from_plaintext(_("Generic bindings:")));
+			listfmt.add_line(StflRichText::from_plaintext(""));
 
-			for (const auto& desc : descs) {
-				if (!(desc.flags & KM_SYSKEYS)) {
-					continue;
-				}
+			for (const auto& desc : syskey_descriptions) {
 				if (should_be_visible(desc)) {
-					auto line = strprintf::fmt("%-15s %-23s %s", desc.key, desc.cmd, desc.desc);
+					auto line = strprintf::fmt("%-15s %-23s %s",
+							desc.key.to_bindkey_string(),
+							desc.cmd,
+							desc.desc);
 					line = utils::quote_for_stfl(line);
 					line = apply_highlights(line);
-					listfmt.add_line(line);
+					listfmt.add_line(StflRichText::from_quoted(line));
 				}
 			}
 		}
 
-		if (unbound_count > 0) {
-			listfmt.add_line("");
-			listfmt.add_line(_("Unbound functions:"));
-			listfmt.add_line("");
+		if (!unbound_descriptions.empty()) {
+			listfmt.add_line(StflRichText::from_plaintext(""));
+			listfmt.add_line(StflRichText::from_plaintext(_("Unbound functions:")));
+			listfmt.add_line(StflRichText::from_plaintext(""));
 
-			for (const auto& desc : descs) {
-				if (desc.key.length() > 0 || desc.flags & KM_SYSKEYS) {
-					continue;
-				}
+			for (const auto& desc : unbound_descriptions) {
 				if (should_be_visible(desc)) {
 					std::string line = strprintf::fmt("%-39s %s", desc.cmd, desc.desc);
 					line = utils::quote_for_stfl(line);
 					line = apply_highlights(line);
-					listfmt.add_line(line);
+					listfmt.add_line(StflRichText::from_quoted(line));
 				}
 			}
 		}
 
-		const auto macros = v->get_keymap()->get_macro_descriptions();
+		const auto macros = v.get_keymap()->get_macro_descriptions();
 		if (!macros.empty()) {
-			listfmt.add_line("");
-			listfmt.add_line(_("Macros:"));
-			listfmt.add_line("");
+			listfmt.add_line(StflRichText::from_plaintext(""));
+			listfmt.add_line(StflRichText::from_plaintext(_("Macros:")));
+			listfmt.add_line(StflRichText::from_plaintext(""));
 
 			for (const auto& macro : macros) {
-				const std::string key = macro.first;
+				const std::string key = macro.first.to_bindkey_string();
 				const std::string description = macro.second.description;
 
 				// "macro-prefix" is not translated because it refers to an operation name
 				std::string line = strprintf::fmt("<macro-prefix>%s  %s", key, description);
 				line = utils::quote_for_stfl(line);
 				line = apply_highlights(line);
-				listfmt.add_line(line);
+				listfmt.add_line(StflRichText::from_quoted(line));
 			}
 		}
 
@@ -221,7 +196,7 @@ const std::vector<KeyMapHintEntry>& HelpFormAction::get_keymap_hint() const
 
 void HelpFormAction::finished_qna(Operation op)
 {
-	v->inside_qna(false);
+	v.inside_qna(false);
 	switch (op) {
 	case OP_INT_START_SEARCH:
 		searchphrase = qna_responses[0];
