@@ -1,7 +1,5 @@
 #include "keymap.h"
 
-#include <algorithm>
-#include <iostream>
 #include <map>
 #include <string>
 #include <vector>
@@ -20,7 +18,7 @@ namespace newsboat {
 struct OpDesc {
 	const Operation op;
 	const std::string opstr;
-	const std::string default_key;
+	const KeyCombination default_key;
 	const std::string help_text;
 	const unsigned short flags;
 };
@@ -33,7 +31,7 @@ static const std::vector<OpDesc> opdescs = {
 	{
 		OP_OPEN,
 		"open",
-		"ENTER",
+		KeyCombination("ENTER"),
 		translatable("Open feed/article"),
 		KM_FEEDLIST | KM_FILEBROWSER | KM_ARTICLELIST | KM_TAGSELECT |
 		KM_FILTERSELECT | KM_URLVIEW | KM_DIALOGS | KM_DIRBROWSER | KM_SEARCHRESULTSLIST
@@ -41,102 +39,126 @@ static const std::vector<OpDesc> opdescs = {
 	{
 		OP_SWITCH_FOCUS,
 		"switch-focus",
-		"TAB",
+		KeyCombination("TAB"),
 		translatable("Switch focus between widgets"),
 		KM_FILEBROWSER | KM_DIRBROWSER
 	},
-	{OP_QUIT, "quit", "q", translatable("Return to previous dialog/Quit"), KM_BOTH},
+	{
+		OP_QUIT,
+		"quit",
+		KeyCombination("q"),
+		translatable("Return to previous dialog/Quit"),
+		KM_BOTH
+	},
 	{
 		OP_HARDQUIT,
 		"hard-quit",
-		"Q",
+		KeyCombination("q", ShiftState::Shift),
 		translatable("Quit program, no confirmation"),
 		KM_BOTH
 	},
 	{
 		OP_RELOAD,
 		"reload",
-		"r",
+		KeyCombination("r"),
 		translatable("Reload currently selected feed"),
 		KM_FEEDLIST | KM_ARTICLELIST
 	},
-	{OP_RELOADALL, "reload-all", "R", translatable("Reload all feeds"), KM_FEEDLIST},
+	{
+		OP_RELOADALL,
+		"reload-all",
+		KeyCombination("r", ShiftState::Shift),
+		translatable("Reload all feeds"),
+		KM_FEEDLIST
+	},
 	{
 		OP_MARKFEEDREAD,
 		"mark-feed-read",
-		"A",
+		KeyCombination("a", ShiftState::Shift),
 		translatable("Mark feed read"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_MARKALLFEEDSREAD,
 		"mark-all-feeds-read",
-		"C",
+		KeyCombination("c", ShiftState::Shift),
 		translatable("Mark all feeds read"),
 		KM_FEEDLIST
 	},
 	{
 		OP_MARKALLABOVEASREAD,
 		"mark-all-above-as-read",
-		"",
+		KeyCombination(""),
 		translatable("Mark all above as read"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
-	{OP_SAVE, "save", "s", translatable("Save article"), KM_ARTICLELIST | KM_ARTICLE | KM_SEARCHRESULTSLIST},
-	{OP_SAVEALL, "save-all", "", translatable("Save articles"), KM_ARTICLELIST | KM_SEARCHRESULTSLIST},
+	{
+		OP_SAVE,
+		"save",
+		KeyCombination("s"),
+		translatable("Save article"),
+		KM_ARTICLELIST | KM_ARTICLE | KM_SEARCHRESULTSLIST
+	},
+	{
+		OP_SAVEALL,
+		"save-all",
+		KeyCombination(""),
+		translatable("Save articles"),
+		KM_ARTICLELIST | KM_SEARCHRESULTSLIST
+	},
 	{
 		OP_NEXT,
 		"next",
-		"J",
+		KeyCombination("j", ShiftState::Shift),
 		translatable("Go to next entry"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_ARTICLE | KM_DIALOGS | KM_DIRBROWSER | KM_FILEBROWSER | KM_FILTERSELECT | KM_TAGSELECT | KM_URLVIEW | KM_SEARCHRESULTSLIST | KM_PODBOAT
 	},
 	{
 		OP_PREV,
 		"prev",
-		"K",
+		KeyCombination("k", ShiftState::Shift),
 		translatable("Go to previous entry"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_ARTICLE | KM_DIALOGS | KM_DIRBROWSER | KM_FILEBROWSER | KM_FILTERSELECT | KM_TAGSELECT | KM_URLVIEW | KM_SEARCHRESULTSLIST | KM_PODBOAT
 	},
 	{
 		OP_NEXTUNREAD,
 		"next-unread",
-		"n",
+		KeyCombination("n"),
 		translatable("Go to next unread article"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
 	},
 	{
 		OP_PREVUNREAD,
 		"prev-unread",
-		"p",
+		KeyCombination("p"),
 		translatable("Go to previous unread article"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
 	},
 	{
 		OP_RANDOMUNREAD,
 		"random-unread",
-		"^K",
+		KeyCombination("k", ShiftState::NoShift, ControlState::Control),
 		translatable("Go to a random unread article"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
 	},
 	{
 		OP_OPENBROWSER_AND_MARK,
 		"open-in-browser-and-mark-read",
-		"O",
+		KeyCombination("o", ShiftState::Shift),
 		translatable("Open URL of article, or entry in URL view. Mark read"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE | KM_URLVIEW
 	},
 	{
 		OP_OPENALLUNREADINBROWSER,
 		"open-all-unread-in-browser",
-		"",
+		KeyCombination(""),
 		translatable("Open all unread items of selected feed in browser"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_OPENALLUNREADINBROWSER_AND_MARK,
 		"open-all-unread-in-browser-and-mark-read",
-		"",
+		KeyCombination(""),
 		translatable("Open all unread items of selected feed in browser and mark "
 			"read"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
@@ -144,257 +166,329 @@ static const std::vector<OpDesc> opdescs = {
 	{
 		OP_OPENINBROWSER,
 		"open-in-browser",
-		"o",
+		KeyCombination("o"),
 		translatable("Open URL of article, feed, or entry in URL view"),
 		KM_FEEDLIST | KM_ARTICLELIST  | KM_SEARCHRESULTSLIST| KM_ARTICLE | KM_URLVIEW
 	},
 	{
 		OP_OPENINBROWSER_NONINTERACTIVE,
 		"open-in-browser-noninteractively",
-		"",
+		KeyCombination(""),
 		translatable("Open URL of article, feed, or entry in a browser, non-interactively"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE | KM_URLVIEW
 	},
 	{
 		OP_HELP,
 		"help",
-		"?",
+		KeyCombination("?"),
 		translatable("Open help dialog"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE | KM_PODBOAT | KM_URLVIEW
 	},
 	{
 		OP_TOGGLESOURCEVIEW,
 		"toggle-source-view",
-		"^U",
+		KeyCombination("u", ShiftState::NoShift, ControlState::Control),
 		translatable("Toggle source view"),
 		KM_ARTICLE
 	},
 	{
 		OP_TOGGLEITEMREAD,
 		"toggle-article-read",
-		"N",
+		KeyCombination("n", ShiftState::Shift),
 		translatable("Toggle read status for article"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
 	},
 	{
 		OP_TOGGLESHOWREAD,
 		"toggle-show-read-feeds",
-		"l",
+		KeyCombination("l"),
 		translatable("Toggle show read feeds/articles"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_SHOWURLS,
 		"show-urls",
-		"u",
+		KeyCombination("u"),
 		translatable("Show URLs in current article"),
 		KM_ARTICLE | KM_SEARCHRESULTSLIST | KM_ARTICLELIST
 	},
-	{OP_CLEARTAG, "clear-tag", "^T", translatable("Clear current tag"), KM_FEEDLIST},
-	{OP_SETTAG, "set-tag", "t", translatable("Select tag"), KM_FEEDLIST},
-	{OP_SETTAG, "select-tag", "t", translatable("Select tag"), KM_FEEDLIST},
+	{
+		OP_CLEARTAG,
+		"clear-tag",
+		KeyCombination("t", ShiftState::NoShift, ControlState::Control),
+		translatable("Clear current tag"),
+		KM_FEEDLIST
+	},
+	{
+		OP_SETTAG,
+		"set-tag",
+		KeyCombination("t"),
+		translatable("Select tag"),
+		KM_FEEDLIST
+	},
+	{
+		OP_SETTAG,
+		"select-tag",
+		KeyCombination("t"),
+		translatable("Select tag"),
+		KM_FEEDLIST
+	},
 	{
 		OP_SEARCH,
 		"open-search",
-		"/",
+		KeyCombination("/"),
 		translatable("Open search dialog"),
 		KM_FEEDLIST | KM_HELP | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
 	},
-	{OP_GOTO_URL, "goto-url", "#", translatable("Goto URL #"), KM_ARTICLE},
-	{OP_GOTO_TITLE, "goto-title", "", translatable("Goto item with title"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST},
-	{OP_ENQUEUE, "enqueue", "e", translatable("Add download to queue"), KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE},
+	{
+		OP_GOTO_URL,
+		"goto-url",
+		KeyCombination("#"),
+		translatable("Goto URL #"),
+		KM_ARTICLE
+	},
+	{
+		OP_GOTO_TITLE,
+		"goto-title",
+		KeyCombination(""),
+		translatable("Goto item with title"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
+	},
+	{
+		OP_ENQUEUE,
+		"enqueue",
+		KeyCombination("e"),
+		translatable("Add download to queue"),
+		KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
+	},
 	{
 		OP_RELOADURLS,
 		"reload-urls",
-		"^R",
+		KeyCombination("r", ShiftState::NoShift, ControlState::Control),
 		translatable("Reload the list of URLs from the configuration"),
 		KM_FEEDLIST
 	},
-	{OP_PB_DOWNLOAD, "pb-download", "d", translatable("Download file"), KM_PODBOAT},
-	{OP_PB_CANCEL, "pb-cancel", "c", translatable("Cancel download"), KM_PODBOAT},
+	{
+		OP_PB_DOWNLOAD,
+		"pb-download",
+		KeyCombination("d"),
+		translatable("Download file"),
+		KM_PODBOAT
+	},
+	{
+		OP_PB_CANCEL,
+		"pb-cancel",
+		KeyCombination("c"),
+		translatable("Cancel download"),
+		KM_PODBOAT
+	},
 	{
 		OP_PB_DELETE,
 		"pb-delete",
-		"D",
+		KeyCombination("d", ShiftState::Shift),
 		translatable("Mark download as deleted"),
 		KM_PODBOAT
 	},
 	{
 		OP_PB_PURGE,
 		"pb-purge",
-		"P",
+		KeyCombination("p", ShiftState::Shift),
 		translatable("Purge finished and deleted downloads from queue"),
 		KM_PODBOAT
 	},
 	{
 		OP_PB_TOGGLE_DLALL,
 		"pb-toggle-download-all",
-		"a",
+		KeyCombination("a"),
 		translatable("Toggle automatic download on/off"),
 		KM_PODBOAT
 	},
 	{
 		OP_PB_PLAY,
 		"pb-play",
-		"p",
+		KeyCombination("p"),
 		translatable("Start player with currently selected download"),
 		KM_PODBOAT
 	},
 	{
 		OP_PB_MARK_FINISHED,
 		"pb-mark-as-finished",
-		"m",
+		KeyCombination("m"),
 		translatable("Mark file as finished (not played)"),
 		KM_PODBOAT
 	},
 	{
 		OP_PB_MOREDL,
 		"pb-increase-max-dls",
-		"+",
+		KeyCombination("+"),
 		translatable("Increase the number of concurrent downloads"),
 		KM_PODBOAT
 	},
 	{
 		OP_PB_LESSDL,
 		"pb-decreate-max-dls",
-		"-",
+		KeyCombination("-"),
 		translatable("Decrease the number of concurrent downloads"),
 		KM_PODBOAT
 	},
-	{OP_REDRAW, "redraw", "^L", translatable("Redraw screen"), KM_SYSKEYS},
-	{OP_CMDLINE, "cmdline", ":", translatable("Open the commandline"), KM_NEWSBOAT},
+	{
+		OP_REDRAW,
+		"redraw",
+		KeyCombination("l", ShiftState::NoShift, ControlState::Control),
+		translatable("Redraw screen"),
+		KM_SYSKEYS
+	},
+	{
+		OP_CMDLINE,
+		"cmdline",
+		KeyCombination(":"),
+		translatable("Open the commandline"),
+		KM_NEWSBOAT
+	},
 	{
 		OP_SETFILTER,
 		"set-filter",
-		"F",
+		KeyCombination("f", ShiftState::Shift),
 		translatable("Set a filter"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_SELECTFILTER,
 		"select-filter",
-		"f",
+		KeyCombination("f"),
 		translatable("Select a predefined filter"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_CLEARFILTER,
 		"clear-filter",
-		"^F",
+		KeyCombination("f", ShiftState::NoShift, ControlState::Control),
 		translatable("Clear currently set filter"),
 		KM_FEEDLIST | KM_HELP | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_BOOKMARK,
 		"bookmark",
-		"^B",
+		KeyCombination("b", ShiftState::NoShift, ControlState::Control),
 		translatable("Bookmark current link/article"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE | KM_URLVIEW
 	},
 	{
 		OP_EDITFLAGS,
 		"edit-flags",
-		"^E",
+		KeyCombination("e", ShiftState::NoShift, ControlState::Control),
 		translatable("Edit flags"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
 	},
-	{OP_NEXTFEED, "next-feed", "j", translatable("Go to next feed"), KM_ARTICLELIST},
+	{
+		OP_NEXTFEED,
+		"next-feed",
+		KeyCombination("j"),
+		translatable("Go to next feed"),
+		KM_ARTICLELIST
+	},
 	{
 		OP_PREVFEED,
 		"prev-feed",
-		"k",
+		KeyCombination("k"),
 		translatable("Go to previous feed"),
 		KM_ARTICLELIST
 	},
 	{
 		OP_NEXTUNREADFEED,
 		"next-unread-feed",
-		"^N",
+		KeyCombination("n", ShiftState::NoShift, ControlState::Control),
 		translatable("Go to next unread feed"),
 		KM_ARTICLELIST
 	},
 	{
 		OP_PREVUNREADFEED,
 		"prev-unread-feed",
-		"^P",
+		KeyCombination("p", ShiftState::NoShift, ControlState::Control),
 		translatable("Go to previous unread feed"),
 		KM_ARTICLELIST
 	},
-	{OP_MACROPREFIX, "macro-prefix", ",", translatable("Call a macro"), KM_NEWSBOAT},
+	{
+		OP_MACROPREFIX,
+		"macro-prefix",
+		KeyCombination(","),
+		translatable("Call a macro"),
+		KM_NEWSBOAT
+	},
 	{
 		OP_DELETE,
 		"delete-article",
-		"D",
+		KeyCombination("d", ShiftState::Shift),
 		translatable("Delete article"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_ARTICLE
 	},
 	{
 		OP_DELETE_ALL,
 		"delete-all-articles",
-		"^D",
+		KeyCombination("d", ShiftState::NoShift, ControlState::Control),
 		translatable("Delete all articles"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_PURGE_DELETED,
 		"purge-deleted",
-		"$",
+		KeyCombination("$"),
 		translatable("Purge deleted articles"),
 		KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_EDIT_URLS,
 		"edit-urls",
-		"E",
+		KeyCombination("e", ShiftState::Shift),
 		translatable("Edit subscribed URLs"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_CLOSEDIALOG,
 		"close-dialog",
-		"^X",
+		KeyCombination("x", ShiftState::NoShift, ControlState::Control),
 		translatable("Close currently selected dialog"),
 		KM_DIALOGS
 	},
 	{
 		OP_VIEWDIALOGS,
 		"view-dialogs",
-		"v",
+		KeyCombination("v"),
 		translatable("View list of open dialogs"),
 		KM_NEWSBOAT
 	},
 	{
 		OP_NEXTDIALOG,
 		"next-dialog",
-		"^V",
+		KeyCombination("v", ShiftState::NoShift, ControlState::Control),
 		translatable("Go to next dialog"),
 		KM_NEWSBOAT
 	},
 	{
 		OP_PREVDIALOG,
 		"prev-dialog",
-		"^G",
+		KeyCombination("g", ShiftState::NoShift, ControlState::Control),
 		translatable("Go to previous dialog"),
 		KM_NEWSBOAT
 	},
 	{
 		OP_PIPE_TO,
 		"pipe-to",
-		"|",
+		KeyCombination("|"),
 		translatable("Pipe article to command"),
 		KM_ARTICLE | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_SORT,
 		"sort",
-		"g",
+		KeyCombination("g"),
 		translatable("Sort current list"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_REVSORT,
 		"rev-sort",
-		"G",
+		KeyCombination("g", ShiftState::Shift),
 		translatable("Sort current list (reverse)"),
 		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
@@ -402,76 +496,226 @@ static const std::vector<OpDesc> opdescs = {
 	{
 		OP_PREVSEARCHRESULTS,
 		"prevsearchresults",
-		"z",
+		KeyCombination("z"),
 		translatable("Return to previous search results (if any)"),
 		KM_SEARCHRESULTSLIST
 	},
 	{
 		OP_ARTICLEFEED,
 		"article-feed",
-		"",
+		KeyCombination(""),
 		translatable("Go to the feed of the article"),
 		KM_ARTICLE | KM_ARTICLELIST | KM_SEARCHRESULTSLIST
 	},
 
-	{OP_OPEN_URL_1, "one", "1", translatable("Open URL 1"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_2, "two", "2", translatable("Open URL 2"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_3, "three", "3", translatable("Open URL 3"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_4, "four", "4", translatable("Open URL 4"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_5, "five", "5", translatable("Open URL 5"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_6, "six", "6", translatable("Open URL 6"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_7, "seven", "7", translatable("Open URL 7"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_8, "eight", "8", translatable("Open URL 8"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_9, "nine", "9", translatable("Open URL 9"), KM_URLVIEW | KM_ARTICLE},
-	{OP_OPEN_URL_10, "zero", "0", translatable("Open URL 10"), KM_URLVIEW | KM_ARTICLE},
+	{
+		OP_OPEN_URL_1,
+		"one",
+		KeyCombination("1"),
+		translatable("Open URL 1"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_2,
+		"two",
+		KeyCombination("2"),
+		translatable("Open URL 2"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_3,
+		"three",
+		KeyCombination("3"),
+		translatable("Open URL 3"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_4,
+		"four",
+		KeyCombination("4"),
+		translatable("Open URL 4"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_5,
+		"five",
+		KeyCombination("5"),
+		translatable("Open URL 5"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_6,
+		"six",
+		KeyCombination("6"),
+		translatable("Open URL 6"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_7,
+		"seven",
+		KeyCombination("7"),
+		translatable("Open URL 7"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_8,
+		"eight",
+		KeyCombination("8"),
+		translatable("Open URL 8"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_9,
+		"nine",
+		KeyCombination("9"),
+		translatable("Open URL 9"),
+		KM_URLVIEW | KM_ARTICLE
+	},
+	{
+		OP_OPEN_URL_10,
+		"zero",
+		KeyCombination("0"),
+		translatable("Open URL 10"),
+		KM_URLVIEW | KM_ARTICLE
+	},
 
-	{OP_CMD_START_1, "cmd-one", "1", translatable("Start cmdline with 1"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_2, "cmd-two", "2", translatable("Start cmdline with 2"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_3, "cmd-three", "3", translatable("Start cmdline with 3"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_4, "cmd-four", "4", translatable("Start cmdline with 4"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_5, "cmd-five", "5", translatable("Start cmdline with 5"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_6, "cmd-six", "6", translatable("Start cmdline with 6"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_7, "cmd-seven", "7", translatable("Start cmdline with 7"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_8, "cmd-eight", "8", translatable("Start cmdline with 8"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
-	{OP_CMD_START_9, "cmd-nine", "9", translatable("Start cmdline with 9"), KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS},
+	{
+		OP_CMD_START_1,
+		"cmd-one",
+		KeyCombination("1"),
+		translatable("Start cmdline with 1"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_2,
+		"cmd-two",
+		KeyCombination("2"),
+		translatable("Start cmdline with 2"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_3,
+		"cmd-three",
+		KeyCombination("3"),
+		translatable("Start cmdline with 3"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_4,
+		"cmd-four",
+		KeyCombination("4"),
+		translatable("Start cmdline with 4"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_5,
+		"cmd-five",
+		KeyCombination("5"),
+		translatable("Start cmdline with 5"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_6,
+		"cmd-six",
+		KeyCombination("6"),
+		translatable("Start cmdline with 6"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_7,
+		"cmd-seven",
+		KeyCombination("7"),
+		translatable("Start cmdline with 7"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_8,
+		"cmd-eight",
+		KeyCombination("8"),
+		translatable("Start cmdline with 8"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
+	{
+		OP_CMD_START_9,
+		"cmd-nine",
+		KeyCombination("9"),
+		translatable("Start cmdline with 9"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_SEARCHRESULTSLIST | KM_TAGSELECT | KM_FILTERSELECT | KM_DIALOGS
+	},
 
-	{OP_SK_UP, "up", "UP", translatable("Move to the previous entry"), KM_SYSKEYS},
-	{OP_SK_DOWN, "down", "DOWN", translatable("Move to the next entry"), KM_SYSKEYS},
+	{
+		OP_SK_UP,
+		"up",
+		KeyCombination("UP"),
+		translatable("Move to the previous entry"),
+		KM_SYSKEYS
+	},
+	{
+		OP_SK_DOWN,
+		"down",
+		KeyCombination("DOWN"),
+		translatable("Move to the next entry"),
+		KM_SYSKEYS
+	},
 	{
 		OP_SK_PGUP,
 		"pageup",
-		"PPAGE",
+		KeyCombination("PPAGE"),
 		translatable("Move to the previous page"),
 		KM_SYSKEYS
 	},
 	{
 		OP_SK_PGDOWN,
 		"pagedown",
-		"NPAGE",
+		KeyCombination("NPAGE"),
 		translatable("Move to the next page"),
 		KM_SYSKEYS
 	},
-	{OP_SK_HALF_PAGE_UP, "halfpageup", "", translatable("Move half page up"), KM_SYSKEYS},
-	{OP_SK_HALF_PAGE_DOWN, "halfpagedown", "", translatable("Move half page down"), KM_SYSKEYS},
+	{
+		OP_SK_HALF_PAGE_UP,
+		"halfpageup",
+		KeyCombination(""),
+		translatable("Move half page up"),
+		KM_SYSKEYS
+	},
+	{
+		OP_SK_HALF_PAGE_DOWN,
+		"halfpagedown",
+		KeyCombination(""),
+		translatable("Move half page down"),
+		KM_SYSKEYS
+	},
 
 	{
 		OP_SK_HOME,
 		"home",
-		"HOME",
+		KeyCombination("HOME"),
 		translatable("Move to the start of page/list"),
 		KM_SYSKEYS
 	},
 	{
 		OP_SK_END,
 		"end",
-		"END",
+		KeyCombination("END"),
 		translatable("Move to the end of page/list"),
 		KM_SYSKEYS
 	},
 
-	{OP_INT_SET, "set", "internal-set", "", KM_INTERNAL},
+	{
+		OP_INT_SET,
+		"set",
+		KeyCombination("internal-set"),
+		"",
+		KM_INTERNAL
+	},
 
-	{OP_INT_GOTO_URL, "gotourl", "internal-goto-url", "", KM_INTERNAL},
+	{
+		OP_INT_GOTO_URL,
+		"gotourl",
+		KeyCombination("internal-goto-url"),
+		"",
+		KM_INTERNAL
+	},
 };
 
 static const std::map<std::string, std::uint32_t> contexts = {
@@ -502,7 +746,7 @@ KeyMap::KeyMap(unsigned flags)
 		}
 
 		// Skip operations without a default key
-		if (op_desc.default_key.empty()) {
+		if (op_desc.default_key.get_key().empty()) {
 			continue;
 		}
 
@@ -510,15 +754,16 @@ KeyMap::KeyMap(unsigned flags)
 			const std::string& context = ctx.first;
 			const std::uint32_t context_flag = ctx.second;
 			if ((op_desc.flags & (context_flag | KM_INTERNAL | KM_SYSKEYS))) {
-				keymap_[context][op_desc.default_key] = op_desc.op;
+				const auto& default_key = op_desc.default_key;
+				keymap_[context][default_key] = op_desc.op;
 			}
 		}
 	}
 
-	keymap_["help"]["b"] = OP_SK_PGUP;
-	keymap_["help"]["SPACE"] = OP_SK_PGDOWN;
-	keymap_["article"]["b"] = OP_SK_PGUP;
-	keymap_["article"]["SPACE"] = OP_SK_PGDOWN;
+	keymap_["help"][KeyCombination("b")] = OP_SK_PGUP;
+	keymap_["help"][KeyCombination("SPACE")] = OP_SK_PGDOWN;
+	keymap_["article"][KeyCombination("b")] = OP_SK_PGUP;
+	keymap_["article"][KeyCombination("SPACE")] = OP_SK_PGDOWN;
 }
 
 std::vector<KeyMapDesc> KeyMap::get_keymap_descriptions(std::string context)
@@ -532,7 +777,7 @@ std::vector<KeyMapDesc> KeyMap::get_keymap_descriptions(std::string context)
 
 		bool bound_to_key = false;
 		for (const auto& keymap : keymap_[context]) {
-			const std::string& key = keymap.first;
+			const auto& key = keymap.first;
 			const Operation op = keymap.second;
 			if (opdesc.op == op) {
 				descs.push_back({key, opdesc.opstr, _(opdesc.help_text.c_str()), context, opdesc.flags});
@@ -544,13 +789,13 @@ std::vector<KeyMapDesc> KeyMap::get_keymap_descriptions(std::string context)
 				"KeyMap::get_keymap_descriptions: found unbound function: %s context = %s",
 				opdesc.opstr,
 				context);
-			descs.push_back({"", opdesc.opstr, _(opdesc.help_text.c_str()), context, opdesc.flags});
+			descs.push_back({KeyCombination(""), opdesc.opstr, _(opdesc.help_text.c_str()), context, opdesc.flags});
 		}
 	}
 	return descs;
 }
 
-const std::map<std::string, MacroBinding>& KeyMap::get_macro_descriptions()
+const std::map<KeyCombination, MacroBinding>& KeyMap::get_macro_descriptions()
 {
 	return macros_;
 }
@@ -558,10 +803,10 @@ const std::map<std::string, MacroBinding>& KeyMap::get_macro_descriptions()
 KeyMap::~KeyMap() {}
 
 void KeyMap::set_key(Operation op,
-	const std::string& key,
+	const KeyCombination& key,
 	const std::string& context)
 {
-	LOG(Level::DEBUG, "KeyMap::set_key(%d,%s) called", op, key);
+	LOG(Level::DEBUG, "KeyMap::set_key(%d,%s) called", op, key.to_bindkey_string());
 	if (context == "all") {
 		for (const auto& ctx : contexts) {
 			keymap_[ctx.first][key] = op;
@@ -571,9 +816,9 @@ void KeyMap::set_key(Operation op,
 	}
 }
 
-void KeyMap::unset_key(const std::string& key, const std::string& context)
+void KeyMap::unset_key(const KeyCombination& key, const std::string& context)
 {
-	LOG(Level::DEBUG, "KeyMap::unset_key(%s) called", key);
+	LOG(Level::DEBUG, "KeyMap::unset_key(%s) called", key.to_bindkey_string());
 	if (context == "all") {
 		for (const auto& ctx : contexts) {
 			keymap_[ctx.first][key] = OP_NIL;
@@ -621,20 +866,15 @@ char KeyMap::get_key(const std::string& keycode)
 	return 0;
 }
 
-Operation KeyMap::get_operation(const std::string& keycode,
+Operation KeyMap::get_operation(const KeyCombination& key_combination,
 	const std::string& context)
 {
 	std::string key;
 	LOG(Level::DEBUG,
 		"KeyMap::get_operation: keycode = %s context = %s",
-		keycode,
+		key_combination.to_bindkey_string(),
 		context);
-	if (keycode.length() > 0) {
-		key = keycode;
-	} else {
-		key = "NIL";
-	}
-	return keymap_[context][key];
+	return keymap_[context][key_combination];
 }
 
 void KeyMap::dump_config(std::vector<std::string>& config_output) const
@@ -645,7 +885,7 @@ void KeyMap::dump_config(std::vector<std::string>& config_output) const
 		for (const auto& keymap : x) {
 			if (keymap.second < OP_INT_MIN) {
 				std::string configline = "bind-key ";
-				configline.append(utils::quote(keymap.first));
+				configline.append(utils::quote(keymap.first.to_bindkey_string()));
 				configline.append(" ");
 				configline.append(getopname(keymap.second));
 				configline.append(" ");
@@ -656,7 +896,7 @@ void KeyMap::dump_config(std::vector<std::string>& config_output) const
 	}
 	for (const auto& macro : macros_) {
 		std::string configline = "macro ";
-		configline.append(macro.first);
+		configline.append(macro.first.to_bindkey_string());
 		configline.append(" ");
 		for (unsigned int i = 0; i < macro.second.cmds.size(); ++i) {
 			const auto& cmd = macro.second.cmds[i];
@@ -717,7 +957,8 @@ void KeyMap::handle_action(const std::string& action, const std::string& params)
 						"key command"),
 					tokens[1]));
 		}
-		set_key(op, tokens[0], context);
+		const auto key_combination = KeyCombination::from_bindkey(tokens[0]);
+		set_key(op, key_combination, context);
 	} else if (action == "unbind-key") {
 		const auto tokens = utils::tokenize_quoted(params);
 		if (tokens.size() < 1) {
@@ -731,7 +972,8 @@ void KeyMap::handle_action(const std::string& action, const std::string& params)
 		if (tokens[0] == "-a") {
 			unset_all_keys(context);
 		} else {
-			unset_key(tokens[0], context);
+			const auto key_combination = KeyCombination::from_bindkey(tokens[0]);
+			unset_key(key_combination, context);
 		}
 	} else if (action == "bind") {
 		bool parsing_failed = false;
@@ -750,7 +992,7 @@ void KeyMap::handle_action(const std::string& action, const std::string& params)
 		if (!token.has_value() || cmds.empty()) {
 			throw ConfigHandlerException(ActionHandlerStatus::TOO_FEW_PARAMS);
 		}
-		const std::string macrokey = token.value();
+		const auto macrokey = KeyCombination::from_bindkey(token.value());
 
 		macros_[macrokey] = {cmds, description};
 	} else if (action == "run-on-startup") {
@@ -795,10 +1037,10 @@ ParsedOperations KeyMap::parse_operation_sequence(const std::string& line,
 		cmds.push_back(cmd);
 	}
 
-	return ParsedOperations{
-		.operations = cmds,
-		.description = std::string(description)
-	};
+	ParsedOperations result;
+	result.operations = cmds;
+	result.description = std::string(description);
+	return result;
 }
 
 std::vector<MacroCmd> KeyMap::get_startup_operation_sequence()
@@ -806,10 +1048,10 @@ std::vector<MacroCmd> KeyMap::get_startup_operation_sequence()
 	return startup_operations_sequence;
 }
 
-std::vector<std::string> KeyMap::get_keys(Operation op,
+std::vector<KeyCombination> KeyMap::get_keys(Operation op,
 	const std::string& context)
 {
-	std::vector<std::string> keys;
+	std::vector<KeyCombination> keys;
 	for (const auto& keymap : keymap_[context]) {
 		if (keymap.second == op) {
 			keys.push_back(keymap.first);
@@ -818,10 +1060,10 @@ std::vector<std::string> KeyMap::get_keys(Operation op,
 	return keys;
 }
 
-std::vector<MacroCmd> KeyMap::get_macro(const std::string& key)
+std::vector<MacroCmd> KeyMap::get_macro(const KeyCombination& key_combination)
 {
-	if (macros_.count(key) >= 1) {
-		return macros_.at(key).cmds;
+	if (macros_.count(key_combination) >= 1) {
+		return macros_.at(key_combination).cmds;
 	}
 	return {};
 }
@@ -839,12 +1081,13 @@ bool KeyMap::is_valid_context(const std::string& context)
 	return false;
 }
 
-std::map<std::string, Operation> KeyMap::get_internal_operations() const
+std::map<KeyCombination, Operation> KeyMap::get_internal_operations() const
 {
-	std::map<std::string, Operation> internal_ops;
+	std::map<KeyCombination, Operation> internal_ops;
 	for (const auto& opdesc : opdescs) {
 		if (opdesc.flags & KM_INTERNAL) {
-			internal_ops[opdesc.default_key] = opdesc.op;
+			const auto& default_key = opdesc.default_key;
+			internal_ops[default_key] = opdesc.op;
 		}
 	}
 	return internal_ops;
@@ -865,17 +1108,22 @@ std::string KeyMap::prepare_keymap_hint(const std::vector<KeyMapHintEntry>& hint
 {
 	std::string keymap_hint;
 	for (const auto& hint : hints) {
-		std::vector<std::string> keys = get_keys(hint.op, context);
+		const std::vector<KeyCombination> bound_keys = get_keys(hint.op, context);
 
-		if (keys.empty()) {
-			keys = {"<none>"};
+		std::vector<std::string> key_stfl_strings;
+		if (bound_keys.empty()) {
+			std::string key_string = utils::quote_for_stfl("<none>");
+			key_string = strprintf::fmt("<key>%s</>", key_string);
+			key_stfl_strings = {key_string};
+		} else {
+			for (const auto& key : bound_keys) {
+				std::string key_string = utils::quote_for_stfl(key.to_bindkey_string());
+				key_string = strprintf::fmt("<key>%s</>", key_string);
+				key_stfl_strings.push_back(key_string);
+			}
 		}
 
-		for (auto& key : keys) {
-			key = strprintf::fmt("<key>%s</>", utils::quote_for_stfl(key));
-		}
-
-		keymap_hint.append(utils::join(keys, "<comma>,</>"));
+		keymap_hint.append(utils::join(key_stfl_strings, "<comma>,</>"));
 		keymap_hint.append("<colon>:</>");
 		keymap_hint.append(strprintf::fmt("<desc>%s</>", utils::quote_for_stfl(hint.text)));
 		keymap_hint.append(" ");
