@@ -1,22 +1,24 @@
 #include "listformaction.h"
 
+#include "controller.h"
 #include "rssfeed.h"
 #include "view.h"
 
 namespace newsboat {
 
-ListFormAction::ListFormAction(View* v,
+ListFormAction::ListFormAction(View& v,
+	const std::string& context,
 	std::string formstr,
 	std::string list_name,
-	ConfigContainer* cfg)
+	ConfigContainer* cfg, RegexManager& r)
 	: FormAction(v, formstr, cfg)
-	, list(list_name, FormAction::f, cfg->get_configvalue_as_int("scrolloff"))
+	, list(list_name, context, FormAction::f, r, cfg->get_configvalue_as_int("scrolloff"))
 {
 }
 
 bool ListFormAction::process_operation(Operation op,
-	bool,
-	std::vector<std::string>*)
+	const std::vector<std::string>& /* args */,
+	BindingType /*bindingType*/)
 {
 	switch (op) {
 	case OP_CMD_START_1:
@@ -47,25 +49,10 @@ bool ListFormAction::process_operation(Operation op,
 		FormAction::start_cmdline("9");
 		break;
 
-	case OP_SK_UP:
-		list.move_up(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_DOWN:
-		list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_HOME:
-		list.move_to_first();
-		break;
-	case OP_SK_END:
-		list.move_to_last();
-		break;
-	case OP_SK_PGUP:
-		list.move_page_up(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_PGDOWN:
-		list.move_page_down(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
 	default:
+		if (handle_list_operations(list, op)) {
+			break;
+		}
 		break;
 	}
 	return true;
@@ -83,8 +70,8 @@ nonstd::optional<std::uint8_t> ListFormAction::open_unread_items_in_browser(
 			cfg->get_configvalue_as_int("max-browser-tabs")) {
 			if (item->unread()) {
 				const bool interactive = true;
-				const auto exit_code = v->open_in_browser(item->link(), item->feedurl(),
-						interactive);
+				const auto exit_code = v.open_in_browser(item->link(), item->feedurl(),
+						"article", item->title(), interactive);
 				if (!exit_code.has_value() || *exit_code != 0) {
 					return_value = exit_code;
 					break;
@@ -102,7 +89,7 @@ nonstd::optional<std::uint8_t> ListFormAction::open_unread_items_in_browser(
 	}
 
 	if (guids_of_read_articles.size() > 0) {
-		v->get_ctrl()->mark_all_read(guids_of_read_articles);
+		v.get_ctrl()->mark_all_read(guids_of_read_articles);
 	}
 
 	return return_value;
