@@ -1,9 +1,10 @@
 #include "listformatter.h"
 
-#include <assert.h>
 #include <limits.h>
 
+#include "logger.h"
 #include "stflpp.h"
+#include "stflrichtext.h"
 #include "strprintf.h"
 #include "utils.h"
 
@@ -16,26 +17,24 @@ ListFormatter::ListFormatter(RegexManager* r, const std::string& loc)
 
 ListFormatter::~ListFormatter() {}
 
-void ListFormatter::add_line(const std::string& text)
+void ListFormatter::add_line(const StflRichText& text)
 {
+	LOG(Level::DEBUG, "ListFormatter::add_line: `%s'", text.stfl_quoted());
 	set_line(UINT_MAX, text);
-	LOG(Level::DEBUG, "ListFormatter::add_line: `%s'", text);
 }
 
 void ListFormatter::set_line(const unsigned int itempos,
-	const std::string& text)
+	const StflRichText& text)
 {
-	std::vector<std::string> formatted_text;
-
-	formatted_text.push_back(utils::wstr2str(utils::clean_nonprintable_characters(
-				utils::str2wstr(text))));
+	const std::wstring wide = utils::str2wstr(text.stfl_quoted());
+	const std::wstring cleaned = utils::clean_nonprintable_characters(wide);
+	const std::string formatted_text = utils::wstr2str(cleaned);
+	const StflRichText stflRichText = StflRichText::from_quoted(formatted_text);
 
 	if (itempos == UINT_MAX) {
-		lines.insert(lines.cend(),
-			formatted_text.cbegin(),
-			formatted_text.cend());
+		lines.push_back(stflRichText);
 	} else {
-		lines[itempos] = formatted_text[0];
+		lines[itempos] = stflRichText;
 	}
 }
 
@@ -47,7 +46,7 @@ std::string ListFormatter::format_list() const
 			rxman->quote_and_highlight(str, location);
 		}
 		format_cache.append(strprintf::fmt(
-				"{listitem text:%s}", Stfl::quote(str)));
+				"{listitem text:%s}", Stfl::quote(str.stfl_quoted())));
 	}
 	format_cache.push_back('}');
 	return format_cache;
