@@ -4,7 +4,7 @@
 #include <string.h>
 #include <time.h>
 
-#include "json.h"
+#include "logger.h"
 #include "remoteapi.h"
 #include "strprintf.h"
 #include "utils.h"
@@ -28,23 +28,21 @@ using HTTPMethod = newsboat::utils::HTTPMethod;
 
 namespace newsboat {
 
-NewsBlurApi::NewsBlurApi(ConfigContainer* c)
+NewsBlurApi::NewsBlurApi(ConfigContainer& c)
 	: RemoteApi(c)
 {
-	api_location = cfg->get_configvalue("newsblur-url");
-	min_pages = (cfg->get_configvalue_as_int("newsblur-min-items") +
+	api_location = cfg.get_configvalue("newsblur-url");
+	min_pages = (cfg.get_configvalue_as_int("newsblur-min-items") +
 			(NEWSBLUR_ITEMS_PER_PAGE + 1)) /
 		NEWSBLUR_ITEMS_PER_PAGE;
 
-	if (cfg->get_configvalue("cookie-cache").empty()) {
+	if (cfg.get_configvalue("cookie-cache").empty()) {
 		LOG(Level::CRITICAL,
 			"NewsBlurApi::NewsBlurApi: No cookie-cache has been "
 			"configured the login won't work.");
 	}
 }
 
-NewsBlurApi::~NewsBlurApi() {}
-
 bool NewsBlurApi::authenticate()
 {
 	json_object* response{};
@@ -64,7 +62,7 @@ bool NewsBlurApi::authenticate()
 		"cached "
 		"in %s",
 		result,
-		cfg->get_configvalue("cookie-cache"));
+		cfg.get_configvalue("cookie-cache"));
 
 	return result;
 }
@@ -109,10 +107,21 @@ std::vector<TaggedFeedUrl> NewsBlurApi::get_subscribed_urls()
 
 		json_object* feed_json = json_object_iter_peek_value(&it);
 		json_object_object_get_ex(feed_json, "feed_title", &node);
-		current_feed.title = json_object_get_string(node);
+		const auto title = json_object_get_string(node);
+		if (title != nullptr) {
+			current_feed.title = title;
+		} else {
+			LOG(Level::WARN, "Subscription has no title, so let's call it \"%s\"", feed_id);
+			current_feed.title = feed_id;
+		}
 		json_object_object_get_ex(feed_json, "feed_link", &node);
 		if (node) {
-			current_feed.link = json_object_get_string(node);
+			const auto link = json_object_get_string(node);
+			if (link == nullptr) {
+				LOG(Level::WARN, "Skipping a subscription without a link");
+				continue;
+			}
+			current_feed.link = link;
 
 			known_feeds[feed_id] = current_feed;
 			std::string std_feed_id(feed_id);
@@ -152,20 +161,20 @@ std::map<std::string, std::vector<std::string>> NewsBlurApi::mk_feeds_to_tags(
 			continue;
 		}
 
-		json_object_object_foreach(
-			tag_to_feed_ids, key, feeds_with_tag_obj) {
+		// invariant: `tag_to_feed_ids` is a JSON object
+
+		json_object_object_foreach(tag_to_feed_ids, key, feeds_with_tag_obj) {
 			std::string std_key(key);
-			array_list* feeds_with_tag_arr =
-				json_object_get_array(feeds_with_tag_obj);
-			int feeds_with_tag_len =
-				array_list_length(feeds_with_tag_arr);
+			array_list* feeds_with_tag_arr = json_object_get_array(feeds_with_tag_obj);
+			int feeds_with_tag_len = array_list_length(feeds_with_tag_arr);
 			for (int j = 0; j < feeds_with_tag_len; ++j) {
-				json_object* feed_id_obj =
-					json_object_array_get_idx(
-						feeds_with_tag_obj, j);
-				std::string feed_id(
-					json_object_get_string(feed_id_obj));
-				result[feed_id].push_back(std_key);
+				json_object* feed_id_obj = json_object_array_get_idx(feeds_with_tag_obj, j);
+				const auto id = json_object_get_string(feed_id_obj);
+				if (id == nullptr) {
+					LOG(Level::WARN, "Skipping subscription's tag whose name is a null value");
+					continue;
+				}
+				result[std::string(id)].push_back(std_key);
 			}
 		}
 	}
@@ -183,7 +192,8 @@ bool request_successfull(json_object* payload)
 	if (json_object_object_get_ex(payload, "result", &result) == FALSE) {
 		return false;
 	} else {
-		return !strcmp("ok", json_object_get_string(result));
+		const auto result_str = json_object_get_string(result);
+		return result_str != nullptr && strcmp("ok", result_str) == 0;
 	}
 }
 
@@ -277,59 +287,61 @@ rsspp::Feed NewsBlurApi::fetch_feed(const std::string& id)
 			items_size);
 
 		for (int i = 0; i < items_size; i++) {
-			json_object* item_obj =
-				(json_object*)array_list_get_idx(items, i);
+			json_object* item_obj = (json_object*)array_list_get_idx(items, i);
 
 			rsspp::Item item;
 
 			json_object* node{};
 
-			if (json_object_object_get_ex(
-					item_obj, "story_title", &node) == TRUE) {
-				item.title = json_object_get_string(node);
+			if (json_object_object_get_ex(item_obj, "story_title", &node) == TRUE) {
+				const auto title = json_object_get_string(node);
+				if (title != nullptr) {
+					item.title = title;
+				}
 			}
 
-			if (json_object_object_get_ex(
-					item_obj, "story_authors", &node) == TRUE) {
-				item.author = json_object_get_string(node);
+			if (json_object_object_get_ex(item_obj, "story_authors", &node) == TRUE) {
+				const auto author = json_object_get_string(node);
+				if (author != nullptr) {
+					item.author = author;
+				}
 			}
 
-			if (json_object_object_get_ex(item_obj,
-					"story_permalink",
-					&node) == TRUE) {
-				item.link = json_object_get_string(node);
+			if (json_object_object_get_ex(item_obj, "story_permalink", &node) == TRUE) {
+				const auto link = json_object_get_string(node);
+				if (link != nullptr) {
+					item.link = link;
+				}
 			}
 
-			if (json_object_object_get_ex(
-					item_obj, "story_content", &node) == TRUE) {
-				item.content_encoded =
-					json_object_get_string(node);
+			if (json_object_object_get_ex(item_obj, "story_content", &node) == TRUE) {
+				const auto content_encoded = json_object_get_string(node);
+				if (content_encoded != nullptr) {
+					item.content_encoded = content_encoded;
+				}
 			}
 
 			const char* article_id{};
-			if (json_object_object_get_ex(item_obj, "id", &node) ==
-				TRUE) {
+			if (json_object_object_get_ex(item_obj, "id", &node) == TRUE) {
 				article_id = json_object_get_string(node);
 			}
-			item.guid = id + ID_SEPARATOR +
-				(article_id ? article_id : "");
+			item.guid = id + ID_SEPARATOR + (article_id ? article_id : "");
 
-			if (json_object_object_get_ex(
-					item_obj, "read_status", &node) == TRUE) {
-				if (!static_cast<bool>(
-						json_object_get_int(node))) {
-					item.labels.push_back(
-						"newsblur:unread");
+			if (json_object_object_get_ex(item_obj, "read_status", &node) == TRUE) {
+				if (!static_cast<bool>(json_object_get_int(node))) {
+					item.labels.push_back("newsblur:unread");
 				} else {
 					item.labels.push_back("newsblur:read");
 				}
 			}
 
-			if (json_object_object_get_ex(
-					item_obj, "story_date", &node) == TRUE) {
-				const char* pub_date =
-					json_object_get_string(node);
-				item.pubDate_ts = parse_date(pub_date);
+			if (json_object_object_get_ex(item_obj, "story_date", &node) == TRUE) {
+				const char* pub_date = json_object_get_string(node);
+				if (pub_date != nullptr) {
+					item.pubDate_ts = parse_date(pub_date);
+				} else {
+					item.pubDate_ts = ::time(nullptr);
+				}
 
 				item.pubDate = utils::mt_strf_localtime(
 						"%a, %d %b %Y %H:%M:%S %z",
