@@ -1,11 +1,8 @@
 #include "pbview.h"
 
 #include <cinttypes>
-#include <cstdio>
 #include <cstring>
 #include <ncurses.h>
-#include <iostream>
-#include <sstream>
 
 #include "config.h"
 #include "configcontainer.h"
@@ -17,7 +14,6 @@
 #include "logger.h"
 #include "pbcontroller.h"
 #include "strprintf.h"
-#include "utils.h"
 
 using namespace newsboat;
 
@@ -28,6 +24,10 @@ PbView::PbView(PbController& c)
 	, ctrl(c)
 	, dllist_form(dllist_str)
 	, help_form(help_str)
+	, title_line_dllist_form(dllist_form, "head")
+	, title_line_help_form(help_form, "head")
+	, msg_line_dllist_form(dllist_form, "msg")
+	, msg_line_help_form(help_form, "msg")
 	, keys(ctrl.get_keymap())
 	, colorman(ctrl.get_colormanager())
 	, downloads_list("dls", dllist_form,
@@ -71,7 +71,7 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 				title += strprintf::fmt(_(" - %u parallel downloads"), ctrl.get_maxdownloads());
 			}
 
-			dllist_form.set("head", title);
+			title_line_dllist_form.set_text(title);
 
 			LOG(Level::DEBUG,
 				"PbView::run: updating view... "
@@ -86,7 +86,7 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 			dllist_form.run(-3); // compute all widget dimensions
 
 			auto render_line = [this, line_format](std::uint32_t line,
-			std::uint32_t width) -> std::string {
+			std::uint32_t width) -> StflRichText {
 				const auto& downloads = ctrl.downloads();
 				const auto& dl = downloads.at(line);
 				return format_line(line_format, dl, line, width);
@@ -98,9 +98,9 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 
 		// If there's no status message, we know there's no error to show
 		// Thus, it's safe to replace with the download's status
-		if (dllist_form.get("msg").empty() && ctrl.downloads().size() > 0) {
+		if (msg_line_dllist_form.get_text().empty() && ctrl.downloads().size() > 0) {
 			const auto idx = downloads_list.get_position();
-			dllist_form.set("msg", ctrl.downloads()[idx].status_msg());
+			msg_line_dllist_form.set_text(ctrl.downloads()[idx].status_msg());
 		}
 
 		const char* event = dllist_form.run(500);
@@ -121,10 +121,11 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 			continue;
 		}
 
-		Operation op = keys.get_operation(event, "podboat");
+		const auto key_combination = KeyCombination::from_bindkey(event);
+		Operation op = keys.get_operation(key_combination, "podboat");
 
-		if (dllist_form.get("msg").length() > 0) {
-			dllist_form.set("msg", "");
+		if (msg_line_dllist_form.get_text().length() > 0) {
+			msg_line_dllist_form.set_text("");
 			update_view = true;
 		}
 
@@ -164,7 +165,7 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 		case OP_HARDQUIT:
 		case OP_QUIT:
 			if (ctrl.downloads_in_progress() > 0) {
-				dllist_form.set("msg", _("Error: can't quit: download(s) in progress."));
+				msg_line_dllist_form.set_text(_("Error: can't quit: download(s) in progress."));
 				update_view = true;
 			} else {
 				quit = true;
@@ -199,10 +200,8 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 					ctrl.downloads()[idx].set_status(
 						DlStatus::PLAYED);
 				} else {
-					dllist_form.set("msg",
-						_("Error: download needs to be "
-							"finished before the file "
-							"can be played."));
+					msg_line_dllist_form.set_text(_("Error: download needs to be "
+							"finished before the file can be played."));
 				}
 			}
 		}
@@ -249,8 +248,7 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 		break;
 		case OP_PB_PURGE:
 			if (ctrl.downloads_in_progress() > 0) {
-				dllist_form.set("msg",
-					_("Error: unable to perform operation: "
+				msg_line_dllist_form.set_text(_("Error: unable to perform operation: "
 						"download(s) in progress."));
 			} else {
 				ctrl.purge_queue();
@@ -300,7 +298,7 @@ void PbView::run_help()
 {
 	set_help_keymap_hint();
 
-	help_form.set("head", _("Help"));
+	title_line_help_form.set_text(_("Help"));
 
 	const auto descs = keys.get_keymap_descriptions("podboat");
 
@@ -308,11 +306,11 @@ void PbView::run_help()
 
 	for (const auto& desc : descs) {
 		const std::string descline = strprintf::fmt("%-7s %-23s %s",
-				desc.key,
+				desc.key.to_bindkey_string(),
 				desc.cmd,
 				desc.desc);
 
-		listfmt.add_line(descline);
+		listfmt.add_line(StflRichText::from_plaintext(descline));
 	}
 
 	help_textview.stfl_replace_lines(listfmt.get_lines_count(),
@@ -331,7 +329,8 @@ void PbView::run_help()
 			continue;
 		}
 
-		Operation op = keys.get_operation(event, "help");
+		const auto key_combination = KeyCombination::from_bindkey(event);
+		Operation op = keys.get_operation(key_combination, "help");
 
 		switch (op) {
 		case OP_SK_UP:
@@ -392,7 +391,7 @@ void PbView::set_dllist_keymap_hint()
 	dllist_form.set("help", keymap_hint);
 }
 
-std::string PbView::format_line(const std::string& podlist_format,
+StflRichText PbView::format_line(const std::string& podlist_format,
 	const Download& dl,
 	unsigned int pos,
 	unsigned int width)
@@ -416,8 +415,7 @@ std::string PbView::format_line(const std::string& podlist_format,
 	fmt.register_fmt('b', strprintf::fmt("%s", dl.basename()));
 
 	auto formattedLine = fmt.do_format(podlist_format, width);
-	formattedLine = utils::quote_for_stfl(formattedLine);
-	return formattedLine;
+	return StflRichText::from_plaintext(formattedLine);
 }
 
 } // namespace podboat
