@@ -3,12 +3,30 @@
 #include <fstream>
 #include <glob.h>
 #include <iostream>
+#include "logger.h"
 #include <unistd.h>
 
+#include "configcontainer.h"
 #include "utils.h"
 
 namespace newsboat {
 
+RemoteApi::RemoteApi(ConfigContainer& c)
+	: cfg(c)
+{
+}
+
+bool RemoteApi::mark_articles_read(const std::vector<std::string>& guids)
+{
+	bool success = true;
+	for (const auto& guid : guids) {
+		if (!this->mark_article_read(guid, true)) {
+			success = false;
+		}
+	}
+	return success;
+}
+
 const std::string RemoteApi::read_password(const std::string& file)
 {
 	glob_t exp;
@@ -45,10 +63,27 @@ const std::string RemoteApi::eval_password(const std::string& cmd)
 Credentials RemoteApi::get_credentials(const std::string& scope,
 	const std::string& name)
 {
-	std::string user = cfg->get_configvalue(scope + "-login");
-	std::string pass = cfg->get_configvalue(scope + "-password");
-	std::string pass_file = cfg->get_configvalue(scope + "-passwordfile");
-	std::string pass_eval = cfg->get_configvalue(scope + "-passwordeval");
+	std::string user = cfg.get_configvalue(scope + "-login");
+	std::string pass = cfg.get_configvalue(scope + "-password");
+	std::string pass_file = cfg.get_configvalue(scope + "-passwordfile");
+	std::string pass_eval = cfg.get_configvalue(scope + "-passwordeval");
+	std::string token = cfg.get_configvalue(scope + "-token");
+	std::string token_file = cfg.get_configvalue(scope + "-tokenfile");
+	std::string token_eval = cfg.get_configvalue(scope + "-tokeneval");
+
+	if (!token.empty()) {
+		return {"", "", token};
+	}
+
+	if (!token_file.empty()) {
+		token = read_password(token_file);
+		return {"", "", token};
+	}
+
+	if (!token_eval.empty()) {
+		token = eval_password(token_eval);
+		return {"", "", token};
+	}
 
 	bool flushed = false;
 
@@ -59,7 +94,7 @@ Credentials RemoteApi::get_credentials(const std::string& scope,
 		printf("Username for %s: ", name.c_str());
 		std::cin >> user;
 		if (user.empty()) {
-			return {"", ""};
+			return {"", "", ""};
 		}
 	}
 
@@ -79,11 +114,24 @@ Credentials RemoteApi::get_credentials(const std::string& scope,
 		}
 
 		if (pass.empty()) {
-			return {"", ""};
+			return {"", "", ""};
 		}
 	}
 
-	return {user, pass};
+	return {user, pass, token};
+}
+
+void RemoteApi::update_flag(const std::string& oldflags,
+	const std::string& newflags,
+	char flag, std::function<void(bool added)>&& do_update)
+{
+	const bool old_has = oldflags.find(flag) != std::string::npos;
+	const bool new_has = newflags.find(flag) != std::string::npos;
+	if (!old_has && new_has) {
+		do_update(true);
+	} else if (old_has && !new_has) {
+		do_update(false);
+	}
 }
 
 } // namespace newsboat
