@@ -1,8 +1,10 @@
 #include "searchresultslistformaction.h"
+
 #include "keymap.h"
+#include "logger.h"
 
 namespace newsboat {
-SearchResultsListFormAction::SearchResultsListFormAction(View* vv,
+SearchResultsListFormAction::SearchResultsListFormAction(View& vv,
 	std::string formstr,
 	Cache* cc,
 	FilterContainer& f,
@@ -46,11 +48,11 @@ bool SearchResultsListFormAction::process_operation(
 			// no need to mark item as read, the itemview already do
 			// that
 			old_itempos = itempos;
-			v->push_itemview(feed,
+			v.push_itemview(feed,
 				visible_items[itempos].first->guid(), search_phrase);
 			invalidate(itempos);
 		} else {
-			v->get_statusline().show_error(
+			v.get_statusline().show_error(
 				_("No item selected!")); // should not happen
 		}
 		break;
@@ -60,7 +62,7 @@ bool SearchResultsListFormAction::process_operation(
 			this->set_feed(search_results.top().search_result_feed);
 			this->set_searchphrase(search_results.top().search_phrase);
 		} else {
-			v->get_statusline().show_message(_("Already in first search result."));
+			v.get_statusline().show_message(_("Already in first search result."));
 		}
 		break;
 	default:
@@ -74,14 +76,12 @@ void SearchResultsListFormAction::set_head(const std::string& s,
 	unsigned int total,
 	const std::string& url)
 {
-	std::string title;
 	FmtStrFormatter fmt = setup_head_formatter(s, unread, total, url);
 
 	const unsigned int width = utils::to_u(f.get("title:w"));
-	title = fmt.do_format(
+	set_title(fmt.do_format(
 			cfg->get_configvalue("searchresult-title-format"),
-			width);
-	set_value("head", title);
+			width));
 }
 
 std::string SearchResultsListFormAction::title()
