@@ -1,12 +1,11 @@
 #include "urlviewformaction.h"
 
-#include <sstream>
 #include <string>
 
 #include "config.h"
 #include "fmtstrformatter.h"
-#include "listformatter.h"
 #include "rssfeed.h"
+#include "stflrichtext.h"
 #include "strprintf.h"
 #include "utils.h"
 #include "view.h"
@@ -19,7 +18,7 @@ namespace newsboat {
  * in a browser or to bookmark them.
  */
 
-UrlViewFormAction::UrlViewFormAction(View* vv,
+UrlViewFormAction::UrlViewFormAction(View& vv,
 	std::shared_ptr<RssFeed>& feed,
 	std::string formstr,
 	ConfigContainer* cfg)
@@ -30,53 +29,36 @@ UrlViewFormAction::UrlViewFormAction(View* vv,
 {
 }
 
-UrlViewFormAction::~UrlViewFormAction() {}
-
 bool UrlViewFormAction::process_operation(Operation op,
-	bool /* automatic */,
-	std::vector<std::string>* /* args */)
+	const std::vector<std::string>& /* args */,
+	BindingType /*bindingType*/)
 {
 	bool hardquit = false;
 	switch (op) {
 	case OP_PREV:
-	case OP_SK_UP:
 		urls_list.move_up(cfg->get_configvalue_as_bool("wrap-scroll"));
 		break;
 	case OP_NEXT:
-	case OP_SK_DOWN:
 		urls_list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"));
 		break;
-	case OP_SK_HOME:
-		urls_list.move_to_first();
-		break;
-	case OP_SK_END:
-		urls_list.move_to_last();
-		break;
-	case OP_SK_PGUP:
-		urls_list.move_page_up(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_PGDOWN:
-		urls_list.move_page_down(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
 	case OP_OPENINBROWSER:
 	case OP_OPENBROWSER_AND_MARK:
 	case OP_OPEN: {
-		if (!links.empty()) {
-			const unsigned int pos = urls_list.get_position();
-			v->set_status(_("Starting browser..."));
-			v->open_in_browser(links[pos].first);
-			v->set_status("");
-		} else {
-			v->show_error(_("No links available!"));
-		}
+		const bool interactive = true;
+		open_current_position_in_browser(interactive);
+	}
+	break;
+	case OP_OPENINBROWSER_NONINTERACTIVE: {
+		const bool interactive = false;
+		open_current_position_in_browser(interactive);
 	}
 	break;
 	case OP_BOOKMARK: {
 		if (!links.empty()) {
 			const unsigned int pos = urls_list.get_position();
-			this->start_bookmark_qna("", links[pos].first, "", feed->title());
+			this->start_bookmark_qna("", links[pos].url, feed->title());
 		} else {
-			v->show_error(_("No links available!"));
+			v.get_statusline().show_error(_("No links available!"));
 		}
 	}
 	break;
@@ -93,71 +75,91 @@ bool UrlViewFormAction::process_operation(Operation op,
 		unsigned int idx = op - OP_OPEN_URL_1;
 
 		if (idx < links.size()) {
-			v->set_status(_("Starting browser..."));
-			v->open_in_browser(links[idx].first);
-			v->set_status("");
+			const std::string feedurl = (feed != nullptr ?  feed->rssurl() : "");
+			const bool interactive = true;
+			v.open_in_browser(links[idx].url, feedurl, utils::link_type_str(links[idx].type),
+				feed->title(), interactive);
 		}
 	}
 	break;
+	case OP_HELP:
+		v.push_help();
+		break;
 	case OP_QUIT:
 		quit = true;
 		break;
 	case OP_HARDQUIT:
 		hardquit = true;
 		break;
-	default: // nothing
+	default:
+		if (handle_list_operations(urls_list, op)) {
+			break;
+		}
 		break;
 	}
 	if (hardquit) {
-		while (v->formaction_stack_size() > 0) {
-			v->pop_current_formaction();
+		while (v.formaction_stack_size() > 0) {
+			v.pop_current_formaction();
 		}
 	} else if (quit) {
-		v->pop_current_formaction();
+		v.pop_current_formaction();
 	}
 	return true;
 }
 
+void UrlViewFormAction::open_current_position_in_browser(bool interactive)
+{
+	if (!links.empty()) {
+		const unsigned int pos = urls_list.get_position();
+		const std::string feedurl = (feed != nullptr ?  feed->rssurl() : "");
+		v.open_in_browser(links[pos].url, feedurl, utils::link_type_str(links[pos].type),
+			feed->title(), interactive);
+	} else {
+		v.get_statusline().show_error(_("No links available!"));
+	}
+}
+
 void UrlViewFormAction::prepare()
 {
 	if (do_redraw) {
-		ListFormatter listfmt;
-		unsigned int i = 0;
-		for (const auto& link : links) {
-			listfmt.add_line(utils::quote_for_stfl(strprintf::fmt("%2u  %s", i + 1,
-						link.first)));
-			i++;
-		}
-		urls_list.stfl_replace_lines(listfmt);
+		update_heading();
+
+		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> StflRichText {
+			(void)width;
+			const auto& link = links[line];
+			return StflRichText::from_plaintext(strprintf::fmt("%2u  %s", line + 1, link.url));
+		};
+
+		urls_list.invalidate_list_content(links.size(), render_line);
 	}
 }
 
 void UrlViewFormAction::init()
 {
-	v->set_status("");
+	recalculate_widget_dimensions();
 
-	f.run(-3); // compute all widget dimensions
+	do_redraw = true;
+	quit = false;
+	set_keymap_hints();
+}
 
+void UrlViewFormAction::update_heading()
+{
 	const unsigned int width = urls_list.get_width();
 
 	FmtStrFormatter fmt;
 	fmt.register_fmt('N', PROGRAM_NAME);
 	fmt.register_fmt('V', utils::program_version());
 
-	f.set("head",
-		fmt.do_format(
-			cfg->get_configvalue("urlview-title-format"), width));
-	do_redraw = true;
-	quit = false;
-	set_keymap_hints();
+	set_title(fmt.do_format(cfg->get_configvalue("urlview-title-format"), width));
 }
 
-KeyMapHintEntry* UrlViewFormAction::get_keymap_hint()
+const std::vector<KeyMapHintEntry>& UrlViewFormAction::get_keymap_hint() const
 {
-	static KeyMapHintEntry hints[] = {{OP_QUIT, _("Quit")},
+	static const std::vector<KeyMapHintEntry> hints = {{OP_QUIT, _("Quit")},
 		{OP_OPEN, _("Open in Browser")},
 		{OP_BOOKMARK, _("Save Bookmark")},
-		{OP_NIL, nullptr}
+		{OP_HELP, _("Help")}
 	};
 	return hints;
 }
@@ -167,7 +169,7 @@ void UrlViewFormAction::handle_cmdline(const std::string& cmd)
 	unsigned int idx = 0;
 	if (1 == sscanf(cmd.c_str(), "%u", &idx)) {
 		if (idx < 1 || idx > links.size()) {
-			v->show_error(_("Invalid position!"));
+			v.get_statusline().show_error(_("Invalid position!"));
 		} else {
 			urls_list.set_position(idx - 1);
 		}
