@@ -1,49 +1,47 @@
 #include "utils.h"
-#include <iostream>
 
-#include <algorithm>
 #include <cinttypes>
-#include <cmath>
-#include <cstdarg>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
 #include <curl/curl.h>
 #include <cwchar>
-#include <errno.h>
 #include <fcntl.h>
 #include <iconv.h>
 #include <langinfo.h>
 #include <libxml/uri.h>
-#include <locale>
 #include <mutex>
 #include <pwd.h>
-#include <regex>
 #include <sstream>
 #include <stfl.h>
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/utsname.h>
 #include <unistd.h>
-#include <unordered_set>
-
-#include "config.h"
-#include "curlhandle.h"
-#include "htmlrenderer.h"
-#include "logger.h"
-#include "strprintf.h"
 
 #if HAVE_GCRYPT
+#include <gnutls/gnutls.h>
+#if GNUTLS_VERSION_NUMBER < 0x020b00
 #include <errno.h>
 #include <gcrypt.h>
-#include <gnutls/gnutls.h>
 #include <pthread.h>
 GCRY_THREAD_OPTION_PTHREAD_IMPL;
 #endif
+#endif
 
-#if HAVE_OPENSSL && OPENSSL_VERSION_NUMBER < 0x01010000fL
+#if HAVE_OPENSSL
+#include <openssl/opensslv.h>
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
 #include <openssl/crypto.h>
 #endif
+#endif
+
+#include "config.h"
+#include "curldatareceiver.h"
+#include "curlhandle.h"
+#include "links.h"
+#include "logger.h"
+#include "strprintf.h"
 
 using HTTPMethod = newsboat::utils::HTTPMethod;
 
@@ -191,14 +189,6 @@ std::string utils::get_command_output(const std::string& cmd)
 	return std::string(utils::bridged::get_command_output(cmd));
 }
 
-static size_t my_write_data(void* buffer, size_t size, size_t nmemb,
-	void* userp)
-{
-	std::string* pbuf = static_cast<std::string*>(userp);
-	pbuf->append(static_cast<const char*>(buffer), size * nmemb);
-	return size * nmemb;
-}
-
 std::string utils::http_method_str(const HTTPMethod method)
 {
 	std::string str = "";
@@ -244,7 +234,7 @@ std::string utils::link_type_str(LinkType type)
 }
 
 std::string utils::retrieve_url(const std::string& url,
-	ConfigContainer* cfgcont,
+	ConfigContainer& cfgcont,
 	const std::string& authinfo,
 	const std::string* body,
 	const HTTPMethod method /* = GET */)
@@ -255,17 +245,15 @@ std::string utils::retrieve_url(const std::string& url,
 
 std::string utils::retrieve_url(const std::string& url,
 	CurlHandle& easyhandle,
-	ConfigContainer* cfgcont,
+	ConfigContainer& cfgcont,
 	const std::string& authinfo,
 	const std::string* body,
 	const HTTPMethod method /* = GET */)
 {
-	std::string buf;
-
 	set_common_curl_options(easyhandle, cfgcont);
 	curl_easy_setopt(easyhandle.ptr(), CURLOPT_URL, url.c_str());
-	curl_easy_setopt(easyhandle.ptr(), CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(easyhandle.ptr(), CURLOPT_WRITEDATA, &buf);
+
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(easyhandle);
 
 	switch (method) {
 	case HTTPMethod::GET:
@@ -286,7 +274,7 @@ std::string utils::retrieve_url(const std::string& url,
 	}
 
 	if (!authinfo.empty()) {
-		const auto auth_method = cfgcont->get_configvalue("http-auth-method");
+		const auto auth_method = cfgcont.get_configvalue("http-auth-method");
 		curl_easy_setopt(easyhandle.ptr(), CURLOPT_HTTPAUTH, get_auth_method(auth_method));
 		curl_easy_setopt(easyhandle.ptr(), CURLOPT_USERPWD, authinfo.c_str());
 	}
@@ -305,6 +293,7 @@ std::string utils::retrieve_url(const std::string& url,
 	logprefix << "utils::retrieve_url(" << http_method_str(method) << " " << url << ")"
 		<< "[" << (body != nullptr ? body->c_str() : "-") << "]";
 
+	std::string buf = curlDataReceiver->get_data();
 	if (res != CURLE_OK) {
 		std::string errmsg(errbuf);
 		if (errmsg.empty()) {
@@ -426,9 +415,9 @@ std::string utils::absolute_url(const std::string& url, const std::string& link)
 	return std::string(utils::bridged::absolute_url(url, link));
 }
 
-std::string utils::get_useragent(ConfigContainer* cfgcont)
+std::string utils::get_useragent(ConfigContainer& cfgcont)
 {
-	std::string ua_pref = cfgcont->get_configvalue("user-agent");
+	std::string ua_pref = cfgcont.get_configvalue("user-agent");
 	if (ua_pref.length() == 0) {
 		struct utsname buf;
 		uname(&buf);
@@ -538,68 +527,66 @@ std::string utils::quote_if_necessary(const std::string& str)
 	return std::string(utils::bridged::quote_if_necessary(str));
 }
 
-void utils::set_common_curl_options(CurlHandle& handle, ConfigContainer* cfg)
+void utils::set_common_curl_options(CurlHandle& handle, ConfigContainer& cfg)
 {
-	if (cfg) {
-		if (cfg->get_configvalue_as_bool("use-proxy")) {
-			const std::string proxy = cfg->get_configvalue("proxy");
-			if (proxy != "")
-				curl_easy_setopt(
-					handle.ptr(), CURLOPT_PROXY, proxy.c_str());
+	if (cfg.get_configvalue_as_bool("use-proxy")) {
+		const std::string proxy = cfg.get_configvalue("proxy");
+		if (proxy != "")
+			curl_easy_setopt(
+				handle.ptr(), CURLOPT_PROXY, proxy.c_str());
 
-			const std::string proxyauth =
-				cfg->get_configvalue("proxy-auth");
-			const std::string proxyauthmethod =
-				cfg->get_configvalue("proxy-auth-method");
-			if (proxyauth != "") {
-				curl_easy_setopt(handle.ptr(),
-					CURLOPT_PROXYAUTH,
-					get_auth_method(proxyauthmethod));
-				curl_easy_setopt(handle.ptr(),
-					CURLOPT_PROXYUSERPWD,
-					proxyauth.c_str());
-			}
-
-			const std::string proxytype =
-				cfg->get_configvalue("proxy-type");
-			if (proxytype != "") {
-				LOG(Level::DEBUG,
-					"utils::set_common_curl_options: "
-					"proxytype "
-					"= %s",
-					proxytype);
-				curl_easy_setopt(handle.ptr(),
-					CURLOPT_PROXYTYPE,
-					get_proxy_type(proxytype));
-			}
+		const std::string proxyauth =
+			cfg.get_configvalue("proxy-auth");
+		const std::string proxyauthmethod =
+			cfg.get_configvalue("proxy-auth-method");
+		if (proxyauth != "") {
+			curl_easy_setopt(handle.ptr(),
+				CURLOPT_PROXYAUTH,
+				get_auth_method(proxyauthmethod));
+			curl_easy_setopt(handle.ptr(),
+				CURLOPT_PROXYUSERPWD,
+				proxyauth.c_str());
 		}
 
-		const std::string useragent = utils::get_useragent(cfg);
-		curl_easy_setopt(handle.ptr(), CURLOPT_USERAGENT, useragent.c_str());
-
-		const unsigned int dl_timeout =
-			cfg->get_configvalue_as_int("download-timeout");
-		curl_easy_setopt(handle.ptr(), CURLOPT_TIMEOUT, dl_timeout);
-
-		const std::string cookie_cache =
-			cfg->get_configvalue("cookie-cache");
-		if (cookie_cache != "") {
+		const std::string proxytype =
+			cfg.get_configvalue("proxy-type");
+		if (proxytype != "") {
+			LOG(Level::DEBUG,
+				"utils::set_common_curl_options: "
+				"proxytype "
+				"= %s",
+				proxytype);
 			curl_easy_setopt(handle.ptr(),
-				CURLOPT_COOKIEFILE,
-				cookie_cache.c_str());
-			curl_easy_setopt(handle.ptr(),
-				CURLOPT_COOKIEJAR,
-				cookie_cache.c_str());
+				CURLOPT_PROXYTYPE,
+				get_proxy_type(proxytype));
 		}
-
-		curl_easy_setopt(handle.ptr(),
-			CURLOPT_SSL_VERIFYHOST,
-			cfg->get_configvalue_as_bool("ssl-verifyhost") ? 2 : 0);
-		curl_easy_setopt(handle.ptr(),
-			CURLOPT_SSL_VERIFYPEER,
-			cfg->get_configvalue_as_bool("ssl-verifypeer"));
 	}
 
+	const std::string useragent = utils::get_useragent(cfg);
+	curl_easy_setopt(handle.ptr(), CURLOPT_USERAGENT, useragent.c_str());
+
+	const unsigned int dl_timeout =
+		cfg.get_configvalue_as_int("download-timeout");
+	curl_easy_setopt(handle.ptr(), CURLOPT_TIMEOUT, dl_timeout);
+
+	const std::string cookie_cache =
+		cfg.get_configvalue("cookie-cache");
+	if (cookie_cache != "") {
+		curl_easy_setopt(handle.ptr(),
+			CURLOPT_COOKIEFILE,
+			cookie_cache.c_str());
+		curl_easy_setopt(handle.ptr(),
+			CURLOPT_COOKIEJAR,
+			cookie_cache.c_str());
+	}
+
+	curl_easy_setopt(handle.ptr(),
+		CURLOPT_SSL_VERIFYHOST,
+		cfg.get_configvalue_as_bool("ssl-verifyhost") ? 2 : 0);
+	curl_easy_setopt(handle.ptr(),
+		CURLOPT_SSL_VERIFYPEER,
+		cfg.get_configvalue_as_bool("ssl-verifypeer"));
+
 	curl_easy_setopt(handle.ptr(), CURLOPT_NOSIGNAL, 1);
 	// Accept all of curl's built-in encodings
 	curl_easy_setopt(handle.ptr(), CURLOPT_ACCEPT_ENCODING, "");
@@ -786,8 +773,7 @@ nonstd::optional<LinkType> utils::podcast_mime_to_link_type(
  * These callbacks are deprecated as of OpenSSL 1.1.0; see the
  * changelog: https://www.openssl.org/news/changelog.html#x6
  */
-
-#if HAVE_OPENSSL && OPENSSL_VERSION_NUMBER < 0x01010000fL
+#if HAVE_OPENSSL && OPENSSL_VERSION_NUMBER < 0x10100000L
 static std::mutex* openssl_mutexes = nullptr;
 static int openssl_mutexes_size = 0;
 
@@ -817,18 +803,23 @@ static unsigned long openssl_mth_id_function(void)
 }
 #endif
 
+/*
+ * GnuTLS 2.11.0+ uses the system availabe locking procedures and discourages
+ * setting thread locks manually. See the changelog:
+ * https://gitlab.com/gnutls/gnutls/-/blob/master/NEWS?ref_type=heads#L4521
+ * Mind the "<=" typo in the suggestion.
+ */
 void utils::initialize_ssl_implementation(void)
 {
-#if HAVE_OPENSSL && OPENSSL_VERSION_NUMBER < 0x01010000fL
+#if HAVE_OPENSSL && OPENSSL_VERSION_NUMBER < 0x10100000L
 	openssl_mutexes_size = CRYPTO_num_locks();
 	openssl_mutexes = new std::mutex[openssl_mutexes_size];
 	CRYPTO_set_id_callback(openssl_mth_id_function);
 	CRYPTO_set_locking_callback(openssl_mth_locking_function);
 #endif
 
-#if HAVE_GCRYPT
+#if HAVE_GCRYPT && GNUTLS_VERSION_NUMBER < 0x020b00
 	gcry_control(GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
-	gnutls_global_init();
 #endif
 }
 
