@@ -1,13 +1,9 @@
 #include "view.h"
 
 #include <assert.h>
-#include <cerrno>
-#include <cstdio>
 #include <cstring>
 #include <dirent.h>
-#include <fstream>
 #include <grp.h>
-#include <iomanip>
 #include <iostream>
 #include <libgen.h>
 #include <limits.h>
@@ -16,7 +12,6 @@
 #include <string.h>
 #include <sys/param.h>
 #include <sys/types.h>
-#include <time.h>
 #include <unistd.h>
 
 extern "C" {
@@ -35,7 +30,6 @@ extern "C" {
 #include "dirbrowserformaction.h"
 #include "emptyformaction.h"
 #include "empty.h"
-#include "exception.h"
 #include "feedlist.h"
 #include "feedlistformaction.h"
 #include "filebrowser.h"
@@ -44,16 +38,14 @@ extern "C" {
 #include "formaction.h"
 #include "help.h"
 #include "helpformaction.h"
-#include "htmlrenderer.h"
 #include "itemlist.h"
 #include "itemlistformaction.h"
 #include "itemview.h"
 #include "itemviewformaction.h"
+#include "keycombination.h"
 #include "keymap.h"
 #include "logger.h"
 #include "matcherexception.h"
-#include "regexmanager.h"
-#include "reloadthread.h"
 #include "rssfeed.h"
 #include "selectformaction.h"
 #include "selecttag.h"
@@ -120,7 +112,7 @@ void View::set_status(const std::string& msg)
 	auto fa = get_current_formaction();
 	if (fa != nullptr
 		&& std::dynamic_pointer_cast<EmptyFormAction>(fa) == nullptr) {
-		fa->set_value("msg", msg);
+		fa->set_status(msg);
 		fa->draw_form();
 	}
 }
@@ -157,7 +149,7 @@ int View::run()
 	bool have_macroprefix = false;
 
 	feedlist_form = std::make_shared<FeedListFormAction>(
-			this, feedlist_str, rsscache, filters, cfg, rxman);
+			*this, feedlist_str, rsscache, filters, cfg, rxman);
 	apply_colors(feedlist_form);
 	formaction_stack.push_back(feedlist_form);
 	current_formaction = formaction_stack_size() - 1;
@@ -216,15 +208,16 @@ int View::run()
 
 		LOG(Level::DEBUG, "View::run: event = %s", event);
 
+		const auto key_combination = KeyCombination::from_bindkey(event);
 		if (have_macroprefix) {
 			have_macroprefix = false;
 			status_line.show_message("");
 			LOG(Level::DEBUG,
 				"View::run: running macro `%s'",
 				event);
-			run_commands(keys->get_macro(event));
+			run_commands(keys->get_macro(key_combination));
 		} else {
-			const Operation op = keys->get_operation(event, fa->id());
+			const Operation op = keys->get_operation(key_combination, fa->id());
 
 			LOG(Level::DEBUG,
 				"View::run: event = %s op = %u",
@@ -286,7 +279,8 @@ std::string View::run_modal(std::shared_ptr<FormAction> f,
 			continue;
 		}
 
-		Operation op = keys->get_operation(event, fa->id());
+		const auto key_combination = KeyCombination::from_bindkey(event);
+		Operation op = keys->get_operation(key_combination, fa->id());
 
 		if (OP_REDRAW == op) {
 			Stfl::reset();
@@ -465,7 +459,7 @@ void View::push_searchresult(std::shared_ptr<RssFeed> feed,
 	if (feed->total_item_count() > 0) {
 		if (this->get_current_formaction()->id() != "searchresultslist") {
 			auto searchresult = std::make_shared<SearchResultsListFormAction>(
-					this, itemlist_str, rsscache, filters, cfg, rxman);
+					*this, itemlist_str, rsscache, filters, cfg, rxman);
 			apply_colors(searchresult);
 			searchresult->set_parent_formaction(get_current_formaction());
 			searchresult->add_to_history(feed, phrase);
@@ -495,7 +489,7 @@ std::shared_ptr<ItemListFormAction> View::push_itemlist(
 
 	if (feed->total_item_count() > 0) {
 		auto itemlist = std::make_shared<ItemListFormAction>(
-				this, itemlist_str, rsscache, filters, cfg, rxman);
+				*this, itemlist_str, rsscache, filters, cfg, rxman);
 		itemlist->set_feed(feed);
 		apply_colors(itemlist);
 		itemlist->set_parent_formaction(get_current_formaction());
@@ -534,7 +528,7 @@ void View::push_itemview(std::shared_ptr<RssFeed> f,
 			FormAction>(fa);
 		assert(itemlist != nullptr);
 		auto itemview = std::make_shared<ItemViewFormAction>(
-				this, itemlist, itemview_str, rsscache, cfg, rxman);
+				*this, itemlist, itemview_str, rsscache, cfg, rxman);
 		itemview->set_feed(f);
 		itemview->set_guid(guid);
 		itemview->set_parent_formaction(fa);
@@ -570,7 +564,7 @@ void View::view_dialogs()
 	auto fa = get_current_formaction();
 	if (fa != nullptr && fa->id() != "dialogs") {
 		auto dialogs = std::make_shared<DialogsFormAction>(
-				this, dialogs_str, cfg, rxman);
+				*this, dialogs_str, cfg, rxman);
 		dialogs->set_parent_formaction(fa);
 		apply_colors(dialogs);
 		dialogs->init();
@@ -584,7 +578,7 @@ void View::push_empty_formaction()
 	auto fa = get_current_formaction();
 
 	auto empty_view = std::make_shared<EmptyFormAction>(
-			this, empty_str, cfg);
+			*this, empty_str, cfg);
 	empty_view->set_parent_formaction(fa);
 	empty_view->init();
 	formaction_stack.push_back(empty_view);
@@ -596,7 +590,7 @@ void View::push_help()
 	auto fa = get_current_formaction();
 
 	auto helpview = std::make_shared<HelpFormAction>(
-			this, help_str, cfg, fa->id());
+			*this, help_str, cfg, fa->id());
 	apply_colors(helpview);
 	helpview->set_parent_formaction(fa);
 	helpview->init();
@@ -608,7 +602,7 @@ void View::push_urlview(const Links& links,
 	std::shared_ptr<RssFeed>& feed)
 {
 	auto urlview = std::make_shared<UrlViewFormAction>(
-			this, feed, urlview_str, cfg);
+			*this, feed, urlview_str, cfg);
 	apply_colors(urlview);
 	urlview->set_parent_formaction(get_current_formaction());
 	urlview->init();
@@ -620,7 +614,7 @@ void View::push_urlview(const Links& links,
 nonstd::optional<std::string> View::run_filebrowser(const std::string& default_filename)
 {
 	auto filebrowser = std::make_shared<FileBrowserFormAction>(
-			this, filebrowser_str, cfg);
+			*this, filebrowser_str, cfg);
 	apply_colors(filebrowser);
 	filebrowser->set_default_filename(default_filename);
 	filebrowser->set_parent_formaction(get_current_formaction());
@@ -634,7 +628,7 @@ nonstd::optional<std::string> View::run_filebrowser(const std::string& default_f
 nonstd::optional<std::string> View::run_dirbrowser()
 {
 	auto dirbrowser = std::make_shared<DirBrowserFormAction>(
-			this, filebrowser_str, cfg);
+			*this, filebrowser_str, cfg);
 	apply_colors(dirbrowser);
 	dirbrowser->set_parent_formaction(get_current_formaction());
 	std::string res = run_modal(dirbrowser, "filenametext");
@@ -651,7 +645,7 @@ std::string View::select_tag(const std::string& current_tag)
 		return "";
 	}
 	auto selecttag = std::make_shared<SelectFormAction>(
-			this, selecttag_str, cfg);
+			*this, selecttag_str, cfg);
 	selecttag->set_type(SelectFormAction::SelectionType::TAG);
 	apply_colors(selecttag);
 	selecttag->set_parent_formaction(get_current_formaction());
@@ -664,7 +658,7 @@ std::string View::select_tag(const std::string& current_tag)
 std::string View::select_filter(const std::vector<FilterNameExprPair>& filters)
 {
 	auto selecttag = std::make_shared<SelectFormAction>(
-			this, selecttag_str, cfg);
+			*this, selecttag_str, cfg);
 	selecttag->set_type(SelectFormAction::SelectionType::FILTER);
 	apply_colors(selecttag);
 	selecttag->set_parent_formaction(get_current_formaction());
@@ -678,9 +672,9 @@ char View::confirm(const std::string& prompt, const std::string& charset)
 	LOG(Level::DEBUG, "View::confirm: charset = %s", charset);
 
 	std::shared_ptr<FormAction> f = get_current_formaction();
-	// Push empty formaction so our "msg" is not overwritten
+	// Push empty formaction so our status message is not overwritten on form `f`
 	push_empty_formaction();
-	f->set_value("msg", prompt);
+	f->set_status(prompt);
 
 	char result = 0;
 
@@ -704,7 +698,7 @@ char View::confirm(const std::string& prompt, const std::string& charset)
 			result);
 	} while (!result || strchr(charset.c_str(), result) == nullptr);
 
-	f->set_value("msg", "");
+	f->set_status("");
 	f->draw_form();
 
 	pop_current_formaction();
@@ -1050,7 +1044,7 @@ void View::pop_current_formaction()
 			std::shared_ptr<FormAction> fa = get_current_formaction();
 			if (fa) {
 				fa->set_redraw(true);
-				fa->set_value("msg", "");
+				f->set_status("");
 				fa->recalculate_widget_dimensions();
 			}
 		}
