@@ -1,13 +1,16 @@
 #include "cache.h"
 
+#include <memory>
 #include <sstream>
 
 #include "3rd-party/catch.hpp"
 #include "configcontainer.h"
+#include "curlhandle.h"
+#include "feedretriever.h"
 #include "rssfeed.h"
 #include "rssignores.h"
 #include "rssparser.h"
-#include "test-helpers/tempfile.h"
+#include "test_helpers/tempfile.h"
 
 using namespace newsboat;
 
@@ -15,12 +18,16 @@ TEST_CASE("items in search result can be marked read", "[Cache]")
 {
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
-	RssParser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	const std::string uri = "file://data/rss.xml";
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+	RssParser parser(uri, rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(uri));
 	REQUIRE(feed->total_item_count() == 8);
 	rsscache.externalize_rssfeed(feed, false);
 
-	auto search_items = rsscache.search_for_items("Botox", "");
+	RssIgnores ign;
+	auto search_items = rsscache.search_for_items("Botox", "", ign);
 	REQUIRE(search_items.size() == 1);
 	auto item = search_items.front();
 	REQUIRE(item->unread());
@@ -28,7 +35,7 @@ TEST_CASE("items in search result can be marked read", "[Cache]")
 	item->set_unread(false);
 	search_items.clear();
 
-	search_items = rsscache.search_for_items("Botox", "");
+	search_items = rsscache.search_for_items("Botox", "", ign);
 	REQUIRE(search_items.size() == 1);
 	auto updatedItem = search_items.front();
 	REQUIRE_FALSE(updatedItem->unread());
@@ -36,12 +43,14 @@ TEST_CASE("items in search result can be marked read", "[Cache]")
 
 TEST_CASE("Cleaning old articles works", "[Cache]")
 {
-	TestHelpers::TempFile dbfile;
-	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), cfg.get()));
-	RssParser parser(
-		"file://data/rss.xml", rsscache.get(), cfg.get(), nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	test_helpers::TempFile dbfile;
+	auto cfg = std::make_unique<ConfigContainer>();
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	const std::string uri = "file://data/rss.xml";
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
+	RssParser parser(uri, *rsscache, *cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(uri));
 
 	/* Adding a fresh item that won't be deleted. If it survives the test,
 	 * we will know that "keep-articles-days" really deletes the old
@@ -51,7 +60,7 @@ TEST_CASE("Cleaning old articles works", "[Cache]")
 	item->set_link("http://example.com/item");
 	item->set_guid("http://example.com/item");
 	item->set_author("Newsboat Testsuite");
-	item->set_description("");
+	item->set_description("", "");
 	item->set_pubDate(time(nullptr)); // current time
 	item->set_unread(true);
 	feed->add_item(item);
@@ -65,9 +74,9 @@ TEST_CASE("Cleaning old articles works", "[Cache]")
 	 *
 	 * The value of 42 days is sufficient because the items in the test feed
 	 * are dating back to 2006. */
-	cfg.reset(new ConfigContainer());
+	cfg = std::make_unique<ConfigContainer>();
 	cfg->set_configvalue("keep-articles-days", "42");
-	rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 	feed = rsscache->internalize_rssfeed("file://data/rss.xml", nullptr);
 
 	/* The important part: old articles should be gone, new one remains. */
@@ -76,12 +85,14 @@ TEST_CASE("Cleaning old articles works", "[Cache]")
 
 TEST_CASE("Last-Modified and ETag values are persisted to DB", "[Cache]")
 {
-	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
-	TestHelpers::TempFile dbfile;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), cfg.get()));
+	auto cfg = std::make_unique<ConfigContainer>();
+	test_helpers::TempFile dbfile;
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 	const auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, *cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	rsscache->externalize_rssfeed(feed, false);
 
 	/* We will run this lambda on different inputs to check different
@@ -93,8 +104,8 @@ TEST_CASE("Last-Modified and ETag values are persisted to DB", "[Cache]")
 		REQUIRE_NOTHROW(rsscache->update_lastmodified(
 				feedurl, last_modified, etag));
 
-		cfg.reset(new ConfigContainer());
-		rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+		cfg = std::make_unique<ConfigContainer>();
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 
 		/* Scrambling the value to make sure the following call changes
 		 * it. */
@@ -130,7 +141,7 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 
-	test_feed = std::make_shared<RssFeed>(&rsscache);
+	test_feed = std::make_shared<RssFeed>(&rsscache, "");
 	test_feed->set_title("Test feed");
 	auto test_feed_url = "http://example.com/atom.xml";
 	test_feed->set_link(test_feed_url);
@@ -144,8 +155,10 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 	/* Ensure that the feeds contain expected number of items, then
 	 * externalize them (put into Cache). */
 	for (const auto& feed_data : feeds) {
-		RssParser parser(feed_data.first, &rsscache, &cfg, nullptr);
-		feed = parser.parse();
+		CurlHandle easyHandle;
+		FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+		RssParser parser(feed_data.first, rsscache, cfg, nullptr);
+		feed = parser.parse(feed_retriever.retrieve(feed_data.first));
 		REQUIRE(feed->total_item_count() == feed_data.second);
 
 		test_feed->add_item(feed->items()[0]);
@@ -232,18 +245,20 @@ TEST_CASE(
 	"and `delete-read-articles-on-quit` settings",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 
 	std::vector<std::string> feedurls = {
 		"file://data/rss.xml", "file://data/atom10_1.xml"
 	};
 
 	std::vector<std::shared_ptr<RssFeed>> feeds;
-	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), cfg.get()));
+	auto cfg = std::make_unique<ConfigContainer>();
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 	for (const auto& url : feedurls) {
-		RssParser parser(url, rsscache.get(), cfg.get(), nullptr);
-		std::shared_ptr<RssFeed> feed = parser.parse();
+		CurlHandle easyHandle;
+		FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
+		RssParser parser(url, *rsscache, *cfg, nullptr);
+		auto feed = parser.parse(feed_retriever.retrieve(url));
 		feeds.push_back(feed);
 		rsscache->externalize_rssfeed(feed, false);
 	}
@@ -252,8 +267,8 @@ TEST_CASE(
 		cfg->set_configvalue("cleanup-on-quit", "no");
 		rsscache->cleanup_cache(feeds);
 
-		cfg.reset(new ConfigContainer());
-		rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+		cfg = std::make_unique<ConfigContainer>();
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 
 		for (const auto& url : feedurls) {
 			std::shared_ptr<RssFeed> feed =
@@ -271,8 +286,8 @@ TEST_CASE(
 			feeds.erase(feeds.cbegin(), feeds.cbegin() + 1);
 			rsscache->cleanup_cache(feeds);
 
-			cfg.reset(new ConfigContainer());
-			rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+			cfg = std::make_unique<ConfigContainer>();
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 
 			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
@@ -292,8 +307,49 @@ TEST_CASE(
 
 			rsscache->cleanup_cache(feeds);
 
-			cfg.reset(new ConfigContainer());
-			rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+			cfg = std::make_unique<ConfigContainer>();
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+
+			std::shared_ptr<RssFeed> feed =
+				rsscache->internalize_rssfeed(
+					feedurls[0], nullptr);
+			REQUIRE(feed->total_item_count() == 6);
+		}
+	}
+
+	SECTION("cache will be cleaned up when `always_clean == true`, even if cleanup-on-quit is set to \"no\"") {
+		cfg->set_configvalue("cleanup-on-quit", "no");
+		const bool always_clean = true;
+
+		SECTION("delete-read-articles-on-quit set to \"no\"") {
+			/* Drop first feed; it should now be removed from the
+			 * Cache, too. */
+			feeds.erase(feeds.cbegin(), feeds.cbegin() + 1);
+			rsscache->cleanup_cache(feeds, always_clean);
+
+			cfg = std::make_unique<ConfigContainer>();
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+
+			std::shared_ptr<RssFeed> feed =
+				rsscache->internalize_rssfeed(
+					feedurls[0], nullptr);
+			REQUIRE(feed->total_item_count() == 0);
+			feed = rsscache->internalize_rssfeed(
+					feedurls[1], nullptr);
+			REQUIRE(feed->total_item_count() != 0);
+		}
+
+		SECTION("delete-read-articles-on-quit set to \"yes\"") {
+			cfg->set_configvalue(
+				"delete-read-articles-on-quit", "yes");
+			REQUIRE(feeds[0]->total_item_count() == 8);
+			feeds[0]->items()[0]->set_unread(false);
+			feeds[0]->items()[1]->set_unread(false);
+
+			rsscache->cleanup_cache(feeds, always_clean);
+
+			cfg = std::make_unique<ConfigContainer>();
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 
 			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
@@ -308,34 +364,38 @@ TEST_CASE("fetch_descriptions fills out feed item's descriptions", "[Cache]")
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 	const auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, &rsscache, &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+	RssParser parser(feedurl, rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 
 	rsscache.externalize_rssfeed(feed, false);
 
 	for (auto& item : feed->items()) {
-		item->set_description("your test failed!");
+		item->set_description("your test failed!", "text/plain");
 	}
 
 	REQUIRE_NOTHROW(rsscache.fetch_descriptions(feed.get()));
 
 	for (auto& item : feed->items()) {
-		REQUIRE(item->description() != "your test failed!");
+		REQUIRE(item->description().text != "your test failed!");
 	}
 }
 
 TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 
 	// We'll keep our own count of which GUIDs are unread
 	std::unordered_set<std::string> read_guids;
-	std::unique_ptr<RssParser> parser(new RssParser(
-			"file://data/rss.xml", rsscache.get(), &cfg, nullptr));
-	std::shared_ptr<RssFeed> feed = parser->parse();
+	const std::string uri1 = "file://data/rss.xml";
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	auto parser = std::make_unique<RssParser>(uri1, *rsscache, cfg, nullptr);
+	auto feed = parser->parse(feed_retriever.retrieve(uri1));
 
 	auto mark_read = [&read_guids](std::shared_ptr<RssItem> item) {
 		item->set_unread(false);
@@ -367,9 +427,9 @@ TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 
 	// Let's add another article to make sure get_unread_count looks at all
 	// feeds present in the Cache
-	parser.reset(new RssParser(
-			"file://data/atom10_1.xml", rsscache.get(), &cfg, nullptr));
-	feed = parser->parse();
+	const std::string uri2 = "file://data/atom10_1.xml";
+	parser = std::make_unique<RssParser>(uri2, *rsscache, cfg, nullptr);
+	feed = parser->parse(feed_retriever.retrieve(uri2));
 	mark_read(feed->items()[0]);
 	mark_read(feed->items()[2]);
 
@@ -379,7 +439,7 @@ TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 
 	// Lastly, let's make sure the info is indeed retrieved from the
 	// database and isn't just stored in the Cache object
-	rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	INFO("Testing on two feeds with new `Cache` object");
 	check(rsscache->get_read_item_guids());
 }
@@ -387,12 +447,14 @@ TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 TEST_CASE("mark_item_deleted changes \"deleted\" flag of item with given GUID ",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 
 	auto item = feed->items()[1];
 	auto guid = item->guid();
@@ -400,7 +462,7 @@ TEST_CASE("mark_item_deleted changes \"deleted\" flag of item with given GUID ",
 	rsscache->externalize_rssfeed(feed, false);
 	rsscache->mark_item_deleted(guid, true);
 
-	rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	// One item was deleted, so shouldn't have been loaded
 	REQUIRE(feed->total_item_count() == 7);
@@ -409,12 +471,14 @@ TEST_CASE("mark_item_deleted changes \"deleted\" flag of item with given GUID ",
 TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 
 	REQUIRE(feed->unread_item_count() == 8);
 
@@ -423,7 +487,7 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 
 		REQUIRE_NOTHROW(rsscache->mark_items_read_by_guid({}));
 
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->unread_item_count() == 8);
 	}
@@ -436,7 +500,7 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 
 		REQUIRE_NOTHROW(rsscache->mark_items_read_by_guid(guids));
 
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->unread_item_count() == 6);
 	}
@@ -450,8 +514,10 @@ TEST_CASE(
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 	auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, &rsscache, &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+	RssParser parser(feedurl, rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 
 	REQUIRE(feed->total_item_count() == 8);
 
@@ -504,8 +570,10 @@ TEST_CASE("search_for_items finds all items with matching title or content",
 		"file://data/atom10_1.xml", "file://data/rss20_1.xml"
 	};
 	for (const auto& url : feedurls) {
-		RssParser parser(url, &rsscache, &cfg, nullptr);
-		std::shared_ptr<RssFeed> feed = parser.parse();
+		CurlHandle easyHandle;
+		FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+		RssParser parser(url, rsscache, cfg, nullptr);
+		auto feed = parser.parse(feed_retriever.retrieve(url));
 
 		rsscache.externalize_rssfeed(feed, false);
 	}
@@ -513,18 +581,19 @@ TEST_CASE("search_for_items finds all items with matching title or content",
 	auto query = "content";
 	std::vector<std::shared_ptr<RssItem>> items;
 
+	RssIgnores ign;
 	SECTION("Search the whole DB") {
-		REQUIRE_NOTHROW(items = rsscache.search_for_items(query, ""));
+		REQUIRE_NOTHROW(items = rsscache.search_for_items(query, "", ign));
 		REQUIRE(items.size() == 4);
 	}
 
 	SECTION("Search specific feed") {
 		REQUIRE_NOTHROW(
-			items = rsscache.search_for_items(query, feedurls[0]));
+			items = rsscache.search_for_items(query, feedurls[0], ign));
 		REQUIRE(items.size() == 3);
 
 		REQUIRE_NOTHROW(
-			items = rsscache.search_for_items(query, feedurls[1]));
+			items = rsscache.search_for_items(query, feedurls[1], ign));
 		REQUIRE(items.size() == 1);
 	}
 }
@@ -532,19 +601,21 @@ TEST_CASE("search_for_items finds all items with matching title or content",
 TEST_CASE("update_rssitem_flags dumps `rss_item` object's flags to DB",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	const auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	rsscache->externalize_rssfeed(feed, false);
 
 	auto item = feed->items()[0];
 	item->set_flags("abc");
 	REQUIRE_NOTHROW(rsscache->update_rssitem_flags(item.get()));
 
-	rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	feed = rsscache->internalize_rssfeed("file://data/rss.xml", nullptr);
 
 	REQUIRE(feed->items()[0]->flags() == "abc");
@@ -555,12 +626,14 @@ TEST_CASE(
 	"\"enqueued\" fields",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	const auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 
 	auto item = feed->items()[0];
 
@@ -572,7 +645,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 				item, feedurl));
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE_FALSE(feed->items()[0]->unread());
@@ -584,7 +657,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 				item, feedurl));
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE(feed->items()[0]->enqueued());
@@ -598,7 +671,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 				item, feedurl));
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE_FALSE(feed->items()[0]->unread());
@@ -635,7 +708,8 @@ TEST_CASE(
 			REQUIRE((*fst_it)->title() == (*snd_it)->title());
 			REQUIRE((*fst_it)->link() == (*snd_it)->link());
 			REQUIRE((*fst_it)->author() == (*snd_it)->author());
-			REQUIRE((*fst_it)->description() == (*snd_it)->description());
+			REQUIRE((*fst_it)->description().text == (*snd_it)->description().text);
+			REQUIRE((*fst_it)->description().mime == (*snd_it)->description().mime);
 			REQUIRE((*fst_it)->size() == (*snd_it)->size());
 			REQUIRE((*fst_it)->length() == (*snd_it)->length());
 			REQUIRE((*fst_it)->pubDate() == (*snd_it)->pubDate());
@@ -653,12 +727,14 @@ TEST_CASE(
 		}
 	};
 
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	const auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	auto initial_feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
+	auto initial_feed = parser.parse(feed_retriever.retrieve(feedurl));
 	initial_feed->load();
 	initial_feed->unload();
 	initial_feed->load();
@@ -666,7 +742,7 @@ TEST_CASE(
 	SECTION("Simple case") {
 		rsscache->externalize_rssfeed(initial_feed, false);
 
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		auto new_feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		new_feed->load();
 
@@ -678,7 +754,7 @@ TEST_CASE(
 		rsscache->externalize_rssfeed(initial_feed, false);
 		rsscache->externalize_rssfeed(initial_feed, false);
 
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		auto new_feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		new_feed->load();
 
@@ -689,19 +765,21 @@ TEST_CASE(
 TEST_CASE("externalize_rssfeed doesn't store more than `max-items` items",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
-	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), cfg.get()));
+	test_helpers::TempFile dbfile;
+	auto cfg = std::make_unique<ConfigContainer>();
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 
 	cfg->set_configvalue("max-items", "3");
 	const auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
-	auto feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, *cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	REQUIRE(feed->total_item_count() == 8);
 	rsscache->externalize_rssfeed(feed, false);
 
-	cfg.reset(new ConfigContainer());
-	rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+	cfg = std::make_unique<ConfigContainer>();
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	REQUIRE(feed->total_item_count() == 3);
 }
@@ -716,21 +794,23 @@ TEST_CASE(
 	"not counting the flagged ones",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
-	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), cfg.get()));
+	test_helpers::TempFile dbfile;
+	auto cfg = std::make_unique<ConfigContainer>();
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 
 	const auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
-	auto feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, *cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	REQUIRE(feed->total_item_count() == 8);
 
 	SECTION("no flagged items") {
 		rsscache->externalize_rssfeed(feed, false);
 
-		cfg.reset(new ConfigContainer());
+		cfg = std::make_unique<ConfigContainer>();
 		cfg->set_configvalue("max-items", "3");
-		rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->total_item_count() == 3);
 	}
@@ -742,9 +822,9 @@ TEST_CASE(
 		rsscache->update_rssitem_flags(feed->items()[0].get());
 		rsscache->update_rssitem_flags(feed->items()[1].get());
 
-		cfg.reset(new ConfigContainer());
+		cfg = std::make_unique<ConfigContainer>();
 		cfg->set_configvalue("max-items", "1");
-		rsscache.reset(new Cache(dbfile.get_path(), cfg.get()));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		// All flagged items should be present no matter what
 		unsigned int flagged_count = 0;
@@ -777,8 +857,10 @@ TEST_CASE("internalize_rssfeed doesn't return items that are ignored",
 	Cache rsscache(":memory:", &cfg);
 
 	const std::string feedurl("file://data/rss092_1.xml");
-	RssParser parser(feedurl, &rsscache, &cfg, nullptr);
-	auto feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+	RssParser parser(feedurl, rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	REQUIRE(feed->total_item_count() == 3);
 	rsscache.externalize_rssfeed(feed, false);
 
@@ -796,32 +878,34 @@ TEST_CASE(
 	"changed and reset_unread = \"yes\"",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	feed->items()[0]->set_unread_nowrite(false);
 	rsscache->externalize_rssfeed(feed, false);
 
-	rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	feed->load();
 	REQUIRE_FALSE(feed->items()[0]->unread());
 	feed->items()[0]->set_unread_nowrite(true);
-	feed->items()[0]->set_description("changed!");
+	feed->items()[0]->set_description("changed!", "text/plain");
 
 	SECTION("reset_unread = false; item remains read") {
 		rsscache->externalize_rssfeed(feed, false);
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE_FALSE(feed->items()[0]->unread());
 	}
 
 	SECTION("reset_unread = true; item becomes unread") {
 		rsscache->externalize_rssfeed(feed, true);
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->items()[0]->unread());
 	}
@@ -832,23 +916,25 @@ TEST_CASE(
 	"is set",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	auto feedurl = "file://data/rss.xml";
-	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	feed->items()[0]->set_unread_nowrite(false);
 	rsscache->externalize_rssfeed(feed, false);
 
-	rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	auto item = feed->items()[0];
 	item->set_unread_nowrite(true);
 
 	SECTION("override_unread not set; item remains read") {
 		rsscache->externalize_rssfeed(feed, false);
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE_FALSE(feed->items()[0]->unread());
 	}
@@ -856,7 +942,7 @@ TEST_CASE(
 	SECTION("override_unread is set; item becomes unread") {
 		item->set_override_unread(true);
 		rsscache->externalize_rssfeed(feed, false);
-		rsscache.reset(new Cache(dbfile.get_path(), &cfg));
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->items()[0]->unread());
 	}
@@ -867,13 +953,12 @@ TEST_CASE(
 	"when passed a query feed",
 	"[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
 
-	auto feed = std::make_shared<RssFeed>(rsscache.get());
-	feed->set_query("unread = \"yes\"");
-	feed->set_rssurl("query:All unread:unread = \"yes\"");
+	auto feed = std::make_shared<RssFeed>(rsscache.get(),
+			"query:All unread:unread = \"yes\"");
 
 	REQUIRE_NOTHROW(rsscache->externalize_rssfeed(feed, false));
 
@@ -891,7 +976,7 @@ TEST_CASE(
 	};
 	std::unique_ptr<sqlite3, sqlite_deleter> db;
 
-	// Open the database and manuever the pointer into our unique_ptr (which
+	// Open the database and maneuver the pointer into our unique_ptr (which
 	// can't be done by direct assignment because sqlite3_open doesn't
 	// return that pointer)
 	sqlite3* dbptr = nullptr;
@@ -924,11 +1009,14 @@ TEST_CASE(
 
 TEST_CASE("do_vacuum doesn't throw an exception", "[Cache]")
 {
-	TestHelpers::TempFile dbfile;
+	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
-	RssParser parser("file://data/rss.xml", rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	const std::string uri = "file://data/rss.xml";
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(uri, *rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(uri));
 	rsscache->externalize_rssfeed(feed, false);
 
 	REQUIRE_NOTHROW(rsscache->do_vacuum());
@@ -942,32 +1030,27 @@ TEST_CASE("search_in_items returns items that contain given substring",
 {
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
-	RssParser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	const std::string uri = "file://data/rss.xml";
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+	RssParser parser(uri, rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(uri));
 	REQUIRE(feed->total_item_count() == 8);
 	rsscache.externalize_rssfeed(feed, false);
 
 	using guids = std::unordered_set<std::string>;
 
 	const guids matching_guids{
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"115822000722667899",
+		"http://www.blogger.com/feeds/33750310/posts/full/115822000722667899",
 	};
 	const guids non_matching_guids{
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"115720132609158191",
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"115868412707787974",
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"115902176438316101",
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"115934092675971946",
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"115954641079726548",
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"116026794030557608",
-		"http://www.blogger.com/feeds/33750310/posts/full/"
-		"116665092831467603",
+		"http://www.blogger.com/feeds/33750310/posts/full/115720132609158191",
+		"http://www.blogger.com/feeds/33750310/posts/full/115868412707787974",
+		"http://www.blogger.com/feeds/33750310/posts/full/115902176438316101",
+		"http://www.blogger.com/feeds/33750310/posts/full/115934092675971946",
+		"http://www.blogger.com/feeds/33750310/posts/full/115954641079726548",
+		"http://www.blogger.com/feeds/33750310/posts/full/116026794030557608",
+		"http://www.blogger.com/feeds/33750310/posts/full/116665092831467603",
 	};
 
 	guids guids_from_feed;
@@ -990,8 +1073,11 @@ TEST_CASE("search_in_items returns empty set if input set is empty", "[Cache]")
 {
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
-	RssParser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
-	std::shared_ptr<RssFeed> feed = parser.parse();
+	const std::string uri = "file://data/rss.xml";
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+	RssParser parser(uri, rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(uri));
 	rsscache.externalize_rssfeed(feed, false);
 
 	using guids = std::unordered_set<std::string>;
@@ -999,3 +1085,25 @@ TEST_CASE("search_in_items returns empty set if input set is empty", "[Cache]")
 	const guids result = rsscache.search_in_items("Botox", empty);
 	REQUIRE(result.empty());
 }
+
+TEST_CASE("Ignoring articles in search", "[Cache]")
+{
+	ConfigContainer cfg{};
+	Cache rsscache(":memory:", &cfg);
+
+	const std::string uri = "file://data/rss.xml";
+	CurlHandle easyHandle;
+	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
+	RssParser parser(uri, rsscache, cfg, nullptr);
+	auto feed = parser.parse(feed_retriever.retrieve(uri));
+	REQUIRE(feed->total_item_count() == 8);
+	rsscache.externalize_rssfeed(feed, false);
+
+	RssIgnores ign, empty_ign;
+	ign.handle_action("ignore-article", {"*", "title =~ \"Botox\""});
+	auto search_items = rsscache.search_for_items("Botox", "", ign);
+	auto no_ignore_items = rsscache.search_for_items("Botox", "", empty_ign);
+
+	REQUIRE(search_items.size() == 0 );
+	REQUIRE(no_ignore_items.size() == 1);
+}
