@@ -1,6 +1,5 @@
 #include "htmlrenderer.h"
 
-#include <fstream>
 #include <sstream>
 
 #include "3rd-party/catch.hpp"
@@ -82,30 +81,26 @@ TEST_CASE(
 {
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	rnd.render("<a href=\"http://slashdot.org/\">slashdot</a>",
 		lines,
 		links,
 		"");
 
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 
 	REQUIRE(lines[0] == p(LineType::wrappable, "<u>slashdot</>[1]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] ==
-		p(LineType::softwrappable, "[1]: http://slashdot.org/ (link)"));
 
-	REQUIRE(links[0].first == "http://slashdot.org/");
-	REQUIRE(links[0].second == LinkType::HREF);
+	REQUIRE(links[0].url == "http://slashdot.org/");
+	REQUIRE(links[0].type == LinkType::HREF);
 }
 
 TEST_CASE("<br>, <br/> and <br /> result in a line break", "[HtmlRenderer]")
 {
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	for (std::string tag : {
 			"<br>", "<br/>", "<br />"
@@ -124,7 +119,7 @@ TEST_CASE("Superscript is rendered with caret symbol", "[HtmlRenderer]")
 {
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	rnd.render("3<sup>10</sup>", lines, links, "");
 	REQUIRE(lines.size() == 1);
@@ -135,7 +130,7 @@ TEST_CASE("Subscript is rendered with square brackets", "[HtmlRenderer]")
 {
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	rnd.render("A<sub>i</sub>", lines, links, "");
 	REQUIRE(lines.size() == 1);
@@ -146,7 +141,7 @@ TEST_CASE("Script tags are ignored", "[HtmlRenderer]")
 {
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	rnd.render("abc<script></script>", lines, links, "");
 	REQUIRE(lines.size() == 1);
@@ -206,12 +201,12 @@ TEST_CASE("links with same URL are coalesced under one number",
 		"<a href='http://example.com/about'>About us</a>"
 		"<a href='http://example.com/about'>Another link</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "http://example.com/about");
-	REQUIRE(links[0].second == LinkType::HREF);
+	REQUIRE(links[0].url == "http://example.com/about");
+	REQUIRE(links[0].type == LinkType::HREF);
 }
 
 TEST_CASE("links with different URLs have different numbers", "[HtmlRenderer]")
@@ -222,14 +217,14 @@ TEST_CASE("links with different URLs have different numbers", "[HtmlRenderer]")
 		"<a href='http://example.com/one'>One</a>"
 		"<a href='http://example.com/two'>Two</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(links.size() == 2);
-	REQUIRE(links[0].first == "http://example.com/one");
-	REQUIRE(links[0].second == LinkType::HREF);
-	REQUIRE(links[1].first == "http://example.com/two");
-	REQUIRE(links[1].second == LinkType::HREF);
+	REQUIRE(links[0].url == "http://example.com/one");
+	REQUIRE(links[0].type == LinkType::HREF);
+	REQUIRE(links[1].url == "http://example.com/two");
+	REQUIRE(links[1].type == LinkType::HREF);
 }
 
 TEST_CASE("link without `href' is neither highlighted nor added to links list",
@@ -239,7 +234,7 @@ TEST_CASE("link without `href' is neither highlighted nor added to links list",
 
 	const std::string input = "<a>test</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -255,7 +250,7 @@ TEST_CASE(
 
 	const std::string input = "<a href=''>test</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -269,7 +264,7 @@ TEST_CASE("<strong> is rendered in bold font", "[HtmlRenderer]")
 
 	const std::string input = "<strong>test</strong>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -282,7 +277,7 @@ TEST_CASE("<u> is rendered as underlined text", "[HtmlRenderer]")
 
 	const std::string input = "<u>test</u>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -295,7 +290,7 @@ TEST_CASE("<q> is rendered as text in quotes", "[HtmlRenderer]")
 
 	const std::string input = "<q>test</q>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -311,19 +306,15 @@ TEST_CASE("Flash <embed>s are added to links if `src' is set", "[HtmlRenderer]")
 		"src='http://example.com/game.swf'>"
 		"</embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[embedded flash: 1]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] ==
-		p(LineType::softwrappable,
-			"[1]: http://example.com/game.swf (embedded flash)"));
+
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "http://example.com/game.swf");
-	REQUIRE(links[0].second == LinkType::EMBED);
+	REQUIRE(links[0].url == "http://example.com/game.swf");
+	REQUIRE(links[0].type == LinkType::EMBED);
 }
 
 TEST_CASE("Flash <embed>s are ignored if `src' is not set", "[HtmlRenderer]")
@@ -333,7 +324,7 @@ TEST_CASE("Flash <embed>s are ignored if `src' is not set", "[HtmlRenderer]")
 	const std::string input =
 		"<embed type='application/x-shockwave-flash'></embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 0);
@@ -348,7 +339,7 @@ TEST_CASE("non-flash <embed>s are ignored", "[HtmlRenderer]")
 		"<embed type='whatever'"
 		"src='http://example.com/thingy'></embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 0);
@@ -362,7 +353,7 @@ TEST_CASE("<embed>s are ignored if `type' is not set", "[HtmlRenderer]")
 	const std::string input =
 		"<embed src='http://example.com/yet.another.thingy'></embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 0);
@@ -377,18 +368,15 @@ TEST_CASE("<iframe>s are added to links if `src' is set", "[HtmlRenderer]")
 		"<iframe src=\"https://www.youtube.com/embed/0123456789A\""
 		"        width=\"640\" height=\"360\"></iframe>");
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, ""));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[iframe 1 (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: https://www.youtube.com/embed/0123456789A (iframe)"));
+
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "https://www.youtube.com/embed/0123456789A");
-	REQUIRE(links[0].second == LinkType::IFRAME);
+	REQUIRE(links[0].url == "https://www.youtube.com/embed/0123456789A");
+	REQUIRE(links[0].type == LinkType::IFRAME);
 }
 
 TEST_CASE("<iframe>s are rendered with a title if `title' is set",
@@ -400,19 +388,16 @@ TEST_CASE("<iframe>s are rendered with a title if `title' is set",
 		"<iframe src=\"https://www.youtube.com/embed/0123456789A\""
 		"        title=\"My Video\" width=\"640\" height=\"360\"></iframe>");
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, ""));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable,
 			"[iframe 1: My Video (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: https://www.youtube.com/embed/0123456789A (iframe)"));
+
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "https://www.youtube.com/embed/0123456789A");
-	REQUIRE(links[0].second == LinkType::IFRAME);
+	REQUIRE(links[0].url == "https://www.youtube.com/embed/0123456789A");
+	REQUIRE(links[0].type == LinkType::IFRAME);
 }
 
 TEST_CASE("<iframe>s are ignored if `src' is not set", "[HtmlRenderer]")
@@ -422,7 +407,7 @@ TEST_CASE("<iframe>s are ignored if `src' is not set", "[HtmlRenderer]")
 	const std::string input(
 		"<iframe width=\"640\" height=\"360\"></iframe>");
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, ""));
 	REQUIRE(lines.size() == 0);
@@ -441,7 +426,7 @@ TEST_CASE("spaces and line breaks are preserved inside <pre>", "[HtmlRenderer]")
 		"neat huh?\n"
 		"</pre>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 5);
@@ -464,7 +449,7 @@ TEST_CASE("tags still work inside <pre>", "[HtmlRenderer]")
 		"<u>underlined text</u>"
 		"</pre>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -483,7 +468,7 @@ TEST_CASE("line breaks are preserved in tags inside <pre>", "[HtmlRenderer]")
 		"very cool</span><span>very cool indeed\n\n\n"
 		"</span></pre>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
@@ -501,19 +486,15 @@ TEST_CASE("<img> results in a placeholder and a link", "[HtmlRenderer]")
 	const std::string input =
 		"<img src='http://example.com/image.png'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1 (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] ==
-		p(LineType::softwrappable,
-			"[1]: http://example.com/image.png (image)"));
+
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "http://example.com/image.png");
-	REQUIRE(links[0].second == LinkType::IMG);
+	REQUIRE(links[0].url == "http://example.com/image.png");
+	REQUIRE(links[0].type == LinkType::IMG);
 }
 
 TEST_CASE(
@@ -528,23 +509,18 @@ TEST_CASE(
 		" and an image: "
 		"<img src='http://example.com/image.png'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 5);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable,
 			"<u>My Page</>[1] and an image: [image 1 (link #2)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: http://example.com/index.html (link)"));
-	REQUIRE(lines[4] == p(LineType::softwrappable,
-			"[2]: http://example.com/image.png (image)"));
+
 	REQUIRE(links.size() == 2);
-	REQUIRE(links[0].first == "http://example.com/index.html");
-	REQUIRE(links[0].second == LinkType::HREF);
-	REQUIRE(links[1].first == "http://example.com/image.png");
-	REQUIRE(links[1].second == LinkType::IMG);
+	REQUIRE(links[0].url == "http://example.com/index.html");
+	REQUIRE(links[0].type == LinkType::HREF);
+	REQUIRE(links[1].url == "http://example.com/image.png");
+	REQUIRE(links[1].type == LinkType::IMG);
 }
 
 TEST_CASE(
@@ -558,16 +534,14 @@ TEST_CASE(
 		"<img src=''></img>"
 		"<img src='http://example.com/image.png'>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1 (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: http://example.com/image.png (image)"));
 	REQUIRE(links.size() == 1);
+	REQUIRE(links[0].url == "http://example.com/image.png");
+	REQUIRE(links[0].type == LinkType::IMG);
 }
 
 TEST_CASE("alt is mentioned in placeholder if <img> has `alt'",
@@ -579,19 +553,15 @@ TEST_CASE("alt is mentioned in placeholder if <img> has `alt'",
 		"<img src='http://example.com/image.png'"
 		"alt='Just a test image'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable,
 			"[image 1: Just a test image (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: http://example.com/image.png (image)"));
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "http://example.com/image.png");
-	REQUIRE(links[0].second == LinkType::IMG);
+	REQUIRE(links[0].url == "http://example.com/image.png");
+	REQUIRE(links[0].type == LinkType::IMG);
 }
 
 TEST_CASE("alt is mentioned in placeholder if <img> has `alt' and `title",
@@ -603,19 +573,15 @@ TEST_CASE("alt is mentioned in placeholder if <img> has `alt' and `title",
 		"<img src='http://example.com/image.png'"
 		"alt='Just a test image' title='Image title'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable,
 			"[image 1: Just a test image (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: http://example.com/image.png (image)"));
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "http://example.com/image.png");
-	REQUIRE(links[0].second == LinkType::IMG);
+	REQUIRE(links[0].url == "http://example.com/image.png");
+	REQUIRE(links[0].type == LinkType::IMG);
 }
 
 TEST_CASE(
@@ -628,20 +594,15 @@ TEST_CASE(
 		"<img src='http://example.com/image.png'"
 		"title='Just a test image'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] ==
 		p(LineType::wrappable, "[image 1: Just a test image (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] ==
-		p(LineType::softwrappable,
-			"[1]: http://example.com/image.png (image)"));
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "http://example.com/image.png");
-	REQUIRE(links[0].second == LinkType::IMG);
+	REQUIRE(links[0].url == "http://example.com/image.png");
+	REQUIRE(links[0].type == LinkType::IMG);
 }
 
 TEST_CASE(
@@ -656,18 +617,14 @@ TEST_CASE(
 		"AAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO"
 		"9TXL0Y4OHwAAAABJRU5ErkJggg==' alt='Red dot' />";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1: Red dot (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] ==
-		p(LineType::softwrappable, "[1]: inline image (image)"));
 	REQUIRE(links.size() == 1);
-	REQUIRE(links[0].first == "inline image");
-	REQUIRE(links[0].second == LinkType::IMG);
+	REQUIRE(links[0].url == "inline image");
+	REQUIRE(links[0].type == LinkType::IMG);
 }
 
 TEST_CASE(
@@ -683,26 +640,20 @@ TEST_CASE(
 		"<p>Check out <a href='https://attachment.zip'>this amazing site</a>!</p>"
 		"<iframe src='https://attachment.zip'></iframe>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 9);
+	REQUIRE(lines.size() == 5);
 	REQUIRE(lines[0] == p(LineType::wrappable, "<u>[image 1 (link #1)]</>[1]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, ""));
 	REQUIRE(lines[2] == p(LineType::wrappable, "Check out <u>this amazing site</>[2]!"));
 	REQUIRE(lines[3] == p(LineType::wrappable, ""));
 	REQUIRE(lines[4] == p(LineType::wrappable, "[iframe 1 (link #2)]"));
-	REQUIRE(lines[5] == p(LineType::wrappable, ""));
-	REQUIRE(lines[6] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[7] ==
-		p(LineType::softwrappable, "[1]: https://example.com/test.jpg (image)"));
-	REQUIRE(lines[8] ==
-		p(LineType::softwrappable, "[2]: https://attachment.zip/ (iframe)"));
 	REQUIRE(links.size() == 2);
-	REQUIRE(links[0].first == "https://example.com/test.jpg");
-	REQUIRE(links[0].second == LinkType::IMG);
-	REQUIRE(links[1].first == "https://attachment.zip/");
-	REQUIRE(links[1].second == LinkType::IFRAME);
+	REQUIRE(links[0].url == "https://example.com/test.jpg");
+	REQUIRE(links[0].type == LinkType::IMG);
+	REQUIRE(links[1].url == "https://attachment.zip/");
+	REQUIRE(links[1].type == LinkType::IFRAME);
 }
 
 TEST_CASE("<blockquote> is indented and is separated by empty lines",
@@ -717,7 +668,7 @@ TEST_CASE("<blockquote> is indented and is separated by empty lines",
 		"&mdash;Randy Pausch"
 		"</blockquote>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 3);
@@ -747,7 +698,7 @@ TEST_CASE(
 		"<dd>Soldier's friend</dd>"
 		"</dl>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 8);
@@ -766,7 +717,7 @@ TEST_CASE("<h[2-6]> and <p>", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	SECTION("<h1> is rendered with setext-style underlining") {
 		const std::string input = "<h1>Why are we here?</h1>";
@@ -858,7 +809,7 @@ TEST_CASE("whitespace is erased at the beginning of the paragraph",
 		"here comes the text"
 		"</p>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -873,7 +824,7 @@ TEST_CASE("newlines are replaced with space", "[HtmlRenderer]")
 	const std::string input =
 		"newlines\nshould\nbe\nreplaced\nwith\na\nspace\ncharacter.";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -893,7 +844,7 @@ TEST_CASE("paragraph is just a long line of text", "[HtmlRenderer]")
 		"width"
 		"</p>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -908,7 +859,7 @@ TEST_CASE("default style for <ol> is Arabic numerals", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	SECTION("no `type' attribute") {
 		const std::string input =
@@ -943,7 +894,7 @@ TEST_CASE("default starting number for <ol> is 1", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	SECTION("no `start' attribute") {
 		const std::string input =
@@ -978,7 +929,7 @@ TEST_CASE("type='1' for <ol> means Arabic numbering", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	const std::string input =
 		"<ol type='1'>"
 		"<li>one</li>"
@@ -997,7 +948,7 @@ TEST_CASE("type='a' for <ol> means lowercase alphabetic numbering",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	const std::string input =
 		"<ol type='a'>"
 		"<li>one</li>"
@@ -1016,7 +967,7 @@ TEST_CASE("type='A' for <ol> means uppercase alphabetic numbering",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	const std::string input =
 		"<ol type='A'>"
 		"<li>one</li>"
@@ -1034,7 +985,7 @@ TEST_CASE("type='i' for <ol> means lowercase Roman numbering", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	const std::string input =
 		"<ol type='i'>"
 		"<li>one</li>"
@@ -1052,7 +1003,7 @@ TEST_CASE("type='I' for <ol> means uppercase Roman numbering", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	const std::string input =
 		"<ol type='I'>"
 		"<li>one</li>"
@@ -1071,7 +1022,7 @@ TEST_CASE("every next <li> implicitly closes the previous one",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	const std::string input =
 		"<ol type='I'>"
 		"<li>one"
@@ -1094,7 +1045,7 @@ TEST_CASE("<style> tags are ignored", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	const std::string input =
 		"<style><h1>ignore me</h1><p>and me</p> body{width: "
 		"100%;}</style>";
@@ -1107,7 +1058,7 @@ TEST_CASE("<style> tags are ignored", "[HtmlRenderer]")
 TEST_CASE("<hr> is not a string, but a special type of line", "[HtmlRenderer]")
 {
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 	HtmlRenderer r;
 	const std::string input = "<hr>";
 
@@ -1122,7 +1073,7 @@ TEST_CASE("header rows of tables are in bold", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	SECTION("one column") {
 		const std::string input =
@@ -1161,7 +1112,7 @@ TEST_CASE("cells are separated by space if `border' is not set",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<table>"
@@ -1184,7 +1135,7 @@ TEST_CASE(
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	for (auto border_width = 1; border_width < 10; ++border_width) {
 		DYNAMIC_SECTION("`border' = " << border_width) {
@@ -1211,7 +1162,7 @@ TEST_CASE("tables with `border' have borders", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1234,7 +1185,7 @@ TEST_CASE("if document ends before </table> is found, table is rendered anyway",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1255,7 +1206,7 @@ TEST_CASE("tables can be nested", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1303,7 +1254,7 @@ TEST_CASE(
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1325,7 +1276,7 @@ TEST_CASE("previous row is implicitly closed when <tr> is found",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1350,7 +1301,7 @@ TEST_CASE(
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1372,7 +1323,7 @@ TEST_CASE("text within <ituneshack> is to be treated specially",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<ituneshack>"
@@ -1396,7 +1347,7 @@ TEST_CASE("When rendeing text, HtmlRenderer strips leading whitespace",
 {
 	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"		<br />\n"
@@ -1428,31 +1379,20 @@ TEST_CASE("<video> results in a placeholder and a link for each valid source",
 		"	<source src='http://example.com/video2.mkv'>"
 		"</video>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 8);
+	REQUIRE(lines.size() == 3);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[video 1 (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, "[video 2 (link #2)]"));
 	REQUIRE(lines[2] == p(LineType::wrappable, "[video 2 (link #3)]"));
-	REQUIRE(lines[3] == p(LineType::wrappable, ""));
-	REQUIRE(lines[4] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[5] ==
-		p(LineType::softwrappable,
-			"[1]: http://example.com/video.avi (video)"));
-	REQUIRE(lines[6] ==
-		p(LineType::softwrappable,
-			"[2]: http://example.com/video2.avi (video)"));
-	REQUIRE(lines[7] ==
-		p(LineType::softwrappable,
-			"[3]: http://example.com/video2.mkv (video)"));
 	REQUIRE(links.size() == 3);
-	REQUIRE(links[0].first == "http://example.com/video.avi");
-	REQUIRE(links[0].second == LinkType::VIDEO);
-	REQUIRE(links[1].first == "http://example.com/video2.avi");
-	REQUIRE(links[1].second == LinkType::VIDEO);
-	REQUIRE(links[2].first == "http://example.com/video2.mkv");
-	REQUIRE(links[2].second == LinkType::VIDEO);
+	REQUIRE(links[0].url == "http://example.com/video.avi");
+	REQUIRE(links[0].type == LinkType::VIDEO);
+	REQUIRE(links[1].url == "http://example.com/video2.avi");
+	REQUIRE(links[1].type == LinkType::VIDEO);
+	REQUIRE(links[2].url == "http://example.com/video2.mkv");
+	REQUIRE(links[2].type == LinkType::VIDEO);
 }
 
 TEST_CASE("<video>s without valid sources are ignored", "[HtmlRenderer]")
@@ -1464,16 +1404,14 @@ TEST_CASE("<video>s without valid sources are ignored", "[HtmlRenderer]")
 		"<video src=''></video>"
 		"<video src='http://example.com/video.avi'></video>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[video 1 (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: http://example.com/video.avi (video)"));
 	REQUIRE(links.size() == 1);
+	REQUIRE(links[0].url == "http://example.com/video.avi");
+	REQUIRE(links[0].type == LinkType::VIDEO);
 }
 
 TEST_CASE("<audio> results in a placeholder and a link for each valid source",
@@ -1488,31 +1426,20 @@ TEST_CASE("<audio> results in a placeholder and a link for each valid source",
 		"	<source src='http://example.com/audio2.m4a'>"
 		"</audio>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 8);
+	REQUIRE(lines.size() == 3);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[audio 1 (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, "[audio 2 (link #2)]"));
 	REQUIRE(lines[2] == p(LineType::wrappable, "[audio 2 (link #3)]"));
-	REQUIRE(lines[3] == p(LineType::wrappable, ""));
-	REQUIRE(lines[4] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[5] ==
-		p(LineType::softwrappable,
-			"[1]: http://example.com/audio.oga (audio)"));
-	REQUIRE(lines[6] ==
-		p(LineType::softwrappable,
-			"[2]: http://example.com/audio2.mp3 (audio)"));
-	REQUIRE(lines[7] ==
-		p(LineType::softwrappable,
-			"[3]: http://example.com/audio2.m4a (audio)"));
 	REQUIRE(links.size() == 3);
-	REQUIRE(links[0].first == "http://example.com/audio.oga");
-	REQUIRE(links[0].second == LinkType::AUDIO);
-	REQUIRE(links[1].first == "http://example.com/audio2.mp3");
-	REQUIRE(links[1].second == LinkType::AUDIO);
-	REQUIRE(links[2].first == "http://example.com/audio2.m4a");
-	REQUIRE(links[2].second == LinkType::AUDIO);
+	REQUIRE(links[0].url == "http://example.com/audio.oga");
+	REQUIRE(links[0].type == LinkType::AUDIO);
+	REQUIRE(links[1].url == "http://example.com/audio2.mp3");
+	REQUIRE(links[1].type == LinkType::AUDIO);
+	REQUIRE(links[2].url == "http://example.com/audio2.m4a");
+	REQUIRE(links[2].type == LinkType::AUDIO);
 }
 
 TEST_CASE("<audio>s without valid sources are ignored", "[HtmlRenderer]")
@@ -1524,16 +1451,14 @@ TEST_CASE("<audio>s without valid sources are ignored", "[HtmlRenderer]")
 		"<audio src=''></audio>"
 		"<audio src='http://example.com/audio.oga'></audio>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 4);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[audio 1 (link #1)]"));
-	REQUIRE(lines[1] == p(LineType::wrappable, ""));
-	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[3] == p(LineType::softwrappable,
-			"[1]: http://example.com/audio.oga (audio)"));
 	REQUIRE(links.size() == 1);
+	REQUIRE(links[0].url == "http://example.com/audio.oga");
+	REQUIRE(links[0].type == LinkType::AUDIO);
 }
 
 TEST_CASE("Unclosed <video> and <audio> tags are closed upon encounter with a "
@@ -1558,44 +1483,27 @@ TEST_CASE("Unclosed <video> and <audio> tags are closed upon encounter with a "
 		"Here comes the text!";
 
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 13);
+	REQUIRE(lines.size() == 6);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[video 1 (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, "[video 2 (link #2)]"));
 	REQUIRE(lines[2] == p(LineType::wrappable, "[audio 1 (link #3)]"));
 	REQUIRE(lines[3] == p(LineType::wrappable, "[audio 1 (link #4)]"));
 	REQUIRE(lines[4] == p(LineType::wrappable, "[audio 2 (link #5)]"));
 	REQUIRE(lines[5] == p(LineType::wrappable, "Here comes the text!"));
-	REQUIRE(lines[6] == p(LineType::wrappable, ""));
-	REQUIRE(lines[7] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[8] ==
-		p(LineType::softwrappable,
-			"[1]: http://example.com/video.avi (video)"));
-	REQUIRE(lines[9] ==
-		p(LineType::softwrappable,
-			"[2]: http://example.com/video2.avi (video)"));
-	REQUIRE(lines[10] ==
-		p(LineType::softwrappable,
-			"[3]: http://example.com/audio.oga (audio)"));
-	REQUIRE(lines[11] ==
-		p(LineType::softwrappable,
-			"[4]: http://example.com/audio.m4a (audio)"));
-	REQUIRE(lines[12] ==
-		p(LineType::softwrappable,
-			"[5]: http://example.com/audio2.mp3 (audio)"));
 	REQUIRE(links.size() == 5);
-	REQUIRE(links[0].first == "http://example.com/video.avi");
-	REQUIRE(links[0].second == LinkType::VIDEO);
-	REQUIRE(links[1].first == "http://example.com/video2.avi");
-	REQUIRE(links[1].second == LinkType::VIDEO);
-	REQUIRE(links[2].first == "http://example.com/audio.oga");
-	REQUIRE(links[2].second == LinkType::AUDIO);
-	REQUIRE(links[3].first == "http://example.com/audio.m4a");
-	REQUIRE(links[3].second == LinkType::AUDIO);
-	REQUIRE(links[4].first == "http://example.com/audio2.mp3");
-	REQUIRE(links[4].second == LinkType::AUDIO);
+	REQUIRE(links[0].url == "http://example.com/video.avi");
+	REQUIRE(links[0].type == LinkType::VIDEO);
+	REQUIRE(links[1].url == "http://example.com/video2.avi");
+	REQUIRE(links[1].type == LinkType::VIDEO);
+	REQUIRE(links[2].url == "http://example.com/audio.oga");
+	REQUIRE(links[2].type == LinkType::AUDIO);
+	REQUIRE(links[3].url == "http://example.com/audio.m4a");
+	REQUIRE(links[3].type == LinkType::AUDIO);
+	REQUIRE(links[4].url == "http://example.com/audio2.mp3");
+	REQUIRE(links[4].type == LinkType::AUDIO);
 }
 
 TEST_CASE("Empty <source> tags do not increase the link count. Media elements"
@@ -1619,37 +1527,23 @@ TEST_CASE("Empty <source> tags do not increase the link count. Media elements"
 		"</audio>";
 
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 10);
+	REQUIRE(lines.size() == 4);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[video 1 (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, "[video 1 (link #2)]"));
 	REQUIRE(lines[2] == p(LineType::wrappable, "[audio 1 (link #3)]"));
 	REQUIRE(lines[3] == p(LineType::wrappable, "[audio 1 (link #4)]"));
-	REQUIRE(lines[4] == p(LineType::wrappable, ""));
-	REQUIRE(lines[5] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[6] ==
-		p(LineType::softwrappable,
-			"[1]: http://example.com/video.avi (video)"));
-	REQUIRE(lines[7] ==
-		p(LineType::softwrappable,
-			"[2]: http://example.com/video.mkv (video)"));
-	REQUIRE(lines[8] ==
-		p(LineType::softwrappable,
-			"[3]: http://example.com/audio.mp3 (audio)"));
-	REQUIRE(lines[9] ==
-		p(LineType::softwrappable,
-			"[4]: http://example.com/audio.oga (audio)"));
 	REQUIRE(links.size() == 4);
-	REQUIRE(links[0].first == "http://example.com/video.avi");
-	REQUIRE(links[0].second == LinkType::VIDEO);
-	REQUIRE(links[1].first == "http://example.com/video.mkv");
-	REQUIRE(links[1].second == LinkType::VIDEO);
-	REQUIRE(links[2].first == "http://example.com/audio.mp3");
-	REQUIRE(links[2].second == LinkType::AUDIO);
-	REQUIRE(links[3].first == "http://example.com/audio.oga");
-	REQUIRE(links[3].second == LinkType::AUDIO);
+	REQUIRE(links[0].url == "http://example.com/video.avi");
+	REQUIRE(links[0].type == LinkType::VIDEO);
+	REQUIRE(links[1].url == "http://example.com/video.mkv");
+	REQUIRE(links[1].type == LinkType::VIDEO);
+	REQUIRE(links[2].url == "http://example.com/audio.mp3");
+	REQUIRE(links[2].type == LinkType::AUDIO);
+	REQUIRE(links[3].url == "http://example.com/audio.oga");
+	REQUIRE(links[3].type == LinkType::AUDIO);
 }
 
 TEST_CASE("Back-to-back <video> and <audio> tags are seperated by a new line",
@@ -1662,25 +1556,17 @@ TEST_CASE("Back-to-back <video> and <audio> tags are seperated by a new line",
 		"<audio src='https://example.com/audio.mp3'></audio>";
 
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 6);
+	REQUIRE(lines.size() == 2);
 	REQUIRE(lines[0] == p(LineType::wrappable, "[video 1 (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, "[audio 1 (link #2)]"));
-	REQUIRE(lines[2] == p(LineType::wrappable, ""));
-	REQUIRE(lines[3] == p(LineType::wrappable, "Links: "));
-	REQUIRE(lines[4] ==
-		p(LineType::softwrappable,
-			"[1]: https://example.com/video.mp4 (video)"));
-	REQUIRE(lines[5] ==
-		p(LineType::softwrappable,
-			"[2]: https://example.com/audio.mp3 (audio)"));
 	REQUIRE(links.size() == 2);
-	REQUIRE(links[0].first == "https://example.com/video.mp4");
-	REQUIRE(links[0].second == LinkType::VIDEO);
-	REQUIRE(links[1].first == "https://example.com/audio.mp3");
-	REQUIRE(links[1].second == LinkType::AUDIO);
+	REQUIRE(links[0].url == "https://example.com/video.mp4");
+	REQUIRE(links[0].type == LinkType::VIDEO);
+	REQUIRE(links[1].url == "https://example.com/audio.mp3");
+	REQUIRE(links[1].type == LinkType::AUDIO);
 }
 
 TEST_CASE("Ordered list can contain unordered list in its items",
@@ -1688,7 +1574,7 @@ TEST_CASE("Ordered list can contain unordered list in its items",
 {
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const auto input = std::string(
 			"<ol>"
@@ -1732,23 +1618,33 @@ TEST_CASE("Skips contents of <script> tags", "[HtmlRenderer]")
 
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
-	std::ifstream input_file("data/1300-reproducer.html");
-	std::string input;
-	input_file >> input;
+	const auto input = std::string(
+			"<script>"
+			"</ul>"
+			"</ul>"
+			"</ul>"
+			"</ul>"
+			"</ul>"
+			"</ul>"
+			"</script>"
+			""
+			"<p>Visible text</p>");
 
 	rnd.render(input, lines, links, "");
 
-	REQUIRE(lines.size() == 0);
+	REQUIRE(lines.size() == 1);
 	REQUIRE(links.size() == 0);
+
+	REQUIRE(lines[0].second == "Visible text");
 }
 
 TEST_CASE("<div> is always rendered on a new line", "[HtmlRenderer]")
 {
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string
 	input("<div>oh</div>"
@@ -1782,7 +1678,7 @@ TEST_CASE("HtmlRenderer does not crash on extra closing OL/UL tags", "[HtmlRende
 
 	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<LinkPair> links;
+	Links links;
 
 	const std::string input =
 		"<ul><li>Double closed list</li></ul></ul><ol><li>Other double closed list</li></ol></ol><ul><li>Test</li></ul>";
