@@ -8,7 +8,6 @@
 #include "cache.h"
 #include "configpaths.h"
 #include "controller.h"
-#include "feedlistformaction.h"
 #include "itemlist.h"
 #include "keymap.h"
 #include "regexmanager.h"
@@ -58,7 +57,7 @@ TEST_CASE("OP_OPEN displays article using an external pager",
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 
 	const std::vector<std::string> args;
@@ -89,7 +88,7 @@ TEST_CASE("OP_PURGE_DELETED purges previously deleted items",
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 
 	SECTION("No items to purge") {
@@ -134,7 +133,7 @@ TEST_CASE(
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 	const std::vector<std::string> args;
 	itemlist.process_op(OP_OPENBROWSER_AND_MARK, args);
@@ -172,7 +171,7 @@ TEST_CASE(
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 	const std::vector<std::string> args;
 	itemlist.process_op(OP_OPENBROWSER_AND_MARK, args);
@@ -205,7 +204,7 @@ TEST_CASE("OP_OPENINBROWSER passes the url to the browser",
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 	const std::vector<std::string> args;
 	itemlist.process_op(OP_OPENINBROWSER, args);
@@ -240,7 +239,7 @@ TEST_CASE("OP_OPENINBROWSER_NONINTERACTIVE passes the url to the browser",
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 	const std::vector<std::string> args;
 	itemlist.process_op(newsboat::OP_OPENINBROWSER_NONINTERACTIVE, args);
@@ -283,7 +282,7 @@ TEST_CASE("OP_OPENALLUNREADINBROWSER passes the url list to the browser",
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 
 	SECTION("unread >= max-browser-tabs") {
@@ -301,7 +300,7 @@ TEST_CASE("OP_OPENALLUNREADINBROWSER passes the url list to the browser",
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -324,7 +323,7 @@ TEST_CASE("OP_OPENALLUNREADINBROWSER passes the url list to the browser",
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -369,7 +368,7 @@ TEST_CASE(
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 
 	SECTION("unread >= max-browser-tabs") {
@@ -386,7 +385,7 @@ TEST_CASE(
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -411,7 +410,7 @@ TEST_CASE(
 			while (std::getline(browserFileStream, line)) {
 				INFO("Each URL should be present exactly once. "
 					"Erase urls after first match to fail if "
-					"an item opens twice.")
+					"an item opens twice.");
 				REQUIRE(url_set.count(line) == 1);
 				url_set.erase(url_set.find(line));
 				openedItemsCount += 1;
@@ -455,7 +454,7 @@ TEST_CASE("OP_SHOWURLS shows the article's properties", "[ItemListFormAction]")
 	item->set_author(test_author);
 	item->set_description(test_description, "text/plain");
 	item->set_pubDate(test_pubDate);
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 
 	SECTION("with external-url-viewer") {
 		feed->add_item(item);
@@ -517,7 +516,7 @@ TEST_CASE("OP_BOOKMARK pipes articles url and title to bookmark-command",
 	item->set_link(test_url);
 	item->set_title(test_title);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 
 	feed->add_item(item);
 	itemlist.set_feed(feed);
@@ -569,7 +568,7 @@ TEST_CASE("OP_EDITFLAGS arguments are added to an item's flags",
 	std::shared_ptr<RssFeed> feed = std::make_shared<RssFeed>(&rsscache, "");
 	std::shared_ptr<RssItem> item = std::make_shared<RssItem>(&rsscache);
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 
 	feed->add_item(item);
 	itemlist.set_feed(feed);
@@ -646,7 +645,7 @@ TEST_CASE("OP_SAVE writes an article's attributes to the specified file",
 	item->set_pubDate(test_pubDate);
 	item->set_description(test_description, "text/plain");
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 
 	feed->add_item(item);
 	itemlist.set_feed(feed);
@@ -715,7 +714,7 @@ TEST_CASE("OP_HARDQUIT command is processed", "[ItemListFormAction]")
 
 	std::shared_ptr<RssFeed> feed = std::make_shared<RssFeed>(&rsscache, "");
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 	itemlist.set_feed(feed);
 
 	const std::vector<std::string> args;
@@ -852,7 +851,7 @@ TEST_CASE("OP_PIPE_TO pipes an article's content to an external command",
 	item->set_pubDate(test_pubDate);
 	item->set_description(test_description, "text/plain");
 
-	ItemListFormAction itemlist(&v, itemlist_str, &rsscache, filters, &cfg, rxman);
+	ItemListFormAction itemlist(v, itemlist_str, &rsscache, filters, &cfg, rxman);
 
 	feed->add_item(item);
 	itemlist.set_feed(feed);
