@@ -6,14 +6,14 @@
 #include "configcontainer.h"
 #include "regexmanager.h"
 #include "rssfeed.h"
-#include "test-helpers/envvar.h"
+#include "test_helpers/envvar.h"
 
 using namespace newsboat;
 
 static const auto FEED_TITLE = std::string("Funniest jokes ever");
 std::shared_ptr<RssFeed> create_test_feed(Cache* c)
 {
-	auto feed = std::make_shared<RssFeed>(c);
+	auto feed = std::make_shared<RssFeed>(c, "");
 
 	feed->set_title(FEED_TITLE);
 
@@ -30,9 +30,12 @@ static const auto ITEM_PUBDATE = time_t
 static const auto ITEM_LINK = std::string("https://example.com/see-more");
 static const auto ITEM_DESCRIPTON = std::string("<p>Hello, world!</p>");
 static const auto ITEM_DESCRIPTON_RENDERED = std::string("Hello, world!");
-static const auto ITEM_ENCLOSURE_URL =
+static const auto ITEM_PODCAST_ENCLOSURE_URL =
 	std::string("https://example.com/see-more.mp3");
-static const auto ITEM_ENCLOSURE_TYPE = std::string("audio/mpeg");
+static const auto ITEM_IMAGE_ENCLOSURE_URL =
+	std::string("https://example.com/see-more.png");
+static const auto ITEM_PODCAST_ENCLOSURE_TYPE = std::string("audio/mpeg");
+static const auto ITEM_IMAGE_ENCLOSURE_TYPE = std::string("image/png");
 static const auto ITEM_FLAGS = std::string("wasdhjkl");
 // Flags are sorted for rendering.
 static const auto ITEM_FLAGS_RENDERED = std::string("adhjklsw");
@@ -57,7 +60,7 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 	"of an RSS item, ready to be displayed to the user",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	test_helpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -72,7 +75,7 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 	std::tie(item, feed) = create_test_item(&rsscache);
 
 	SECTION("Item without an enclosure") {
-		item->set_description(ITEM_DESCRIPTON);
+		item->set_description(ITEM_DESCRIPTON, "text/html");
 
 		const auto result = item_renderer::to_plain_text(cfg, item);
 
@@ -90,8 +93,8 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 	}
 
 	SECTION("Item with an enclosure") {
-		item->set_description(ITEM_DESCRIPTON);
-		item->set_enclosure_url(ITEM_ENCLOSURE_URL);
+		item->set_description(ITEM_DESCRIPTON, "text/html");
+		item->set_enclosure_url(ITEM_PODCAST_ENCLOSURE_URL);
 
 		const auto result = item_renderer::to_plain_text(cfg, item);
 
@@ -102,17 +105,17 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
 			"Link: " + ITEM_LINK + '\n' +
 			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
-			"Podcast Download URL: " + ITEM_ENCLOSURE_URL + '\n' +
+			"Podcast Download URL: " + ITEM_PODCAST_ENCLOSURE_URL + '\n' +
 			" \n" +
 			ITEM_DESCRIPTON_RENDERED + '\n';
 
 		REQUIRE(result == expected);
 	}
 
-	SECTION("Item with an enclosure that has a MIME type") {
-		item->set_description(ITEM_DESCRIPTON);
-		item->set_enclosure_url(ITEM_ENCLOSURE_URL);
-		item->set_enclosure_type(ITEM_ENCLOSURE_TYPE);
+	SECTION("Item with an enclosure that has a podcast MIME type") {
+		item->set_description(ITEM_DESCRIPTON, "text/html");
+		item->set_enclosure_url(ITEM_PODCAST_ENCLOSURE_URL);
+		item->set_enclosure_type(ITEM_PODCAST_ENCLOSURE_TYPE);
 
 		const auto result = item_renderer::to_plain_text(cfg, item);
 
@@ -123,18 +126,43 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
 			"Link: " + ITEM_LINK + '\n' +
 			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
-			"Podcast Download URL: " + ITEM_ENCLOSURE_URL
-			+ " (type: " + ITEM_ENCLOSURE_TYPE + ")\n" +
+			"Podcast Download URL: " + ITEM_PODCAST_ENCLOSURE_URL
+			+ " (type: " + ITEM_PODCAST_ENCLOSURE_TYPE + ")\n" +
 			" \n" +
 			ITEM_DESCRIPTON_RENDERED + '\n';
 
 		REQUIRE(result == expected);
 	}
 
+	SECTION("Item with an enclosure that has an image MIME type") {
+		item->set_description(ITEM_DESCRIPTON, "text/html");
+		item->set_enclosure_url(ITEM_IMAGE_ENCLOSURE_URL);
+		item->set_enclosure_type(ITEM_IMAGE_ENCLOSURE_TYPE);
+
+		const auto result = item_renderer::to_plain_text(cfg, item);
+
+		const auto expected = std::string() +
+			"Feed: " + FEED_TITLE + '\n' +
+			"Title: " + ITEM_TITLE + '\n' +
+			"Author: " + ITEM_AUTHOR + '\n' +
+			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
+			"Link: " + ITEM_LINK + '\n' +
+			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
+			" \n" +
+			"Image[1]\n" +
+			" \n" +
+			ITEM_DESCRIPTON_RENDERED + '\n' +
+			" \n" +
+			"Links: \n" +
+			"[1]: " + ITEM_IMAGE_ENCLOSURE_URL + " (image)\n";
+
+		REQUIRE(result == expected);
+	}
+
 	SECTION("Item with some links in the description") {
 		item->set_description(
 			ITEM_DESCRIPTON +
-			"<p>See also <a href='https://example.com'>this site</a>.</p>");
+			"<p>See also <a href='https://example.com'>this site</a>.</p>", "text/html");
 
 		const auto result = item_renderer::to_plain_text(cfg, item);
 
@@ -155,13 +183,38 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 
 		REQUIRE(result == expected);
 	}
+
+	SECTION("Item with enclosure and plaintext description") {
+		item->set_description(ITEM_DESCRIPTON, "text/plain");
+		item->set_enclosure_url("https://example.com/test.png");
+		item->set_enclosure_type("image/png");
+
+		const auto result = item_renderer::to_plain_text(cfg, item);
+
+		const auto expected = std::string() +
+			"Feed: " + FEED_TITLE + '\n' +
+			"Title: " + ITEM_TITLE + '\n' +
+			"Author: " + ITEM_AUTHOR + '\n' +
+			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
+			"Link: " + ITEM_LINK + '\n' +
+			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
+			" \n" +
+			"Image[1]\n" +
+			" \n" +
+			ITEM_DESCRIPTON + '\n' +
+			" \n" +
+			"Links: \n" +
+			"[1]: https://example.com/test.png (image)\n";
+
+		REQUIRE(result == expected);
+	}
 }
 
 TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 	"in `text-width` setting",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	test_helpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -176,7 +229,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 		"Lorem ipsum dolor sit amet, consectetur adipiscing elit. "
 		"Pellentesque nisl massa, luctus ut ligula vitae, suscipit tempus "
 		"velit. Vivamus sodales, quam in convallis posuere, libero nisi "
-		"ultricies orci, nec lobortis.");
+		"ultricies orci, nec lobortis.", "text/html");
 
 	const auto header = std::string() +
 		"Feed: " + FEED_TITLE + '\n' +
@@ -253,7 +306,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 		item->set_description(
 			"&lt;&lt;&lt;&lt;&lt;&lt;&lt;&lt;&lt;&lt;" // 10 characters
 			"&gt;&gt;&gt;&gt;&gt;&gt;&gt;&gt;&gt;&gt;" // 10 characters
-			"Lorem ipsum dolor sit amet");
+			"Lorem ipsum dolor sit amet", "text/html");
 
 		const auto result = item_renderer::to_plain_text(cfg, item);
 
@@ -268,7 +321,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 TEST_CASE("to_plain_text() does not escape '<' and '>' in header and body",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	test_helpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -282,7 +335,7 @@ TEST_CASE("to_plain_text() does not escape '<' and '>' in header and body",
 	feed->set_title("<" + FEED_TITLE + ">");
 	item->set_title("<" + ITEM_TITLE + ">");
 	item->set_author("<" + ITEM_AUTHOR + ">");
-	item->set_description("&lt;test&gt;");
+	item->set_description("&lt;test&gt;", "text/html");
 
 	const auto expected = std::string() +
 		"Feed: <" + FEED_TITLE + ">\n" +
@@ -300,7 +353,7 @@ TEST_CASE("to_plain_text() does not escape '<' and '>' in header and body",
 
 TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	test_helpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -379,7 +432,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 	}
 
 	SECTION("Item without an enclosure") {
-		item->set_description(ITEM_DESCRIPTON);
+		item->set_description(ITEM_DESCRIPTON, "text/html");
 
 		const auto result = item_renderer::to_plain_text(cfg, item);
 
@@ -416,7 +469,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	test_helpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -432,7 +485,7 @@ TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 		const auto description = std::string() +
 			"<p>Hello, world! Check out "
 			"<a href='https://example.com'>our site</a>.</p>";
-		item->set_description(description);
+		item->set_description(description, "text/html");
 
 		SECTION("internal renderer") {
 			cfg.set_configvalue("html-renderer", "internal");
@@ -481,7 +534,7 @@ TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 		const auto description = std::string() +
 			"<p>Hello, world!</p>\n\n"
 			"<p>Check out <a href='https://example.com'>our site</a>.</p>";
-		item->set_description(description);
+		item->set_description(description, "text/html");
 
 		SECTION("internal renderer") {
 			cfg.set_configvalue("html-renderer", "internal");
@@ -584,15 +637,15 @@ TEST_CASE("item_renderer::get_feedtitle() returns item's feed URL "
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
 
-	std::shared_ptr<RssItem> item;
-	std::shared_ptr<RssFeed> feed;
-	std::tie(item, feed) = create_test_item(&rsscache);
-
 	const auto feedurl = std::string("https://example.com/~joe/entries.rss");
 
+	std::shared_ptr<RssFeed> feed = std::make_shared<RssFeed>(&rsscache, feedurl);
+	auto item = std::make_shared<RssItem>(&rsscache);
+	item->set_feedptr(feed);
+
+
 	feed->set_title("");
 	feed->set_link("");
-	feed->set_rssurl(feedurl);
 
 	const auto result = item_renderer::get_feedtitle(item);
 	REQUIRE(result == feedurl);
@@ -601,7 +654,7 @@ TEST_CASE("item_renderer::get_feedtitle() returns item's feed URL "
 TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use with stfl",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	test_helpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -616,7 +669,7 @@ TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use wi
 	feed->set_title("<" + FEED_TITLE + ">");
 	item->set_title("<" + ITEM_TITLE + ">");
 	item->set_author("<" + ITEM_AUTHOR + ">");
-	item->set_description("<html>&lt;test&gt;</html>");
+	item->set_description("<html>&lt;test&gt;</html>", "text/html");
 
 	SECTION("to_stfl_list()") {
 		const auto expected = std::string() +
@@ -631,7 +684,7 @@ TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use wi
 			"{listitem text:\"<>test>\"}" +
 			"}";
 
-		std::vector<LinkPair> links;
+		Links links;
 		const auto result = item_renderer::to_stfl_list(cfg, item, 80, 80, &rxman,
 				"article", links);
 		REQUIRE(result.first == expected);
@@ -650,9 +703,86 @@ TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use wi
 			"{listitem text:\"<>html>&lt;test&gt;<>/html>\"}" +
 			"}";
 
-		std::vector<LinkPair> links;
+		Links links;
 		const auto result = item_renderer::source_to_stfl_list(item, 80, 80, &rxman,
 				"article");
 		REQUIRE(result.first == expected);
 	}
 }
+
+TEST_CASE("item_renderer::render_plaintext() splits text on newlines", "[item_renderer]")
+{
+	using newsboat::item_renderer::OutputFormat;
+	// Verifies that render_plaintext creates the expected lines, all marked as wrappable
+	const auto check = [](const std::string input,
+	const std::vector<std::string>& expected_lines, OutputFormat format) {
+		std::vector<std::pair<LineType, std::string>> output;
+		item_renderer::render_plaintext(input, output, format);
+
+		REQUIRE(output.size() == expected_lines.size());
+		for (std::size_t i = 0; i < output.size(); ++i) {
+			INFO("i: " + std::to_string(i));
+			REQUIRE(output[i].first == LineType::wrappable);
+			REQUIRE(output[i].second == expected_lines[i]);
+		}
+	};
+
+	SECTION(R"(regular text is split on \r and \n)") {
+		const std::string text =
+			"Lorem ipsum dolor sit amet\nconsectetur adipiscing elit\rsed do eiusmod tempor incididunt ut labore\net dolore magna aliqua.";
+
+		check(text, {
+			"Lorem ipsum dolor sit amet",
+			"consectetur adipiscing elit",
+			"sed do eiusmod tempor incididunt ut labore",
+			"et dolore magna aliqua."
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION("render_plaintext keeps indentation") {
+		const std::string text =
+			"The following lines are indented:\n    hello\n    this is a test\n\nback to no indentation";
+
+		check(text, {
+			"The following lines are indented:",
+			"    hello",
+			"    this is a test",
+			"",
+			"back to no indentation"
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION(R"(text is split on sequences of \r\n, and on separate \r and \n characters)") {
+		const std::string text =
+			"Lorem ipsum\r\ndolor sit amet\n\rconsectetur adipiscing elit\rsed do eiusmod tempor incididunt ut labore\net dolore magna\r\n\r\naliqua.";
+
+		check(text, {
+			"Lorem ipsum",
+			"dolor sit amet",
+			"",
+			"consectetur adipiscing elit",
+			"sed do eiusmod tempor incididunt ut labore",
+			"et dolore magna",
+			"",
+			"aliqua."
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION("render_plaintext escapes angle brackets for STFL") {
+		const std::string text = "this < should be escaped >\n<p>test text</p>";
+
+		check(text, {
+			"this <> should be escaped >",
+			"<>p>test text<>/p>"
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION("render_plaintext does not escape when rendering towards some plaintext output") {
+		const std::string text = "this < should *not* be escaped >\n<p>test text</p>";
+
+		check(text, {
+			"this < should *not* be escaped >",
+			"<p>test text</p>"
+		}, OutputFormat::PlainText);
+	}
+}
