@@ -6,6 +6,7 @@
 #include "3rd-party/catch.hpp"
 
 #include "confighandlerexception.h"
+#include "keycombination.h"
 
 using namespace newsboat;
 
@@ -18,14 +19,14 @@ TEST_CASE("get_operation()", "[KeyMap]")
 {
 	KeyMap k(KM_NEWSBOAT);
 
-	REQUIRE(k.get_operation("u", "article") == OP_SHOWURLS);
-	REQUIRE(k.get_operation("X", "feedlist") == OP_NIL);
-	REQUIRE(k.get_operation("", "feedlist") == OP_NIL);
-	REQUIRE(k.get_operation("ENTER", "feedlist") == OP_OPEN);
+	REQUIRE(k.get_operation(KeyCombination("u"), "article") == OP_SHOWURLS);
+	REQUIRE(k.get_operation(KeyCombination("x", ShiftState::Shift), "feedlist") == OP_NIL);
+	REQUIRE(k.get_operation(KeyCombination(""), "feedlist") == OP_NIL);
+	REQUIRE(k.get_operation(KeyCombination("ENTER"), "feedlist") == OP_OPEN);
 
 	SECTION("Returns OP_NIL after unset_key()") {
-		k.unset_key("ENTER", "all");
-		REQUIRE(k.get_operation("ENTER", "feedlist") == OP_NIL);
+		k.unset_key(KeyCombination("ENTER"), "all");
+		REQUIRE(k.get_operation(KeyCombination("ENTER"), "feedlist") == OP_NIL);
 	}
 }
 
@@ -33,17 +34,17 @@ TEST_CASE("unset_key() and set_key()", "[KeyMap]")
 {
 	KeyMap k(KM_NEWSBOAT);
 
-	REQUIRE(k.get_operation("ENTER", "feedlist") == OP_OPEN);
-	REQUIRE(k.get_keys(OP_OPEN, "feedlist") == std::vector<std::string>({"ENTER"}));
+	REQUIRE(k.get_operation(KeyCombination("ENTER"), "feedlist") == OP_OPEN);
+	REQUIRE(k.get_keys(OP_OPEN, "feedlist") == std::vector<KeyCombination>({KeyCombination("ENTER")}));
 
 	SECTION("unset_key() removes the mapping") {
-		k.unset_key("ENTER", "all");
-		REQUIRE(k.get_operation("ENTER", "feedlist") == OP_NIL);
+		k.unset_key(KeyCombination("ENTER"), "all");
+		REQUIRE(k.get_operation(KeyCombination("ENTER"), "feedlist") == OP_NIL);
 
 		SECTION("set_key() sets the mapping") {
-			k.set_key(OP_OPEN, "ENTER", "all");
-			REQUIRE(k.get_operation("ENTER", "feedlist") == OP_OPEN);
-			REQUIRE(k.get_keys(OP_OPEN, "feedlist") == std::vector<std::string>({"ENTER"}));
+			k.set_key(OP_OPEN, KeyCombination("ENTER"), "all");
+			REQUIRE(k.get_operation(KeyCombination("ENTER"), "feedlist") == OP_OPEN);
+			REQUIRE(k.get_keys(OP_OPEN, "feedlist") == std::vector<KeyCombination>({KeyCombination("ENTER")}));
 		}
 	}
 }
@@ -59,7 +60,9 @@ TEST_CASE(
 			if (i == OP_OPENALLUNREADINBROWSER ||
 				i == OP_MARKALLABOVEASREAD ||
 				i == OP_OPENALLUNREADINBROWSER_AND_MARK ||
-				i == OP_SAVEALL) {
+				i == OP_SAVEALL ||
+				i == OP_GOTO_TITLE ||
+				i == OP_OPENINBROWSER_NONINTERACTIVE) {
 				continue;
 			}
 			bool used_in_some_context = false;
@@ -81,7 +84,7 @@ TEST_CASE(
 				INFO("Operation: " << i);
 				INFO("used in context: " << context);
 				REQUIRE(k.get_keys(static_cast<Operation>(i),
-						context) == std::vector<std::string>());
+						context) == std::vector<KeyCombination>());
 			}
 		}
 	}
@@ -117,7 +120,7 @@ TEST_CASE(
 
 		for (int i = OP_NB_MIN; i < OP_NB_MAX; ++i) {
 			REQUIRE(k.get_keys(static_cast<Operation>(i),
-					"articlelist") == std::vector<std::string>());
+					"articlelist") == std::vector<KeyCombination>());
 		}
 
 		KeyMap default_keys(KM_NEWSBOAT);
@@ -141,22 +144,22 @@ TEST_CASE("get_keys()", "[KeyMap]")
 	KeyMap k(KM_NEWSBOAT);
 
 	SECTION("Retrieves general bindings") {
-		REQUIRE(k.get_keys(OP_OPEN, "feedlist") == std::vector<std::string>({"ENTER"}));
+		REQUIRE(k.get_keys(OP_OPEN, "feedlist") == std::vector<KeyCombination>({KeyCombination("ENTER")}));
 		REQUIRE(k.get_keys(OP_TOGGLEITEMREAD,
-				"articlelist") == std::vector<std::string>({"N"}));
+				"articlelist") == std::vector<KeyCombination>({KeyCombination("n", ShiftState::Shift)}));
 	}
 
 	SECTION("Returns context-specific bindings only in that context") {
-		k.unset_key("q", "article");
-		k.set_key(OP_QUIT, "O", "article");
-		REQUIRE(k.get_keys(OP_QUIT, "article") == std::vector<std::string>({"O"}));
-		REQUIRE(k.get_keys(OP_QUIT, "feedlist") == std::vector<std::string>({"q"}));
+		k.unset_key(KeyCombination("q"), "article");
+		k.set_key(OP_QUIT, KeyCombination("o", ShiftState::Shift), "article");
+		REQUIRE(k.get_keys(OP_QUIT, "article") == std::vector<KeyCombination>({KeyCombination("o", ShiftState::Shift)}));
+		REQUIRE(k.get_keys(OP_QUIT, "feedlist") == std::vector<KeyCombination>({KeyCombination("q")}));
 	}
 
 	SECTION("Returns all keys bound to an operation (both default and added)") {
-		k.set_key(OP_QUIT, "a", "article");
-		k.set_key(OP_QUIT, "d", "article");
-		REQUIRE(k.get_keys(OP_QUIT, "article") == std::vector<std::string>({"a", "d", "q"}));
+		k.set_key(OP_QUIT, KeyCombination("a"), "article");
+		k.set_key(OP_QUIT, KeyCombination("d"), "article");
+		REQUIRE(k.get_keys(OP_QUIT, "article") == std::vector<KeyCombination>({KeyCombination("a"), KeyCombination("d"), KeyCombination("q")}));
 	}
 }
 
@@ -212,16 +215,32 @@ TEST_CASE("handle_action()", "[KeyMap]")
 		REQUIRE_NOTHROW(k.handle_action("bind-key", "p pageup"));
 
 		REQUIRE(k.get_keys(OP_SK_PGUP, "feedlist")
-			== std::vector<std::string>({"PPAGE", "p", "u"}));
+			== std::vector<KeyCombination>({KeyCombination("PPAGE"), KeyCombination("p"), KeyCombination("u")}));
 	}
 
 	SECTION("macro without commands results in exception") {
-		REQUIRE_NOTHROW(k.handle_action("macro", "r ; ; ; ; open"));
 		REQUIRE_THROWS_AS(k.handle_action("macro", "r ; ; ; ;"),
 			ConfigHandlerException);
 	}
 }
 
+TEST_CASE("handle_action() for bind", "[KeyMap]")
+{
+	KeyMap k(KM_NEWSBOAT);
+
+	SECTION("supports optional description") {
+		REQUIRE_NOTHROW(k.handle_action("bind", R"(a everywhere open -- "a description")"));
+		REQUIRE_NOTHROW(k.handle_action("bind", R"(a everywhere open)"));
+	}
+
+	SECTION("throws if incomplete") {
+		REQUIRE_NOTHROW(k.handle_action("bind", "a everywhere open"));
+		REQUIRE_THROWS_AS(k.handle_action("bind", "a everywhere open --"), ConfigHandlerException);
+		REQUIRE_THROWS_AS(k.handle_action("bind", "a everywhere"), ConfigHandlerException);
+		REQUIRE_THROWS_AS(k.handle_action("bind", "a"), ConfigHandlerException);
+	}
+}
+
 TEST_CASE("verify get_keymap_descriptions() behavior",
 	"[KeyMap]")
 {
@@ -270,8 +289,8 @@ TEST_CASE("verify get_keymap_descriptions() behavior",
 
 	GIVEN("that multiple keys are bound to the same operation (\"quit\")") {
 		KeyMap k(KM_NEWSBOAT);
-		k.set_key(OP_QUIT, "a", "feedlist");
-		k.set_key(OP_QUIT, "b", "feedlist");
+		k.set_key(OP_QUIT, KeyCombination("a"), "feedlist");
+		k.set_key(OP_QUIT, KeyCombination("b"), "feedlist");
 
 		WHEN("calling get_keymap_descriptions(\"feedlist\")") {
 			const auto descriptions = k.get_keymap_descriptions("feedlist");
@@ -287,7 +306,7 @@ TEST_CASE("verify get_keymap_descriptions() behavior",
 
 	GIVEN("that a key is bound to an operation which by default has no key configured") {
 		KeyMap k(KM_NEWSBOAT);
-		const std::string key = "O";
+		const auto key = KeyCombination("o", ShiftState::Shift);
 		k.set_key(OP_OPENALLUNREADINBROWSER_AND_MARK, key, "feedlist");
 
 		WHEN("calling get_keymap_descriptions(\"feedlist\")") {
@@ -312,7 +331,7 @@ TEST_CASE("verify get_keymap_descriptions() behavior",
 			THEN("all entries for the operation have non-empty key") {
 				for (const auto& description : descriptions) {
 					if (description.cmd == "open-all-unread-in-browser-and-mark-read") {
-						REQUIRE(description.key != "");
+						REQUIRE(description.key.get_key() != "");
 					}
 				}
 			}
@@ -327,17 +346,17 @@ TEST_CASE("get_keymap_descriptions() returns at most one entry per key",
 
 	const auto descriptions = k.get_keymap_descriptions("feedlist");
 
-	std::set<std::string> keys;
+	std::set<KeyCombination> keys;
 	for (const auto& description : descriptions) {
 		if (description.cmd == "set-tag" || description.cmd == "select-tag") {
 			// Ignore set-tag/select-tag as these have the same operation-enum value
 			continue;
 		}
 
-		const std::string& key = description.key;
-		INFO("key: \"" << key << "\"");
+		const auto& key = description.key;
+		INFO("key: \"" << key.to_bindkey_string() << "\"");
 
-		if (!key.empty()) {
+		if (!key.get_key().empty()) {
 			REQUIRE(keys.count(key) == 0);
 			keys.insert(key);
 		}
@@ -362,7 +381,8 @@ TEST_CASE("get_keymap_descriptions() does not return empty commands or descripti
 	}
 }
 
-TEST_CASE("get_keymap_descriptions() includes entries which include different keys bound to same operation",
+TEST_CASE("get_keymap_descriptions() includes entries which include different "
+	"keys bound to same operation",
 	"[KeyMap]")
 {
 	KeyMap k(KM_NEWSBOAT);
@@ -375,15 +395,15 @@ TEST_CASE("get_keymap_descriptions() includes entries which include different ke
 
 	const auto descriptions = k.get_keymap_descriptions("feedlist");
 
-	std::set<std::string> keys;
+	std::set<KeyCombination> keys;
 	for (const auto& description : descriptions) {
 		if (description.cmd == operation) {
-			CHECK(description.key != "");
+			CHECK(description.key.get_key() != "");
 			keys.insert(description.key);
 		}
 	}
 
-	REQUIRE(keys == std::set<std::string>({"a", "b", "c"}));
+	REQUIRE(keys == std::set<KeyCombination>({KeyCombination("a"), KeyCombination("b"), KeyCombination("c")}));
 }
 
 TEST_CASE("dump_config() returns a line for each keybind and macro", "[KeyMap]")
@@ -420,9 +440,9 @@ TEST_CASE("dump_config() returns a line for each keybind and macro", "[KeyMap]")
 
 	GIVEN("a few keybindings") {
 		k.unset_all_keys("all");
-		k.set_key(OP_OPEN, "ENTER", "feedlist");
-		k.set_key(OP_NEXT, "j", "articlelist");
-		k.set_key(OP_PREV, "k", "articlelist");
+		k.set_key(OP_OPEN, KeyCombination("ENTER"), "feedlist");
+		k.set_key(OP_NEXT, KeyCombination("j"), "articlelist");
+		k.set_key(OP_PREV, KeyCombination("k"), "articlelist");
 
 		WHEN("calling dump_config()") {
 			k.dump_config(dumpOutput);
@@ -440,7 +460,7 @@ TEST_CASE("dump_config() returns a line for each keybind and macro", "[KeyMap]")
 	GIVEN("a few registered macros and one regular keybinding") {
 		k.unset_all_keys("all");
 
-		k.set_key(OP_OPEN, "ENTER", "feedlist");
+		k.set_key(OP_OPEN, KeyCombination("ENTER"), "feedlist");
 		k.handle_action("macro", "1 open");
 		k.handle_action("macro", "2 open ; next");
 		k.handle_action("macro", "3 open ; next ; prev");
@@ -466,22 +486,53 @@ TEST_CASE("dump_config() returns a line for each keybind and macro", "[KeyMap]")
 
 		k.handle_action("macro", "1 set \"arg 1\"");
 		k.handle_action("macro", "2 set \"arg 1\" ; set \"arg 2\" \"arg 3\"");
+		k.handle_action("macro", "x set a \"arg 1\"");
+		k.handle_action("macro", "y set m n");
+		k.handle_action("macro", "z set var I");
 
 		WHEN("calling dump_config()") {
 			k.dump_config(dumpOutput);
 
 			THEN("there is one line per configured macro ; all arguments are included") {
-				REQUIRE(dumpOutput.size() == 2);
+				REQUIRE(dumpOutput.size() == 5);
 
 				REQUIRE(dumpOutput[0] == R"(macro 1 set "arg 1")");
 				REQUIRE(dumpOutput[1] == R"(macro 2 set "arg 1" ; set "arg 2" "arg 3")");
+				REQUIRE(dumpOutput[2] == R"(macro x set "a" "arg 1")");
+				REQUIRE(dumpOutput[3] == R"(macro y set "m" "n")");
+				REQUIRE(dumpOutput[4] == R"(macro z set "var" "I")");
 			}
 		}
 	}
 }
 
-// Related to https://github.com/newsboat/newsboat/issues/702
-TEST_CASE("Regression test for macro configuration semicolon handling",
+TEST_CASE("dump_config() stores a description if it is present", "[KeyMap]")
+{
+	KeyMap k(KM_NEWSBOAT);
+
+	GIVEN("a few macros, some with a description") {
+		k.unset_all_keys("all");
+
+		k.handle_action("macro", R"(x open -- "first description")");
+		k.handle_action("macro", R"(y set m n -- "configure \"m\" \\ ")");
+		k.handle_action("macro", R"(z set var I)");
+
+		WHEN("calling dump_config()") {
+			std::vector<std::string> dumpOutput;
+			k.dump_config(dumpOutput);
+
+			THEN("there is one line per configured macro ; all given descriptions are included") {
+				REQUIRE(dumpOutput.size() == 3);
+
+				REQUIRE(dumpOutput[0] == R"(macro x open -- "first description")");
+				REQUIRE(dumpOutput[1] == R"(macro y set "m" "n" -- "configure \"m\" \\ ")");
+				REQUIRE(dumpOutput[2] == R"(macro z set "var" "I")");
+			}
+		}
+	}
+}
+
+TEST_CASE("Regression test for https://github.com/newsboat/newsboat/issues/702",
 	"[KeyMap]")
 {
 	KeyMap k(KM_NEWSBOAT);
@@ -489,7 +540,7 @@ TEST_CASE("Regression test for macro configuration semicolon handling",
 	SECTION("semicolon following quoted argument") {
 		k.handle_action("macro", R"(a set browser "firefox"; open-in-browser)");
 
-		const auto macros = k.get_macro("a");
+		const auto macros = k.get_macro(KeyCombination("a"));
 		REQUIRE(macros.size() == 2);
 		REQUIRE(macros[0].op == OP_INT_SET);
 		REQUIRE(macros[0].args == std::vector<std::string>({"browser", "firefox"}));
@@ -500,7 +551,7 @@ TEST_CASE("Regression test for macro configuration semicolon handling",
 	SECTION("semicolon following unquoted argument") {
 		k.handle_action("macro", R"(b set browser firefox; open-in-browser)");
 
-		const auto macros = k.get_macro("b");
+		const auto macros = k.get_macro(KeyCombination("b"));
 		REQUIRE(macros.size() == 2);
 		REQUIRE(macros[0].op == OP_INT_SET);
 		REQUIRE(macros[0].args == std::vector<std::string>({"browser", "firefox"}));
@@ -511,7 +562,7 @@ TEST_CASE("Regression test for macro configuration semicolon handling",
 	SECTION("semicolon following unquoted operation") {
 		k.handle_action("macro", R"(c open-in-browser; quit)");
 
-		const auto macros = k.get_macro("c");
+		const auto macros = k.get_macro(KeyCombination("c"));
 		REQUIRE(macros.size() == 2);
 		REQUIRE(macros[0].op == OP_OPENINBROWSER);
 		REQUIRE(macros[0].args == std::vector<std::string>({}));
@@ -519,3 +570,117 @@ TEST_CASE("Regression test for macro configuration semicolon handling",
 		REQUIRE(macros[1].args == std::vector<std::string>({}));
 	}
 }
+
+TEST_CASE("Whitespace around semicolons in macros is optional", "[KeyMap]")
+{
+	KeyMap k(KM_NEWSBOAT);
+
+	const auto check = [&k]() {
+		const auto macro = k.get_macro(KeyCombination("x"));
+
+		REQUIRE(macro.size() == 3);
+
+		REQUIRE(macro[0].op == OP_OPEN);
+		REQUIRE(macro[0].args == std::vector<std::string>({}));
+
+		REQUIRE(macro[1].op == OP_INT_SET);
+		REQUIRE(macro[1].args == std::vector<std::string>({"browser", "firefox --private-window"}));
+
+		REQUIRE(macro[2].op == OP_QUIT);
+		REQUIRE(macro[2].args == std::vector<std::string>({}));
+	};
+
+	SECTION("Whitespace not required before the semicolon") {
+		k.handle_action("macro",
+			R"(x open; set browser "firefox --private-window"; quit)");
+		check();
+	}
+
+	SECTION("Whitespace not required after the semicolon") {
+		k.handle_action("macro",
+			R"(x open ;set browser "firefox --private-window" ;quit)");
+		check();
+	}
+
+	SECTION("Whitespace not required on either side of the semicolon") {
+		k.handle_action("macro",
+			R"(x open;set browser "firefox --private-window";quit)");
+		check();
+	}
+}
+
+TEST_CASE("It's not an error to have no operations before a semicolon in "
+	"a macro",
+	"[KeyMap]")
+{
+	KeyMap k(KM_NEWSBOAT);
+
+	const std::vector<std::string> op_lists = {
+		"; ;; ; open",
+		";;; ;; ; open",
+		";;; ;; ; open ;",
+		";;; ;; ; open ;; ;",
+		";;; ;; ; open ; ;;;;",
+		";;; open ; ;;;;",
+		"; open ;; ;; ;",
+		"open ; ;;; ;;",
+	};
+
+	for (const auto& op_list : op_lists) {
+		DYNAMIC_SECTION(op_list) {
+			k.handle_action("macro", "r " + op_list);
+
+			const auto macro = k.get_macro(KeyCombination("r"));
+			REQUIRE(macro.size() == 1);
+			REQUIRE(macro[0].op == OP_OPEN);
+			REQUIRE(macro[0].args == std::vector<std::string>({}));
+		}
+	}
+}
+
+TEST_CASE("Semicolons in operation's arguments don't break parsing of a macro",
+	"[KeyMap]")
+{
+	// This is a regression test for https://github.com/newsboat/newsboat/issues/1200
+
+	KeyMap k(KM_NEWSBOAT);
+
+	k.handle_action("macro",
+		R"(x set browser "sleep 3; do-something ; echo hi"; open-in-browser)");
+
+	const auto macro = k.get_macro(KeyCombination("x"));
+	REQUIRE(macro.size() == 2);
+	REQUIRE(macro[0].op == OP_INT_SET);
+	REQUIRE(macro[0].args == std::vector<std::string>({"browser", "sleep 3; do-something ; echo hi"}));
+	REQUIRE(macro[1].op == OP_OPENINBROWSER);
+	REQUIRE(macro[1].args == std::vector<std::string>({}));
+}
+
+TEST_CASE("prepare_keymap_hint() returns a string describing keys to which given operations are bound",
+	"[KeyMap]")
+{
+	KeyMap k(KM_NEWSBOAT);
+
+	k.handle_action("bind-key", "w help");
+	k.handle_action("bind-key", "x open");
+	k.handle_action("bind-key", "< open");
+	k.handle_action("unbind-key", "r");
+	k.handle_action("bind-key", "O reload");
+	// This frees up OP_SEARCH
+	k.handle_action("unbind-key", "/");
+
+	const std::vector<KeyMapHintEntry> hints {
+		{OP_QUIT, "Get out of <this> dialog"},
+		{OP_HELP, "HALP"},
+		{OP_OPEN, "Open"},
+		{OP_RELOAD, "Reload current entry"},
+		{OP_SEARCH, "Go find me"}
+	};
+
+	REQUIRE(k.prepare_keymap_hint(hints, "feedlist") ==
+		"<key>q</><colon>:</><desc>Get out of <>this> dialog</> "
+		"<key>?</><comma>,</><key>w</><colon>:</><desc>HALP</> "
+		"<key><></><comma>,</><key>ENTER</><comma>,</><key>x</><colon>:</><desc>Open</> "
+		"<key>O</><colon>:</><desc>Reload current entry</> "
+		"<key><>none></><colon>:</><desc>Go find me</> ");
+}
