@@ -2,11 +2,11 @@
 
 #include "3rd-party/catch.hpp"
 #include "rss/exception.h"
-#include "test-helpers/exceptionwithmsg.h"
+#include "test_helpers/exceptionwithmsg.h"
 
 TEST_CASE("Throws exception if file doesn't exist", "[rsspp::Parser]")
 {
-	using TestHelpers::ExceptionWithMsg;
+	using test_helpers::ExceptionWithMsg;
 
 	rsspp::Parser p;
 
@@ -17,7 +17,7 @@ TEST_CASE("Throws exception if file doesn't exist", "[rsspp::Parser]")
 
 TEST_CASE("Throws exception if file can't be parsed", "[rsspp::Parser]")
 {
-	using TestHelpers::ExceptionWithMsg;
+	using test_helpers::ExceptionWithMsg;
 
 	rsspp::Parser p;
 
@@ -232,32 +232,50 @@ TEST_CASE("Extracts data from media:... tags in atom feed", "[rsspp::Parser]")
 	REQUIRE(f.pubDate == "Tue, 30 Dec 2008 18:26:15 +0000");
 	REQUIRE(f.link == "http://example.com/");
 
-	REQUIRE(f.items.size() == 5u);
+	REQUIRE(f.items.size() == 6u);
 	REQUIRE(f.items[0].title == "using regular content");
 	REQUIRE(f.items[0].description == "regular html content");
 	REQUIRE(f.items[0].description_mime_type == "text/html");
+	REQUIRE(f.items[0].author == "A Person");
 
 	REQUIRE(f.items[1].title == "using media:description");
 	REQUIRE(f.items[1].description == "media plaintext content");
 	REQUIRE(f.items[1].description_mime_type == "text/plain");
+	REQUIRE(f.items[1].author == "John Doe");
 
 	REQUIRE(f.items[2].title == "using multiple media tags");
 	REQUIRE(f.items[2].description == "media html content");
 	REQUIRE(f.items[2].description_mime_type == "text/html");
 	REQUIRE(f.items[2].link == "http://example.com/player.html");
+	REQUIRE(f.items[2].author == "John Doe");
 
 	REQUIRE(f.items[3].title ==
 		"using multiple media tags nested in group/content");
 	REQUIRE(f.items[3].description == "nested media html content");
 	REQUIRE(f.items[3].description_mime_type == "text/html");
 	REQUIRE(f.items[3].link == "http://example.com/player.html");
+	REQUIRE(f.items[3].author == "John Doe");
+	REQUIRE(f.items[3].enclosures.size() == 1);
+	REQUIRE(f.items[3].enclosures[0].description == "nested media html content");
+	REQUIRE(f.items[3].enclosures[0].description_mime_type == "text/html");
 
 	SECTION("media:{title,description,player} does not overwrite regular title, description, and link if they exist") {
 		REQUIRE(f.items[4].title == "regular title");
 		REQUIRE(f.items[4].description == "regular content");
 		REQUIRE(f.items[4].description_mime_type == "text/html");
 		REQUIRE(f.items[4].link == "http://example.com/regular-link");
+		REQUIRE(f.items[4].author == "John Doe");
 	}
+
+	REQUIRE(f.items[5].title == "using media:content");
+	REQUIRE(f.items[5].description == "regular content");
+	REQUIRE(f.items[5].description_mime_type == "text/html");
+	REQUIRE(f.items[5].link == "http://example.com/4.html");
+	REQUIRE(f.items[5].enclosures.size() == 2);
+	REQUIRE(f.items[5].enclosures[0].url == "http://example.com/media-test.png");
+	REQUIRE(f.items[5].enclosures[0].type == "image/png");
+	REQUIRE(f.items[5].enclosures[1].url == "http://example.com/movie.mov");
+	REQUIRE(f.items[5].enclosures[1].type == "video/quicktime");
 }
 
 TEST_CASE("Extracts data from media:... tags in  RSS 2.0 feeds",
@@ -272,7 +290,7 @@ TEST_CASE("Extracts data from media:... tags in  RSS 2.0 feeds",
 	REQUIRE(f.link == "http://example.com/blog/");
 	REQUIRE(f.description == "my description");
 
-	REQUIRE(f.items.size() == 2u);
+	REQUIRE(f.items.size() == 3u);
 
 	REQUIRE(f.items[0].title == "using multiple media tags");
 	REQUIRE(f.items[0].description == "media html content");
@@ -284,4 +302,79 @@ TEST_CASE("Extracts data from media:... tags in  RSS 2.0 feeds",
 	REQUIRE(f.items[1].description == "nested media html content");
 	REQUIRE(f.items[1].description_mime_type == "text/html");
 	REQUIRE(f.items[1].link == "http://example.com/player.html");
+	REQUIRE(f.items[1].enclosures.size() == 1);
+	REQUIRE(f.items[1].enclosures[0].description == "nested media html content");
+	REQUIRE(f.items[1].enclosures[0].description_mime_type == "text/html");
+
+	REQUIRE(f.items[2].enclosures.size() == 2);
+	REQUIRE(f.items[2].enclosures[0].url == "http://example.com/media-test.png");
+	REQUIRE(f.items[2].enclosures[0].type == "image/png");
+	REQUIRE(f.items[2].enclosures[1].url == "http://example.com/movie.mov");
+	REQUIRE(f.items[2].enclosures[1].type == "video/quicktime");
+}
+
+TEST_CASE("Multiple links in item", "[rsspp::Parser]")
+{
+	rsspp::Parser p;
+	rsspp::Feed f;
+
+	REQUIRE_NOTHROW(f = p.parse_file("data/multiple_item_links.atom"));
+
+	REQUIRE(f.items.size() == 1u);
+
+	REQUIRE(f.items[0].title == "Multiple links");
+	REQUIRE(f.items[0].link == "http://www.test.org/tests");
+}
+
+TEST_CASE("Feed authors and source authors in atom feed", "[rsspp::Parser]")
+{
+	rsspp::Parser p;
+	rsspp::Feed f;
+
+	REQUIRE_NOTHROW(f = p.parse_file("data/atom10_feed_authors.xml"));
+
+	REQUIRE(f.rss_version == rsspp::Feed::ATOM_1_0);
+
+	REQUIRE(f.title == "Author Test Feed");
+	REQUIRE(f.title_type == "text");
+	REQUIRE(f.pubDate == "Mon, 28 Nov 2022 13:01:25 +0000");
+	REQUIRE(f.link == "http://example.com/");
+
+	REQUIRE(f.items.size() == 9u);
+	REQUIRE(f.items[0].title == "Entry Without Author");
+	REQUIRE(f.items[0].description == "Feed authors should be used.");
+	REQUIRE(f.items[0].author == "First Feed Author, Second Feed Author");
+
+	REQUIRE(f.items[1].title == "Entry With Single Author");
+	REQUIRE(f.items[1].description == "Entry author should be used.");
+	REQUIRE(f.items[1].author == "Entry Author");
+
+	REQUIRE(f.items[2].title == "Entry With Multiple Authors");
+	REQUIRE(f.items[2].description == "Both entry authors should be used.");
+	REQUIRE(f.items[2].author == "Entry Author 1, Entry Author 2");
+
+	REQUIRE(f.items[3].title == "Entry With Empty Author Names");
+	REQUIRE(f.items[3].description == "Both feed authors should be used.");
+	REQUIRE(f.items[3].author == "First Feed Author, Second Feed Author");
+
+	REQUIRE(f.items[4].title == "Entry With Single Source Author");
+	REQUIRE(f.items[4].description == "Entry source author should be used.");
+	REQUIRE(f.items[4].author == "Entry Source Author");
+
+	REQUIRE(f.items[5].title == "Entry With Multiple Source Authors");
+	REQUIRE(f.items[5].description == "All entry source authors should be used.");
+	REQUIRE(f.items[5].author ==
+		"Entry Source Author 1, Entry Source Author 2, Entry Source Author 3");
+
+	REQUIRE(f.items[6].title == "Entry With Empty Source Author Names");
+	REQUIRE(f.items[6].description == "Both feed authors should be used.");
+	REQUIRE(f.items[6].author == "First Feed Author, Second Feed Author");
+
+	REQUIRE(f.items[7].title == "Entry With Single Author And Source Author");
+	REQUIRE(f.items[7].description == "Entry author should be used.");
+	REQUIRE(f.items[7].author == "Entry Author");
+
+	REQUIRE(f.items[8].title == "Entry With Multiple Author And Source Authors");
+	REQUIRE(f.items[8].description == "Both entry authors should be used.");
+	REQUIRE(f.items[8].author == "Entry Author 1, Entry Author 2");
 }
