@@ -1,7 +1,7 @@
 #include "rss/rssparser.h"
 
 #include "3rd-party/catch.hpp"
-#include "test-helpers/envvar.h"
+#include "test_helpers/envvar.h"
 
 TEST_CASE("W3CDTF parser extracts date and time from any valid string",
 	"[rsspp::RssParser]")
@@ -65,10 +65,7 @@ TEST_CASE(
 	auto input = "2008-12-30T10:03:15-08:00";
 	auto expected = "Tue, 30 Dec 2008 18:03:15 +0000";
 
-	TestHelpers::EnvVar tzEnv("TZ");
-	tzEnv.on_change([](nonstd::optional<std::string>) {
-		::tzset();
-	});
+	test_helpers::TzEnvVar tzEnv;
 
 	// US/Pacific and Australia/Sydney have pretty much opposite DST
 	// schedules, so for any given moment in time one of the following two
