@@ -6,10 +6,8 @@ test_helpers::Opts::Opts(std::initializer_list<std::string> opts)
 	m_opts.reserve(m_argc);
 
 	for (const std::string& option : opts) {
-		// Copy string into separate char[], managed by
-		// unique_ptr.
-		auto ptr = std::unique_ptr<char[]>(
-				new char[option.size() + 1]);
+		// Copy string into separate char[], managed by unique_ptr.
+		auto ptr = std::make_unique<char[]>(option.size() + 1);
 		std::copy(option.cbegin(), option.cend(), ptr.get());
 		// C and C++ require argv to be NULL-terminated:
 		// https://stackoverflow.com/questions/18547114/why-do-we-need-argc-while-there-is-always-a-null-at-the-end-of-argv
@@ -21,7 +19,7 @@ test_helpers::Opts::Opts(std::initializer_list<std::string> opts)
 	}
 
 	// Copy out intermediate argv vector into its final storage.
-	m_data = std::unique_ptr<char* []>(new char* [m_argc + 1]);
+	m_data = std::make_unique<char* []>(m_argc + 1);
 	int i = 0;
 	for (const auto& ptr : m_opts) {
 		m_data.get()[i++] = ptr.get();
